@@ -16,7 +16,7 @@ class MainWindow : public CGAL::Qt::DemosMainWindow, private Ui::MainWindow
   Q_OBJECT
 
   public:
-  MainWindow(QWidget* parent = 0);
+  MainWindow(QWidget* parent = nullptr);
 
   void connectActions();
 
