@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/demo/Arrangement_on_surface_2/ArrangementDemoTab.h $
-// $Id: ArrangementDemoTab.h 1d3815f 2020-10-02T17:29:03+02:00 Ahmed Essam
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/demo/Arrangement_on_surface_2/ArrangementDemoTab.h $
+// $Id: demo/Arrangement_on_surface_2/ArrangementDemoTab.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Alex Tsui <alextsui05@gmail.com>
@@ -38,7 +38,6 @@ namespace Qt
 {
 class Callback;
 class ArrangementGraphicsItemBase;
-class ArrangementGraphicsItemBase;
 class GraphicsViewCurveInputBase;
 class GraphicsViewNavigation;
 enum class CurveType;
