@@ -4,13 +4,9 @@
 #include <iostream>
 #include <fstream>
 
-#include <CGAL/IO/File_scanner_OFF.h>
-#include <CGAL/IO/File_header_OFF.h>
-#include <CGAL/IO/File_writer_OFF.h>
-#include <CGAL/IO/read_off_points.h>
-#include <CGAL/IO/write_off_points.h>
-#include <CGAL/IO/read_xyz_points.h>
-#include <CGAL/IO/write_xyz_points.h>
+#include <CGAL/IO/OFF.h>
+#include <CGAL/IO/read_points.h>
+#include <CGAL/IO/write_points.h>
 
 #include <CGAL/Iterator_range.h>
 
@@ -104,20 +100,6 @@ void Scene::loadPointsOFF(const char* filename)
   /* 1. use CGAL::File_scanner_OFF to read in data --tested */
   readOFFPointsandFacets( filename, pts );
 
-  /* 2. use CGAL::read_off_points to read in data -- tested */
-  /* Note: read in points only, i.e. normals and faces are ignored */
-  /* Note: this function can NOT omit comments (starting with '#') */
-//  ifstream fin;
-//  fin.open( filename );
-  // check whether the file is opened properly
-//  if( !fin ) {
-//    showError( QObject::tr("Error: cannot open file %1 for reading.").arg(filename) );
-//    return;
-//  }
-//  if ( !CGAL::read_off_points( fin,  // inout ifstream
-//                               back_inserter(pts) ) ) {  // output iterator over points
-//    showError( QObject::tr("Error: cannot read file %1.").arg(filename) );
-//  }
 
   /* Insert the points to build a Delaunay triangulation */
   /* Note: this function returns the number of inserted points;
@@ -141,20 +123,12 @@ void Scene::loadPointsOFF(const char* filename)
 
 void Scene::loadPointsXYZ(const char* filename)
 {
-  ifstream fin;
-  fin.open( filename );
-  // Check whether the file is opened properly
-  if( !fin ) {
-    showError( QObject::tr("Error: cannot open file %1 for reading.").arg(filename) );
-    return;
-  }
-
-  /* Use CGAL::read_xyz_points to read in data -- tested */
+  /* Use CGAL::IO::read_XYZ to read in data -- tested */
   /* Note: this function reads in points only (normals are ignored) */
   /* Note: this function can NOT omit comments (starting with '#') */
   list<Point_3> pts;
-  if( !CGAL::read_xyz_points( fin,  // input ifstream
-                              back_inserter(pts) ) ) {  // output iterator over points
+  if( !CGAL::IO::read_XYZ( filename,  // input ifstream
+                           back_inserter(pts) ) ) {  // output iterator over points
     showError( QObject::tr("Error: cannot read file %1.").arg(filename) );
   }
 
@@ -225,11 +199,11 @@ void Scene::savePointsXYZ(const char* filename)
     return;
   }
 
-  /* Use CGAL::write_xyz_points to write out data */
+  /* Use CGAL::IO::write_xyz_points to write out data */
   /* Note: this function writes out points only (normals are ignored) */
-  if( !CGAL::write_xyz_points( fout,  // output ofstream
-                               CGAL::make_range (m_dt.points_begin(),  // first output point
-                                                 m_dt.points_end()) ) ) {  // past-the-end output point
+  if( !CGAL::IO::write_XYZ( fout,  // output ofstream
+                            CGAL::make_range( m_dt.points_begin(),  // first output point
+                                              m_dt.points_end()) ) ) {  // past-the-end output point
     showError( QObject::tr("Error: cannot read file %1.").arg(filename) );
   }
 }
