@@ -16,7 +16,7 @@ public:
 public:
   inline void setViewer(CGAL::QGLViewer* v) {  m_viewer = v;  }
   inline void showError(const QString & msg) {
-    if(!m_viewer) m_viewer->displayMessage( msg );
+    if(m_viewer != nullptr) m_viewer->displayMessage( msg );
   }
   inline bool isDTEmpty() {  return m_dt.number_of_vertices()==0;  }
   inline void eraseOldData() {  m_dt.clear();  m_vhArray.clear();  }
