@@ -13,18 +13,17 @@
 
 #include "MainWindow.h"
 #include <QApplication>
+#include <CGAL/Qt/init_ogl_context.h>
 
 int main(int argc, char** argv)
 {
+  CGAL::Qt::init_ogl_context(2, 1);
+
   QApplication app(argc, argv);
 
   app.setOrganizationDomain("inria.fr");
   app.setOrganizationName("INRIA");
   app.setApplicationName("3D Triangulation Demo");
-  //for windows
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 3, 0))
-  app.setAttribute(Qt::AA_UseDesktopOpenGL);
-#endif
 
   MainWindow mw;
   mw.show();
