@@ -9,10 +9,10 @@
 
 enum Segment_color {RED, BLUE};
 
-typedef CGAL::Arr_consolidated_curve_data_traits_2<Traits, Segment_color>
-                                                           Data_traits;
-typedef Data_traits::Curve_2                               Colored_segment;
-typedef CGAL::Arrangement_2<Data_traits>                   Colored_arr;
+using Data_traits =
+  CGAL::Arr_consolidated_curve_data_traits_2<Traits, Segment_color>;
+using Colored_segment = Data_traits::Curve_2;
+using Colored_arr = CGAL::Arrangement_2<Data_traits>;
 
 int main() {
   Colored_arr arr;
