@@ -8,8 +8,8 @@
 #include "arr_inexact_construction_segments.h"
 #include "point_location_utils.h"
 
-typedef CGAL::Arr_walk_along_line_point_location<Arrangement> Walk_pl;
-typedef CGAL::Arr_trapezoid_ric_point_location<Arrangement>   Trap_pl;
+using Walk_pl = CGAL::Arr_walk_along_line_point_location<Arrangement>;
+using Trap_pl = CGAL::Arr_trapezoid_ric_point_location<Arrangement>;
 
 int main() {
   // Construct the arrangement.
