@@ -6,8 +6,8 @@ typedef K::Point_2 Point_2;
 
 int main()
 {
-  CGAL::set_ascii_mode(std::cin);
-  CGAL::set_ascii_mode(std::cout);
+  CGAL::IO::set_ascii_mode(std::cin);
+  CGAL::IO::set_ascii_mode(std::cout);
   std::istream_iterator< Point_2 >  in_start( std::cin );
   std::istream_iterator< Point_2 >  in_end;
   std::ostream_iterator< Point_2 >  out( std::cout, "\n" );
