@@ -1,6 +1,7 @@
 #include <CGAL/HalfedgeDS_min_items.h>
 #include <CGAL/HalfedgeDS_default.h>
 #include <CGAL/HalfedgeDS_decorator.h>
+#include <cassert>
 
 // no traits needed, argument can be arbitrary dummy.
 typedef CGAL::HalfedgeDS_default<int, CGAL::HalfedgeDS_min_items> HDS;
@@ -10,6 +11,6 @@ int main() {
     HDS hds;
     Decorator decorator(hds);
     decorator.create_loop();
-    CGAL_assertion( decorator.is_valid());
+    assert( decorator.is_valid());
     return 0;
 }
