@@ -26,7 +26,7 @@ int main()
 
   std::cout << "Generate " << n << " random points on a sphere." << std::endl;
   CGAL::Random_points_on_sphere_3<Point_3> g(1);
-  CGAL::cpp11::copy_n(g, n, std::back_inserter(points));
+  std::copy_n(g, n, std::back_inserter(points));
 
   Point_3 p(1, 0, 0);
   Vector_3 normal(p - CGAL::ORIGIN);
@@ -48,9 +48,8 @@ int main()
 
   std::cout << "Testing the barycentric property " << std::endl;
   Point_3 b(0, 0, 0);
-  for(std::vector< std::pair< Point_3, Coord_type > >::const_iterator
-      it = coords.begin(); it!=coords.end(); ++it)
-    b = b + (it->second/norm) * (it->first - CGAL::ORIGIN);
+  for(const std::pair< Point_3, Coord_type >& pc : coords)
+    b = b + (pc.second/norm) * (pc.first - CGAL::ORIGIN);
 
   std::cout << "    weighted barycenter: " << b <<std::endl;
   std::cout << "    squared distance: " << CGAL::squared_distance(p,b) << std::endl;
