@@ -32,8 +32,7 @@ typedef CGAL::Mesh_complex_3_in_triangulation_3<Tr> C3t3;
 // Criteria
 typedef CGAL::Mesh_criteria_3<Tr> Mesh_criteria;
 
-// To avoid verbose function and named parameters call
-using namespace CGAL::parameters;
+namespace params = CGAL::parameters;
 
 int main(int argc, char* argv[])
 {
@@ -46,12 +45,12 @@ int main(int argc, char* argv[])
   }
   /// [Domain creation]
   Mesh_domain domain =
-    Mesh_domain::create_gray_image_mesh_domain(image, 2.9f, 0.f);
+    Mesh_domain::create_gray_image_mesh_domain(image, params::iso_value(2.9f).value_outside(0.f));
   /// [Domain creation]
 
   /// [Mesh criteria]
-  Mesh_criteria criteria(facet_angle = 30, facet_size = 6, facet_distance = 2,
-    cell_radius_edge_ratio = 3, cell_size = 8);
+  Mesh_criteria criteria(params::facet_angle(30).facet_size(6).facet_distance(2).
+                                 cell_radius_edge_ratio(3).cell_size(8));
 
   /// [Meshing]
   C3t3 c3t3;
