@@ -8,6 +8,7 @@
 #include <CGAL/Polyhedral_mesh_domain_3.h>
 #include <CGAL/make_mesh_3.h>
 #include <CGAL/refine_mesh_3.h>
+#include <CGAL/IO/File_medit.h>
 
 // Domain
 typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
@@ -28,8 +29,7 @@ typedef CGAL::Mesh_complex_3_in_triangulation_3<Tr> C3t3;
 // Criteria
 typedef CGAL::Mesh_criteria_3<Tr> Mesh_criteria;
 
-// To avoid verbose function and named parameters call
-using namespace CGAL::parameters;
+namespace params = CGAL::parameters;
 
 int main(int argc, char*argv[])
 {
@@ -53,26 +53,27 @@ int main(int argc, char*argv[])
   Mesh_domain domain(polyhedron);
 
   // Mesh criteria (no cell_size set)
-  Mesh_criteria criteria(facet_angle=25, facet_size=0.15, facet_distance=0.008,
-                         cell_radius_edge_ratio=3);
+  Mesh_criteria criteria(params::facet_angle(25).facet_size(0.15).facet_distance(0.008).
+                                 cell_radius_edge_ratio(3));
 
   // Mesh generation
-  C3t3 c3t3 = CGAL::make_mesh_3<C3t3>(domain, criteria, no_perturb(), no_exude());
+  C3t3 c3t3 = CGAL::make_mesh_3<C3t3>(domain, criteria, params::no_perturb().no_exude());
 
   // Output
   std::ofstream medit_file("out_1.mesh");
-  c3t3.output_to_medit(medit_file);
+  CGAL::IO::write_MEDIT(medit_file, c3t3);
   medit_file.close();
 
   // Set tetrahedron size (keep cell_radius_edge_ratio), ignore facets
-  Mesh_criteria new_criteria(cell_radius_edge_ratio=3, cell_size=0.03);
+  Mesh_criteria new_criteria(params::cell_radius_edge_ratio(3).cell_size(0.03));
 
   // Mesh refinement (and make the output manifold)
-  CGAL::refine_mesh_3(c3t3, domain, new_criteria, manifold());
+  CGAL::refine_mesh_3(c3t3, domain, new_criteria, params::manifold());
 
   // Output
   medit_file.open("out_2.mesh");
-  c3t3.output_to_medit(medit_file);
+  CGAL::IO::write_MEDIT(medit_file, c3t3);
+  medit_file.close();
 
   return EXIT_SUCCESS;
 }
