@@ -22,8 +22,7 @@ typedef CGAL::Mesh_complex_3_in_triangulation_3<
 // Criteria
 typedef CGAL::Mesh_criteria_3<Tr> Mesh_criteria;
 
-// To avoid verbose function and named parameters call
-using namespace CGAL::parameters;
+namespace params = CGAL::parameters;
 
 int main()
 {
@@ -49,13 +48,13 @@ int main()
   domain.detect_features(); //includes detection of borders
 
   // Mesh criteria
-  Mesh_criteria criteria(edge_size = 0.025,
-                         facet_angle = 25,
-                         facet_size = 0.1,
-                         facet_distance = 0.001);
+  Mesh_criteria criteria(params::edge_size(0.025).
+                                 facet_angle(25).
+                                 facet_size(0.1).
+                                 facet_distance(0.001));
 
   // Mesh generation
-  C3t3 c3t3 = CGAL::make_mesh_3<C3t3>(domain, criteria, no_perturb(), no_exude());
+  C3t3 c3t3 = CGAL::make_mesh_3<C3t3>(domain, criteria, params::no_perturb().no_exude());
 
   // Output the facets of the c3t3 to an OFF file. The facets will not be
   // oriented.
