@@ -1,6 +1,7 @@
 #include <CGAL/Exact_integer.h>
 #include <CGAL/Homogeneous.h>
 #include <CGAL/Nef_polyhedron_3.h>
+#include <cassert>
 
 typedef CGAL::Homogeneous<CGAL::Exact_integer>  Kernel;
 typedef CGAL::Nef_polyhedron_3<Kernel> Nef_polyhedron;
@@ -9,7 +10,7 @@ int main() {
   Nef_polyhedron N0(Nef_polyhedron::EMPTY);
   Nef_polyhedron N1(Nef_polyhedron::COMPLETE);
 
-  CGAL_assertion (N0 == N1.complement());
-  CGAL_assertion (N0 != N1);
+  assert(N0 == N1.complement());
+  assert(N0 != N1);
   return 0;
 }
