@@ -21,7 +21,7 @@ create_random_Nef_S2(Nef_polyhedron_S2<K,I,M>& P, int n=5, int seed=0) {
   typedef CGAL::Random_points_in_cube_3<Point_3,Creator> Point_source;
 
   if(seed == 0)
-    std::srand(static_cast<unsigned int>(time(0)));
+    std::srand(static_cast<unsigned int>(time(nullptr)));
   else
     std::srand(seed);
 
