@@ -7,14 +7,14 @@
 #include <iostream>
 #include <string>
 
-typedef CGAL::Exact_predicates_inexact_constructions_kernel       K;
+typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
 
-typedef K::Point_3                                                Point;
-typedef K::Vector_3                                               Vector;
+typedef K::Point_3                                          Point;
+typedef K::Vector_3                                         Vector;
 
-typedef CGAL::Surface_mesh<Point>                                 Surface_mesh;
-typedef boost::graph_traits<Surface_mesh>::vertex_descriptor      vertex_descriptor;
-typedef boost::graph_traits<Surface_mesh>::face_descriptor        face_descriptor;
+typedef CGAL::Surface_mesh<Point>                           Mesh;
+typedef boost::graph_traits<Mesh>::vertex_descriptor        vertex_descriptor;
+typedef boost::graph_traits<Mesh>::face_descriptor          face_descriptor;
 
 namespace PMP = CGAL::Polygon_mesh_processing;
 
@@ -22,15 +22,15 @@ int main(int argc, char* argv[])
 {
   const std::string filename = (argc > 1) ? argv[1] : CGAL::data_file_path("meshes/eight.off");
 
-  Surface_mesh mesh;
+  Mesh mesh;
   if(!PMP::IO::read_polygon_mesh(filename, mesh))
   {
     std::cerr << "Invalid input." << std::endl;
     return 1;
   }
 
-  auto vnormals = mesh.add_property_map<vertex_descriptor, Vector>("v:normals", CGAL::NULL_VECTOR).first;
-  auto fnormals = mesh.add_property_map<face_descriptor, Vector>("f:normals", CGAL::NULL_VECTOR).first;
+  auto vnormals = mesh.add_property_map<vertex_descriptor, Vector>("v:normal", CGAL::NULL_VECTOR).first;
+  auto fnormals = mesh.add_property_map<face_descriptor, Vector>("f:normal", CGAL::NULL_VECTOR).first;
 
   PMP::compute_normals(mesh, vnormals, fnormals);
 
