@@ -7,8 +7,11 @@
 #include <OpenMesh/Core/IO/MeshIO.hh>
 #include <OpenMesh/Core/Mesh/PolyMesh_ArrayKernelT.hh>
 
-#include <iostream>
+#include <cassert>
 #include <fstream>
+#include <iostream>
+#include <iterator>
+#include <string>
 #include <vector>
 
 typedef CGAL::Exact_predicates_inexact_constructions_kernel   Kernel;
@@ -37,12 +40,12 @@ int main(int argc, char* argv[])
       std::vector<face_descriptor>  patch_facets;
       std::vector<vertex_descriptor> patch_vertices;
       bool success = std::get<0>(PMP::triangulate_refine_and_fair_hole(mesh, h,
-                                                                       std::back_inserter(patch_facets),
-                                                                       std::back_inserter(patch_vertices),
-                                                                       CGAL::parameters::vertex_point_map(get(CGAL::vertex_point, mesh))
+                                                                       CGAL::parameters::face_output_iterator(std::back_inserter(patch_facets))
+                                                                                        .vertex_output_iterator(std::back_inserter(patch_vertices))
+                                                                                        .vertex_point_map(get(CGAL::vertex_point, mesh))
                                                                                         .geom_traits(Kernel())));
 
-      CGAL_assertion(CGAL::is_valid_polygon_mesh(mesh));
+      assert(CGAL::is_valid_polygon_mesh(mesh));
 
       std::cout << "* FILL HOLE NUMBER " << ++nb_holes << std::endl;
       std::cout << "  Number of facets in constructed patch: " << patch_facets.size() << std::endl;
@@ -51,7 +54,7 @@ int main(int argc, char* argv[])
     }
   }
 
-  CGAL_assertion(CGAL::is_valid_polygon_mesh(mesh));
+  assert(CGAL::is_valid_polygon_mesh(mesh));
   std::cout << std::endl;
   std::cout << nb_holes << " holes have been filled" << std::endl;
 
