@@ -26,12 +26,22 @@ int main()
             boost::counting_iterator<std::size_t>(points.size()),
             std::back_inserter(indices));
 
+  std::cout << "Order using default policy (median)\n";
   CGAL::spatial_sort( indices.begin(),
                       indices.end(),
                       Search_traits_3(CGAL::make_property_map(points)) );
 
-  for (std::vector<std::size_t>::iterator it=indices.begin();it!=indices.end();++it)
-    std::cout << points[*it] << "\n";
+  for (std::size_t i : indices)
+    std::cout << points[i] << "\n";
+
+  std::cout << "Order using middle policy\n";
+  CGAL::spatial_sort( indices.begin(),
+                      indices.end(),
+                      Search_traits_3(CGAL::make_property_map(points)),
+                      CGAL::Hilbert_sort_middle_policy());
+
+  for (std::size_t i : indices)
+    std::cout << points[i] << "\n";
 
   std::cout << "done" << std::endl;
 
