@@ -16,6 +16,7 @@ typedef CGAL::Surface_mesh<Kernel::Point_3>     PolygonMesh;
 
 using namespace std;
 using namespace CGAL;
+namespace params = CGAL::parameters;
 
 int main(int argc, char **argv) {
   if (argc > 4) {
@@ -27,7 +28,7 @@ int main(int argc, char **argv) {
   }
 
   int d = (argc > 1) ? boost::lexical_cast<int>(argv[1]) : 2;
-  const char* in_file = (argc > 2) ? argv[2] : "data/quint_tris.off";
+  const std::string in_file = (argc > 2) ? argv[2] : CGAL::data_file_path("meshes/quint_tris.off");
   const char* out_file = (argc > 3) ? argv[3] : "result.off";
 
   PolygonMesh pmesh;
@@ -40,7 +41,7 @@ int main(int argc, char **argv) {
 
   Timer t;
   t.start();
-  Subdivision_method_3::Sqrt3_subdivision(pmesh,d);
+  Subdivision_method_3::Sqrt3_subdivision(pmesh, params::number_of_iterations(d));
   std::cerr << "Done (" << t.time() << " s)" << std::endl;
 
   std::ofstream out(out_file);
