@@ -2,10 +2,11 @@
 
 #include <CGAL/Simple_cartesian.h>
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_face_graph_triangle_primitive.h>
 #include <CGAL/Surface_mesh.h>
 #include <CGAL/boost/graph/Euler_operations.h>
+#include <CGAL/boost/graph/generators.h>
 
 typedef CGAL::Simple_cartesian<double> K;
 typedef K::Point_3 Point;
@@ -14,10 +15,10 @@ typedef K::Vector_3 Vector;
 typedef K::Segment_3 Segment;
 typedef CGAL::Surface_mesh<Point> Mesh;
 typedef CGAL::AABB_face_graph_triangle_primitive<Mesh> Primitive;
-typedef CGAL::AABB_traits<K, Primitive> Traits;
+typedef CGAL::AABB_traits_3<K, Primitive> Traits;
 typedef CGAL::AABB_tree<Traits> Tree;
-typedef boost::optional< Tree::Intersection_and_primitive_id<Segment>::Type > Segment_intersection;
-typedef boost::optional< Tree::Intersection_and_primitive_id<Plane>::Type > Plane_intersection;
+typedef std::optional< Tree::Intersection_and_primitive_id<Segment>::Type > Segment_intersection;
+typedef std::optional< Tree::Intersection_and_primitive_id<Plane>::Type > Plane_intersection;
 typedef Tree::Primitive_id Primitive_id;
 
 int main()
@@ -53,8 +54,8 @@ int main()
         tree.any_intersection(segment_query);
     if(intersection){
       // gets intersection object
-      if(boost::get<Point>(&(intersection->first))){
-        Point* p = boost::get<Point>(&(intersection->first));
+      if(std::get_if<Point>(&(intersection->first))){
+        Point* p = std::get_if<Point>(&(intersection->first));
         std::cout << "intersection object is a point " << *p <<  std::endl;
         std::cout << "with face "<< intersection->second  <<  std::endl;
       }
@@ -77,8 +78,8 @@ int main()
     // (generally a segment)
     Plane_intersection plane_intersection = tree.any_intersection(plane_query);
     if(plane_intersection){
-      if(boost::get<Segment>(&(plane_intersection->first))){
-        Segment* s = boost::get<Segment>(&(plane_intersection->first));
+      if(std::get_if<Segment>(&(plane_intersection->first))){
+        Segment* s = std::get_if<Segment>(&(plane_intersection->first));
         std::cout << "one intersection object is the segment " << s << std::endl;
         std::cout << "with face "<< intersection->second  <<  std::endl;
       }
