@@ -41,12 +41,13 @@ int main()
     vb = r.begin();
     ve = r.end();
     // or the boost Range API
-    vb = boost::begin(r);
-    ve = boost::end(r);
+    vb = std::begin(r);
+    ve = std::end(r);
 
     // or with boost::tie, as the CGAL range derives from std::pair
     for(boost::tie(vb, ve) = m.vertices(); vb != ve; ++vb){
-            std::cout << *vb << std::endl;
+            // Print vertex index and vertex coordinates
+            std::cout << *vb << " " << m.point(*vb) << std::endl;
     }
 
     // Instead of the classical for loop one can use
