@@ -12,8 +12,8 @@ typedef boost::graph_traits<Mesh>::vertex_descriptor vertex_descriptor;
 
 int main(int argc, char* argv[])
 {
-  const char* filename1 = (argc>1) ? argv[1] : "data/triangle.off";
-  const char* filename2 = (argc>2) ? argv[2] : "data/quad.off";
+  const std::string filename1 = (argc>1) ? argv[1] : CGAL::data_file_path("meshes/triangle.off");
+  const std::string filename2 = (argc>2) ? argv[2] : CGAL::data_file_path("meshes/quad.off");
 
   Mesh sm1, sm2;
   if(!CGAL::IO::read_polygon_mesh(filename1, sm1) || !CGAL::IO::read_polygon_mesh(filename2, sm2))
