@@ -44,7 +44,7 @@ struct My_visitor : SMS::Edge_collapse_visitor_base<Surface_mesh>
   My_visitor(Stats* s) : stats(s) {}
 
   // Called during the collecting phase for each edge collected.
-  void OnCollected(const Profile&, const boost::optional<double>&)
+  void OnCollected(const Profile&, const std::optional<double>&)
   {
     ++(stats->collected);
     std::cerr << "\rEdges collected: " << stats->collected << std::flush;
@@ -53,7 +53,7 @@ struct My_visitor : SMS::Edge_collapse_visitor_base<Surface_mesh>
   // Called during the processing phase for each edge selected.
   // If cost is absent the edge won't be collapsed.
   void OnSelected(const Profile&,
-                  boost::optional<double> cost,
+                  std::optional<double> cost,
                   std::size_t initial,
                   std::size_t current)
   {
@@ -69,7 +69,7 @@ struct My_visitor : SMS::Edge_collapse_visitor_base<Surface_mesh>
   // Called during the processing phase for each edge being collapsed.
   // If placement is absent the edge is left uncollapsed.
   void OnCollapsing(const Profile&,
-                    boost::optional<Point> placement)
+                    std::optional<Point> placement)
   {
     if(!placement)
       ++(stats->placement_uncomputable);
