@@ -2,7 +2,7 @@
 #include <CGAL/Linear_cell_complex_for_combinatorial_map.h>
 
 #include <CGAL/boost/graph/graph_traits_Linear_cell_complex_for_combinatorial_map.h>
-#include <CGAL/boost/graph/IO/polygon_mesh_io.h>
+#include <CGAL/IO/polygon_mesh_io.h>
 #include <CGAL/Mean_curvature_flow_skeletonization.h>
 
 #include <fstream>
