@@ -1,3 +1,5 @@
+#include <CGAL/Installation/internal/disable_deprecation_warnings_and_errors.h>
+
 #include <CGAL/Surface_mesh_default_triangulation_3.h>
 #include <CGAL/Surface_mesh_default_criteria_3.h>
 #include <CGAL/Complex_2_in_triangulation_3.h>
@@ -22,7 +24,7 @@ int main() {
   C2t3 c2t3 (tr);   // 2D-complex in 3D-Delaunay triangulation
 
   // the 'function' is a 3D gray level image
-  Gray_level_image image("data/skull_2.9.inr", 2.9f);
+  Gray_level_image image(CGAL::data_file_path("images/skull_2.9.inr"), 2.9f);
 
   // Carefully chosen bounding sphere: the center must be inside the
   // surface defined by 'image' and the radius must be high enough so that
