@@ -6,7 +6,7 @@
 typedef CGAL::Exact_predicates_inexact_constructions_kernel K;
 
 typedef CGAL::Triangulation_vertex_base_2<K> Vb;
-typedef CGAL::Triangulation_face_base_with_info_2<CGAL::Color,K> Fb;
+typedef CGAL::Triangulation_face_base_with_info_2<CGAL::IO::Color,K> Fb;
 typedef CGAL::Triangulation_data_structure_2<Vb,Fb> Tds;
 typedef CGAL::Triangulation_2<K,Tds> Triangulation;
 
@@ -21,11 +21,11 @@ int main() {
   t.insert(Point(2,2));
 
   for(Face_handle f : t.finite_face_handles())
-    f->info() = CGAL::blue();
+    f->info() = CGAL::IO::blue();
 
   Point p(0.5,0.5);
   Face_handle fh = t.locate(p);
-  fh->info() = CGAL::red();
+  fh->info() = CGAL::IO::red();
 
   return 0;
 }
