@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Surface_mesher/include/CGAL/AABB_polyhedral_oracle.h $
-// $Id: AABB_polyhedral_oracle.h 1faa0e2 2021-04-28T10:55:26+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesher/include/CGAL/AABB_polyhedral_oracle.h $
+// $Id: include/CGAL/AABB_polyhedral_oracle.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,13 +16,17 @@
 
 #include <CGAL/license/Surface_mesher.h>
 
+#define CGAL_DEPRECATED_HEADER "<CGAL/AABB_polyhedral_oracle.h>"
+#define CGAL_DEPRECATED_MESSAGE_DETAILS \
+  "The 3D Mesh Generation package (see https://doc.cgal.org/latest/Mesh_3/) should be used instead."
+#include <CGAL/Installation/internal/deprecation_warning.h>
 
 #include <utility>
 #include <CGAL/iterator.h>
 
 #include <CGAL/point_generators_3.h>
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_face_graph_triangle_primitive.h>
 
 #include <memory>
@@ -46,7 +50,7 @@ namespace CGAL {
 
     // AABB tree
     typedef AABB_face_graph_triangle_primitive<Polyhedron> AABB_primitive;
-    typedef class AABB_traits<Kernel,AABB_primitive> AABB_traits;
+    typedef class AABB_traits_3<Kernel,AABB_primitive> AABB_traits;
     typedef AABB_tree<AABB_traits> Tree;
     typedef typename AABB_traits::Bounding_box Bounding_box;
 
@@ -84,7 +88,7 @@ namespace CGAL {
 
       Object operator()(const Surface_3& surface, const Segment_3& segment) const
       {
-        boost::optional< typename AABB_traits::template Intersection_and_primitive_id<Segment_3>::Type >
+        std::optional< typename AABB_traits::template Intersection_and_primitive_id<Segment_3>::Type >
           intersection = surface.tree()->any_intersection(segment);
 
         if ( intersection )
@@ -95,7 +99,7 @@ namespace CGAL {
 
       Object operator()(const Surface_3& surface, const Line_3& line) const
       {
-        boost::optional< typename AABB_traits::template Intersection_and_primitive_id<Line_3>::Type >
+        std::optional< typename AABB_traits::template Intersection_and_primitive_id<Line_3>::Type >
           intersection = surface.tree()->any_intersection(line);
 
         if ( intersection )
@@ -105,7 +109,7 @@ namespace CGAL {
       }
       Object operator()(const Surface_3& surface, const Ray_3& ray) const
       {
-        boost::optional< typename AABB_traits::template Intersection_and_primitive_id<Ray_3>::Type >
+        std::optional< typename AABB_traits::template Intersection_and_primitive_id<Ray_3>::Type >
           intersection = surface.tree()->any_intersection(ray);
 
         if ( intersection )
