@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/AABB_tree/include/CGAL/AABB_triangulation_3_triangle_primitive.h $
-// $Id: AABB_triangulation_3_triangle_primitive.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/AABB_tree/include/CGAL/AABB_triangulation_3_triangle_primitive.h $
+// $Id: include/CGAL/AABB_triangulation_3_triangle_primitive.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,8 +18,7 @@
 
 #include <CGAL/disable_warnings.h>
 
-#include <boost/utility/enable_if.hpp>
-#include <boost/type_traits/is_same.hpp>
+#include <type_traits>
 
 namespace CGAL {
     // \ingroup PkgAABBTreeRef
@@ -29,7 +28,7 @@ namespace CGAL {
     // the TriangleMesh from which the AABB tree is built should not be
     // deleted while the AABB tree is in use.
     //
-    // \cgalModels `AABBPrimitive`
+    // \cgalModels{AABBPrimitive}
     // \tparam GeomTraits must provides a \c %Point_3
     // type, used as \c Point, and a \c %Triangle_3 type, used as \c
     // Datum and constructible from three arguments of type \c
@@ -68,9 +67,9 @@ namespace CGAL {
             : m_facet(*ptr)  { }
         template <class Iterator>
         AABB_triangulation_3_triangle_primitive( Iterator it,
-                                            typename boost::enable_if<
-                                                       boost::is_same<Id,typename Iterator::value_type>
-                                            >::type* =0
+                                            std::enable_if_t<
+                                                std::is_same<Id,typename Iterator::value_type>::value
+                                            >* =0
         ) : m_facet(*it)  { }
 
 
