@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h $
-// $Id: Algebraic_curve_kernel_2.h 1faa0e2 2021-04-28T10:55:26+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h $
+// $Id: include/CGAL/Algebraic_kernel_d/Algebraic_curve_kernel_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,10 +24,10 @@
 #define CGAL_ALGEBRAIC_CURVE_KERNEL_D_2_H
 
 #include <limits>
+#include <type_traits>
 #include <CGAL/iterator.h>
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
-#include <boost/optional.hpp>
+#include <optional>
 
 #include <CGAL/basic.h>
 #include <CGAL/config.h>
@@ -73,7 +73,7 @@ namespace CGAL {
  * in turn required by the \c CurvedKernelViaAnalysis_2 concept
  * (see the documentation of the corresponding package). Therefore,
  * some types and methods of the class have both an "algebraic" name
- * (demanded by \c CurveKernelWithAnalysis_d_2) and an "non-algebraic name
+ * (demanded by \c CurveKernelWithAnalysis_d_2) and a "non-algebraic" name
  * (demanded by \c CurveKernel_2).
  *
  * \b Algebraic_curve_kernel_2 is a template class, and needs a model
@@ -356,10 +356,10 @@ public:
                      const OuterFunctor& outer)
          : _inner(inner), _outer(outer) {}
 
-       Unary_compose(const Unary_compose& other)
-         : _inner(other._inner), _outer(other._outer) {}
+       Unary_compose(const Unary_compose& other) = default;
+       Unary_compose& operator=(const Unary_compose& other) = default;
 
-         Unary_compose() : _inner(::boost::none),_outer(::boost::none) {}
+       Unary_compose() : _inner(::std::nullopt),_outer(::std::nullopt) {}
 
        typedef typename InnerFunctor::argument_type argument_type;
        typedef typename OuterFunctor::result_type result_type;
@@ -368,11 +368,11 @@ public:
        result_type operator() (const argument_type& arg) const {
          CGAL_assertion(bool(_inner));
          CGAL_assertion(bool(_outer));
-         return _outer.get()(_inner.get()(arg));
+         return _outer.value()(_inner.value()(arg));
        }
     private:
-       ::boost::optional<InnerFunctor> _inner;
-       ::boost::optional<OuterFunctor> _outer;
+       ::std::optional<InnerFunctor> _inner;
+       ::std::optional<OuterFunctor> _outer;
     };
 
     template<typename InnerFunctor,typename OuterFunctor>
@@ -481,18 +481,18 @@ public:
       Curve_analysis_2 _construct_defining_polynomial_from(Bound b) const {
         typedef CGAL::Fraction_traits<Bound> FT;
         // We rely on the fact that the Bound is a fraction
-        CGAL_static_assertion((::boost::is_same<typename FT::Is_fraction,
-                                             CGAL::Tag_true>::value));
+        static_assert(::std::is_same<typename FT::Is_fraction,
+                                             CGAL::Tag_true>::value);
         typedef typename FT::Numerator_type Numerator;
         typedef typename FT::Denominator_type Denominator;
         typedef CGAL::Coercion_traits<Numerator,Coefficient> Num_coercion;
-        CGAL_static_assertion((::boost::is_same
+        static_assert(::std::is_same
                               <Coefficient,
-                                  typename Num_coercion::Type>::value));
+                                  typename Num_coercion::Type>::value);
         typedef CGAL::Coercion_traits<Denominator,Coefficient> Denom_coercion;
-        CGAL_static_assertion((::boost::is_same
+        static_assert(::std::is_same
                                <Coefficient,
-                                typename Denom_coercion::Type>::value));
+                                typename Denom_coercion::Type>::value);
         typename Num_coercion::Cast num_cast;
         typename Denom_coercion::Cast denom_cast;
         typename FT::Decompose decompose;
@@ -840,7 +840,7 @@ public:
         } else {
           // more work! We should not assume that each
           // roots[i].first has f or g as defining polynomial, because
-          // the representation might have been simplifed
+          // the representation might have been simplified
 
           // Here's the safe way: Take the simpler of the curves
           // (but the one without vertical component!)
@@ -922,7 +922,7 @@ public:
      *
      * \attention{This method returns the y-coordinate in isolating interval
      * representation. Calculating such a representation is usually a time-
-     * consuming taks, since it is against the "y-per-x"-view that we take
+     * consuming task, since it is against the "y-per-x"-view that we take
      * in our kernel. Therefore, it is recommended, if possible,
      *  to use the functors
      * \c Approximate_absolute_y_2 and \c Approximate_relative_y_2 that
@@ -1811,7 +1811,7 @@ public:
      * An x-critical point (x,y) of \c f (or its induced curve)
      * satisfies f(x,y) = f_y(x,y) = 0,
      * where f_y means the derivative w.r.t. y.
-     * In pariticular, each singular point is x-critical.
+     * In particular, each singular point is x-critical.
      */
     class X_critical_points_2 :
         public CGAL::cpp98::binary_function< Curve_analysis_2,
@@ -1890,7 +1890,7 @@ public:
      * An y-critical point (x,y) of \c f (or its induced curve)
      * satisfies f(x,y) = f_x(x,y) = 0,
      * where f_x means the derivative w.r.t. x.
-     * In pariticular, each singular point is y-critical.
+     * In particular, each singular point is y-critical.
      */
     class Y_critical_points_2 :
         public CGAL::cpp98::binary_function< Curve_analysis_2,
@@ -2541,18 +2541,18 @@ public:
       Polynomial_1 operator() (const Polynomial_2& f, Bound b) const {
         typedef CGAL::Fraction_traits<Bound> FT;
         // We rely on the fact that the Bound is a fraction
-        CGAL_static_assertion((::boost::is_same<typename FT::Is_fraction,
-                                             CGAL::Tag_true>::value));
+        static_assert(::std::is_same<typename FT::Is_fraction,
+                                             CGAL::Tag_true>::value);
         typedef typename FT::Numerator_type Numerator;
         typedef typename FT::Denominator_type Denominator;
         typedef CGAL::Coercion_traits<Numerator,Coefficient> Num_coercion;
-        CGAL_static_assertion((::boost::is_same
+        static_assert(::std::is_same
                               <Coefficient,
-                                  typename Num_coercion::Type>::value));
+                                  typename Num_coercion::Type>::value);
         typedef CGAL::Coercion_traits<Denominator,Coefficient> Denom_coercion;
-        CGAL_static_assertion((::boost::is_same
+        static_assert(::std::is_same
                                <Coefficient,
-                                typename Denom_coercion::Type>::value));
+                                typename Denom_coercion::Type>::value);
         typename Num_coercion::Cast num_cast;
         typename Denom_coercion::Cast denom_cast;
         typename FT::Decompose decompose;
