@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_circular_arc_traits_2.h $
-// $Id: Arr_circular_arc_traits_2.h 1b23ac2 2020-07-02T19:10:00+03:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_circular_arc_traits_2.h $
+// $Id: include/CGAL/Arr_circular_arc_traits_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion
@@ -178,17 +178,17 @@ public:
     template <typename OutputIterator>
     OutputIterator operator()(const Curve_2& arc, OutputIterator oi) const
     {
-      typedef boost::variant<Point_2, X_monotone_curve_2>
+      typedef std::variant<Point_2, X_monotone_curve_2>
         Make_x_monotone_result;
 
-      std::vector<CGAL::Object> objs;
+      std::vector<Make_x_monotone_result> objs;
       CircularKernel().make_x_monotone_2_object()(arc, std::back_inserter(objs));
       for (const auto& obj : objs) {
-        if (const auto* p = CGAL::object_cast<Point_2>(&obj)) {
+        if (const auto* p = std::get_if<Point_2>(&obj)) {
           *oi++ = Make_x_monotone_result(*p);
           continue;
         }
-        if (const auto* xcv = CGAL::object_cast<X_monotone_curve_2>(&obj)) {
+        if (const auto* xcv = std::get_if<X_monotone_curve_2>(&obj)) {
           *oi++ = Make_x_monotone_result(*xcv);
           continue;
         }
