@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_active_edge.h $
-// $Id: Td_active_edge.h 97cac65 2021-07-23T10:59:49+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_active_edge.h $
+// $Id: include/CGAL/Arr_point_location/Td_active_edge.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)         : Oren Nechushtan <theoren@math.tau.ac.il>
@@ -17,11 +17,11 @@
 
 
 /*! \file
- * Defintion of the Td_active_edge<Td_traits> class.
+ * Definition of the Td_active_edge<Td_traits> class.
  */
 
 #include <CGAL/Arr_point_location/Trapezoidal_decomposition_2.h>
-#include <boost/variant.hpp>
+#include <variant>
 #include <memory>
 
 
@@ -44,7 +44,7 @@ namespace CGAL {
  * when one of the four sides is on the parameter space boundary.
  * Trapezoids are created as active and become inactive when Remove() member
  * function called.
- * Each trapezoid has at most four neighbouring trapezoids.
+ * Each trapezoid has at most four neighboring trapezoids.
  * X_trapezoid structure can represent a real trapezoid, a Td-edge or an
  * edge-end (end point).
  */
@@ -144,11 +144,15 @@ public:
 
   //Dag_node* m_dag_node; //pointer to the search structure (DAG) node
 
-  /*! Initialize the trapezoid's neighbours. */
-  inline void init_neighbours(boost::optional<Td_map_item&> next)
+  /*! Initialize the trapezoid's neighbors. */
+  inline void init_neighbors(std::optional<std::reference_wrapper<Td_map_item>> next)
   {
-    set_next((next) ? *next : Td_map_item(0));
+    set_next((next) ? next->get() : Td_map_item(0));
   }
+  /*! \copydoc init_neighbors
+   *  \deprecated please use #init_neighbors */
+  CGAL_DEPRECATED inline void init_neighbours(std::optional<std::reference_wrapper<Td_map_item>> next)
+  { init_neighbors(next); }
 
   /*! Set the DAG node. */
   CGAL_TD_INLINE void set_dag_node(Dag_node* p)
@@ -195,10 +199,10 @@ public:
    /*! Constructor given Vertex & Halfedge handles. */
   Td_active_edge (Halfedge_const_handle he ,
                   Dag_node* node = 0,
-                  boost::optional<Td_map_item&> next = boost::none)
+                  std::optional<std::reference_wrapper<Td_map_item>> next = std::nullopt)
   {
 
-    PTR = new Data(he, (next) ? *next : Td_map_item(0), node);
+    PTR = new Data(he, (next) ? next->get() : Td_map_item(0), node);
     //m_dag_node = node;
   }
 
