@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_active_trapezoid.h $
-// $Id: Td_active_trapezoid.h 9c2f8ff 2023-01-13T18:51:28+01:00 albert-github
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Arr_point_location/Td_active_trapezoid.h $
+// $Id: include/CGAL/Arr_point_location/Td_active_trapezoid.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)         : Oren Nechushtan <theoren@math.tau.ac.il>
@@ -23,8 +23,8 @@
 #include <CGAL/Arr_point_location/Trapezoidal_decomposition_2.h>
 #include <CGAL/tuple.h>
 
-#include <boost/variant.hpp>
-#include <boost/optional.hpp>
+#include <variant>
+#include <optional>
 
 
 #ifdef CGAL_TD_DEBUG
@@ -163,18 +163,18 @@ private:
   //Dag_node* m_dag_node; //pointer to the search structure (DAG) node
 
   /*! Initialize the trapezoid's neighbors. */
-   inline void init_neighbors(boost::optional<Td_map_item&> lb, boost::optional<Td_map_item&> lt,
-                              boost::optional<Td_map_item&> rb, boost::optional<Td_map_item&> rt)
+   inline void init_neighbors(std::optional<std::reference_wrapper<Td_map_item>> lb, std::optional<std::reference_wrapper<Td_map_item>> lt,
+                              std::optional<std::reference_wrapper<Td_map_item>> rb, std::optional<std::reference_wrapper<Td_map_item>> rt)
   {
-    set_lb((lb) ? *lb : Td_map_item(0));
-    set_lt((lt) ? *lt : Td_map_item(0));
-    set_rb((rb) ? *rb : Td_map_item(0));
-    set_rt((rt) ? *rt : Td_map_item(0));
+    set_lb((lb) ? lb->get() : Td_map_item(0));
+    set_lt((lt) ? lt->get() : Td_map_item(0));
+    set_rb((rb) ? rb->get() : Td_map_item(0));
+    set_rt((rt) ? rt->get() : Td_map_item(0));
   }
   /*! \copydoc init_neighbors
    *  \deprecated please use #init_neighbors */
-   CGAL_DEPRECATED inline void init_neighbours(boost::optional<Td_map_item&> lb, boost::optional<Td_map_item&> lt,
-                                               boost::optional<Td_map_item&> rb, boost::optional<Td_map_item&> rt)
+   CGAL_DEPRECATED inline void init_neighbours(std::optional<std::reference_wrapper<Td_map_item>> lb, std::optional<std::reference_wrapper<Td_map_item>> lt,
+                                               std::optional<std::reference_wrapper<Td_map_item>> rb, std::optional<std::reference_wrapper<Td_map_item>> rt)
   { init_neighbors(lb, lt, rb, rt); }
 
   /*! Set the DAG node. */
@@ -267,14 +267,14 @@ private:
   /*! Constructor given Vertex & Halfedge handles. */
   Td_active_trapezoid (Vertex_const_handle l, Vertex_const_handle r,
                   Halfedge_const_handle b, Halfedge_const_handle t,
-                  boost::optional<Td_map_item&> lb = boost::none,
-                  boost::optional<Td_map_item&> lt = boost::none,
-                  boost::optional<Td_map_item&> rb = boost::none,
-                  boost::optional<Td_map_item&> rt = boost::none,
+                  std::optional<std::reference_wrapper<Td_map_item>> lb = std::nullopt,
+                  std::optional<std::reference_wrapper<Td_map_item>> lt = std::nullopt,
+                  std::optional<std::reference_wrapper<Td_map_item>> rb = std::nullopt,
+                  std::optional<std::reference_wrapper<Td_map_item>> rt = std::nullopt,
                   Dag_node* node = 0)
   {
-    PTR = new Data (l, r, b, t, (lb) ? *lb : Td_map_item(0), (lt) ? *lt : Td_map_item(0),
-                   (rb) ? *rb : Td_map_item(0), (rt) ? *rt : Td_map_item(0), node);
+    PTR = new Data (l, r, b, t, (lb) ? lb->get() : Td_map_item(0), (lt) ? lt->get() : Td_map_item(0),
+                   (rb) ? rb->get() : Td_map_item(0), (rt) ? rt->get() : Td_map_item(0), node);
     //m_dag_node = node;
   }
 
@@ -459,14 +459,14 @@ private:
 
     Td_map_item item (*this);
 
-    if (ptr()->rb.which() != 0)
+    if (ptr()->rb.index() != 0)
     {
-      Self tr(boost::get<Self>(rb()));
+      Self tr(std::get<Self>(rb()));
       tr.set_lb(item);
     }
-    if (ptr()->rt.which() != 0)
+    if (ptr()->rt.index() != 0)
     {
-      Self tr(boost::get<Self>(rt()));
+      Self tr(std::get<Self>(rt()));
       tr.set_lt(item);
     }
     CGAL_assertion(is_on_right_boundary() == right.is_on_right_boundary());
