@@ -21,8 +21,8 @@
  * WWW URL: https://cs.nyu.edu/exact/
  * Email: exact@cs.nyu.edu
  *
- * $URL: https://github.com/CGAL/cgal/blob/v5.6/CGAL_Core/include/CGAL/CORE/Expr.h $
- * $Id: Expr.h 0ff7882 2022-12-06T22:21:06+01:00 Mael
+ * $URL: https://github.com/CGAL/cgal/blob/v6.0.1/CGAL_Core/include/CGAL/CORE/Expr.h $
+ * $Id: include/CGAL/CORE/Expr.h 50cfbde3b84 $
  * SPDX-License-Identifier: LGPL-3.0-or-later
  ***************************************************************************/
 
@@ -72,9 +72,7 @@ public:
   Expr(float f) : RCExpr(nullptr) { // check for valid numbers
     // (i.e., not infinite and not NaN)
     if (! CGAL_CORE_finite(f)) {
-      core_error(" ERROR : constructed an invalid float! ", __FILE__, __LINE__, false);
-      if (get_static_AbortFlag())
-        abort();
+      CGAL_error_msg("ERROR : constructed an invalid float! ");
       get_static_InvalidFlag() = -1;
     }
     rep = new ConstDoubleRep(f);
@@ -83,9 +81,7 @@ public:
   Expr(double d) : RCExpr(nullptr) { // check for valid numbers
     // (i.e., not infinite and not NaN)
     if (! CGAL_CORE_finite(d)) {
-      core_error(" ERROR : constructed an invalid double! ", __FILE__, __LINE__, false);
-      if (get_static_AbortFlag())
-        abort();
+      CGAL_error_msg("ERROR : constructed an invalid double! ");
       get_static_InvalidFlag() = -2;
     }
     rep = new ConstDoubleRep(d);
@@ -95,6 +91,14 @@ public:
   Expr(const BigInt& I) : RCExpr(new ConstRealRep(Real(I))) {}
   /// constructor for <tt>BigRat</tt>
   Expr(const BigRat& R) : RCExpr(new ConstRealRep(Real(R))) {}
+  /// constructor from expression template
+  template <class TmplExpr,
+            class = std::enable_if_t<
+              boost::multiprecision::is_number_expression<TmplExpr>::value> >
+  Expr(const TmplExpr& R)
+    : RCExpr(new ConstRealRep(Real(
+        std::conditional_t<boost::multiprecision::number_category<TmplExpr>::value == boost::multiprecision::number_kind_integer,
+        BigInt, BigRat>(R)))) {}
 
   /// constructor for <tt>BigFloat</tt>
   Expr(const BigFloat& F) : RCExpr(new ConstRealRep(Real(F))) {}
@@ -173,9 +177,7 @@ public:
   /// /= operator
   Expr& operator/=(const Expr& e) {
     if ((e.rep)->getSign() == 0) {
-      core_error(" ERROR : division by zero ! ",__FILE__, __LINE__, false);
-      if (get_static_AbortFlag())
-        abort();
+      CGAL_error_msg("ERROR : division by zero ! ");
       get_static_InvalidFlag() = -3;
     }
     *this = new DivRep(rep, e.rep);
@@ -344,7 +346,11 @@ public:
 
 /// I/O Stream operator<<
 inline std::ostream& operator<<(std::ostream& o, const Expr& e) {
-  o << *(const_cast<ExprRep*>(&e.getRep()));
+  if (o.precision() > 17) {
+    o << *(const_cast<ExprRep*>(&e.getRep()));
+  } else {
+    o << e.doubleValue();
+  }
   return o;
 }
 /// I/O Stream operator>>
@@ -376,9 +382,7 @@ inline Expr operator*(const Expr& e1, const Expr& e2) {
 /// division
 inline Expr operator/(const Expr& e1, const Expr& e2) {
   if (e2.sign() == 0) {
-    core_error(" ERROR : division by zero ! ", __FILE__, __LINE__, false);
-    if (get_static_AbortFlag())
-      abort();
+    CGAL_error_msg("ERROR : division by zero ! ");
     get_static_InvalidFlag() = -4;
   }
   return Expr(new DivRep(e1.Rep(), e2.Rep()));
@@ -479,9 +483,7 @@ inline bool isDivisible(const Expr& e1, const Expr& e2) {
 /// square root
 inline Expr sqrt(const Expr& e) {
   if (e.sign() < 0) {
-    core_error(" ERROR : sqrt of negative value ! ", __FILE__, __LINE__, false);
-    if (get_static_AbortFlag())
-      abort();
+    CGAL_error_msg("ERROR : sqrt of negative value ! ");
     get_static_InvalidFlag() = -5;
   }
   return Expr(new SqrtRep(e.Rep()));
