@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Combinatorial_map/include/CGAL/Cell_iterators.h $
-// $Id: Cell_iterators.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Combinatorial_map/include/CGAL/Cell_iterators.h $
+// $Id: include/CGAL/Cell_iterators.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -15,7 +15,7 @@
 #include <CGAL/Dart_iterators.h>
 #include <CGAL/Combinatorial_map_basic_operations.h>
 
-#include <boost/type_traits/is_same.hpp>
+#include <type_traits>
 
 // TODO do all the orbit iterator of any orbit ?
 
@@ -47,7 +47,7 @@ namespace CGAL {
     typedef CMap_cell_iterator<Map_,Ite,i,dim,Const,Tag_true> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
   protected:
@@ -78,12 +78,12 @@ namespace CGAL {
 
   public:
     /// Main constructor.
-    CMap_cell_iterator(Map& amap, Dart_handle adart):
+    CMap_cell_iterator(Map& amap, Dart_descriptor adart):
       Ite(amap, adart, amap.get_new_mark()),
       mcell_mark_number(amap.get_new_mark())
     {
-      CGAL_static_assertion( (boost::is_same<typename Ite::Basic_iterator,
-                              Tag_true>::value) );
+      static_assert(std::is_same<typename Ite::Basic_iterator,
+                              Tag_true>::value);
       CGAL_assertion(amap.is_whole_map_unmarked(mcell_mark_number));
 
       mark_cell<Map,i,dim>(amap, adart, mcell_mark_number);
@@ -168,7 +168,7 @@ namespace CGAL {
     typedef CMap_cell_iterator<Map_,Ite,i,dim,Const,Tag_false> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
   protected:
@@ -192,12 +192,12 @@ namespace CGAL {
 
   public:
     /// Main constructor.
-    CMap_cell_iterator(Map& amap, Dart_handle adart):
+    CMap_cell_iterator(Map& amap, Dart_descriptor adart):
       Ite(amap, adart),
       mmark_number(amap.get_new_mark())
     {
-      CGAL_static_assertion( (boost::is_same<typename Ite::Basic_iterator,
-                              Tag_true>::value) );
+      static_assert(std::is_same<typename Ite::Basic_iterator,
+                              Tag_true>::value);
       CGAL_assertion(amap.is_whole_map_unmarked(mmark_number));
       mark_cell<Map,i,dim>(amap, adart, mmark_number);
     }
@@ -275,7 +275,7 @@ namespace CGAL {
     typedef CMap_dart_iterator_basic_of_all<Map_,Const> Base;
     typedef CMap_cell_iterator<Map_,Base,i,dim,Const,Tag_false> Self;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
   protected:
@@ -303,18 +303,18 @@ namespace CGAL {
       Base(amap),
       mmark_number(amap.get_new_mark())
     {
-      CGAL_static_assertion( (boost::is_same<typename Base::Basic_iterator,
-                              Tag_true>::value) );
+      static_assert(std::is_same<typename Base::Basic_iterator,
+                              Tag_true>::value);
       CGAL_assertion(amap.is_whole_map_unmarked(mmark_number));
       mark_cell<Map,i,dim>(amap, (*this), mmark_number);
     }
 
    /// Constructor with a dart in parameter (for end iterator).
-    CMap_cell_iterator(Map& amap, Dart_handle adart):
+    CMap_cell_iterator(Map& amap, Dart_descriptor adart):
       Base(amap, adart),
       mmark_number(amap.get_new_mark())
     {
-      if (adart!=this->mmap->null_handle)
+      if (adart!=this->mmap->null_descriptor)
         mark_cell<Map,i,dim>(amap, (*this), mmark_number);
     }
 
@@ -395,14 +395,14 @@ namespace CGAL {
                                                                 dim,Const>,
                                i,dim,Const> Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_false Use_mark;
     typedef Tag_false Basic_iterator;
 
     /// Main constructor.
-    CMap_one_dart_per_incident_cell_iterator(Map& amap, Dart_handle adart):
+    CMap_one_dart_per_incident_cell_iterator(Map& amap, Dart_descriptor adart):
       Base(amap, adart)
     {}
   };
@@ -422,7 +422,7 @@ namespace CGAL {
                                CMap_dart_iterator_basic_of_all<Map_,Const>,
                                i,dim,Const> Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_false Use_mark;
@@ -432,7 +432,7 @@ namespace CGAL {
     CMap_one_dart_per_cell_iterator(Map& amap): Base(amap)
     {}
     /// Constructor with a dart in parameter (for end iterator).
-    CMap_one_dart_per_cell_iterator(Map& amap, Dart_handle adart):
+    CMap_one_dart_per_cell_iterator(Map& amap, Dart_descriptor adart):
              Base(amap, adart)
     {}
   };
