@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.2.1/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
-// $Id: internal_functions_on_sphere_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Circular_kernel_3/include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h $
+// $Id: include/CGAL/Circular_kernel_3/internal_functions_on_sphere_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado
@@ -202,17 +202,10 @@ namespace CGAL {
    namespace internal {
      // we need to pass the result_type, to hack around the fact that
      // object doesn't support operator=(const T&) and so we keep backwards compatibility
-     template<typename SK, typename RT>
-     struct pair_transform {
-       RT operator()(const std::pair< typename SK::Root_for_spheres_2_3, unsigned >& p) {
-         return RT(std::make_pair(typename SK::Circular_arc_point_3(p.first), p.second));
-       }
-     };
-
      template<typename SK>
-     struct pair_transform<SK, CGAL::Object> {
-       CGAL::Object operator()(const std::pair< typename SK::Root_for_spheres_2_3, unsigned >& p) {
-         return CGAL::make_object(std::make_pair(typename SK::Circular_arc_point_3(p.first), p.second));
+     struct pair_transform {
+       auto operator()(const std::pair< typename SK::Root_for_spheres_2_3, unsigned >& p) {
+         return std::make_pair(typename SK::Circular_arc_point_3(p.first), p.second);
        }
      };
 
@@ -222,15 +215,15 @@ namespace CGAL {
    // pair, otherwise just dump the value with conversion to RT
    // (again: converting to RT before assigning to the Iterator is
    // just to keep object working)
-   template<typename SK, typename RT, typename OutputIterator>
-   struct Point_conversion_visitor : public boost::static_visitor<OutputIterator> {
+   template<typename SK, typename OutputIterator>
+   struct Point_conversion_visitor {
      Point_conversion_visitor(const OutputIterator& it) : it(it) {}
      template<typename T>
-     OutputIterator operator()(const T& t) { *it++ = RT(t); return it; }
+     OutputIterator operator()(const T& t) { *it++ = t; return it; }
 
      OutputIterator operator()(const typename SK::Point_3& p) {
        // 2 multiplicities
-       *it++ = RT(std::make_pair(typename SK::Circular_arc_point_3(p), 2u));
+       *it++ = std::make_pair(typename SK::Circular_arc_point_3(p), 2u);
        return it;
      }
      OutputIterator it;
@@ -244,8 +237,6 @@ namespace CGAL {
                 const typename SK::Line_3 & l,
                 OutputIterator res)
     {
-      typedef typename SK3_Intersection_traits<SK, typename SK::Sphere_3, typename SK::Line_3>
-        ::type result_type;
       typedef typename SK::Algebraic_kernel                          Algebraic_kernel;
       typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere;
       typedef typename SK::Polynomials_for_line_3      Equation_line;
@@ -259,7 +250,7 @@ namespace CGAL {
       solutions_container solutions;
       Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
 
-      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     // The special 3 object functions
@@ -278,20 +269,20 @@ namespace CGAL {
        typedef typename SK::Point_3  Point_3;
        typedef typename SK::Sphere_3  Sphere_3;
        typedef typename SK::Algebraic_kernel  Algebraic_kernel;
-       typedef typename SK3_Intersection_traits<SK, Sphere_3, Sphere_3, Sphere_3>::type result_type;
+       typedef typename SK::Boolean Bool;
 
        CGAL_kernel_precondition(!s1.is_degenerate());
        CGAL_kernel_precondition(!s2.is_degenerate());
        CGAL_kernel_precondition(!s3.is_degenerate());
        if(non_oriented_equal<SK>(s1,s2) && non_oriented_equal<SK>(s2,s3)) {
-         *res++ = result_type(s1);
+         *res++ = s1;
          return res;
        }
        if(non_oriented_equal<SK>(s1,s2)) {
          if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(s1, s3)) {
-           internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
-           return boost::apply_visitor(visitor,
+           internal::Point_conversion_visitor<SK, OutputIterator> visitor(res);
+           return std::visit(visitor,
              *v);
          }
          return res;
@@ -299,8 +290,8 @@ namespace CGAL {
        if(non_oriented_equal<SK>(s1,s3) || non_oriented_equal<SK>(s2,s3)) {
          if(typename Intersection_traits<SK, Sphere_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(s1, s2)) {
-           internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
-           return boost::apply_visitor(
+           internal::Point_conversion_visitor<SK, OutputIterator> visitor(res);
+           return std::visit(
              visitor,
              *v);
          }
@@ -312,13 +303,13 @@ namespace CGAL {
          if(!v) return res;
          if(const Point_3* p = CGAL::Intersections::internal::intersect_get<Point_3>(v)) {
             if(SK().has_on_3_object()(s3, *p)) {
-              *res++ = result_type(std::make_pair(Circular_arc_point_3(*p),2u));
+              *res++ = std::make_pair(Circular_arc_point_3(*p),2u);
             }
              return res;
          }
          if(const Circle_3* c = CGAL::Intersections::internal::intersect_get<Circle_3>(v)) {
-            if(SK().has_on_3_object()(s3, *c)) {
-              *res++ = result_type(*c);
+            if(static_cast<Bool>(SK().has_on_3_object()(s3, *c))) {
+              *res++ = *c;
             }
            return res;
          }
@@ -332,7 +323,7 @@ namespace CGAL {
        algebraic_solutions_container solutions;
        Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
 
-       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+       return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     template < class SK, class OutputIterator >
@@ -342,8 +333,6 @@ namespace CGAL {
                 const typename SK::Sphere_3 & s2,
                 OutputIterator res)
     {
-      typedef typename boost::variant< std::pair< typename SK::Circular_arc_point_3, unsigned int>,
-                                       typename SK::Circle_3 > result_type;
       typedef typename SK::Root_for_spheres_2_3  Root_for_spheres_2_3;
       typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere;
       typedef typename SK::Polynomial_1_3  Equation_plane;
@@ -356,8 +345,8 @@ namespace CGAL {
       if(non_oriented_equal<SK>(s1,s2)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p, s1)) {
-           internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
-           return boost::apply_visitor(
+           internal::Point_conversion_visitor<SK, OutputIterator> visitor(res);
+           return std::visit(
              visitor,
              *v);
          }
@@ -367,8 +356,8 @@ namespace CGAL {
       if(non_oriented_equal<SK>(p,radical_p)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p, s1)) {
-           internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
-           return boost::apply_visitor(
+           internal::Point_conversion_visitor<SK, OutputIterator> visitor(res);
+           return std::visit(
              visitor,
              *v);
          }
@@ -381,7 +370,7 @@ namespace CGAL {
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
       Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
-      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     template < class SK, class OutputIterator >
@@ -391,8 +380,6 @@ namespace CGAL {
                 const typename SK::Sphere_3 & s,
                 OutputIterator res)
     {
-      typedef typename boost::variant< std::pair< typename SK::Circular_arc_point_3, unsigned int>,
-                                       typename SK::Circle_3 > result_type;
       typedef typename SK::Root_for_spheres_2_3  Root_for_spheres_2_3;
       typedef typename SK::Polynomial_for_spheres_2_3  Equation_sphere;
       typedef typename SK::Polynomial_1_3  Equation_plane;
@@ -405,8 +392,8 @@ namespace CGAL {
       if(non_oriented_equal<SK>(p1,p2)) {
         if(typename Intersection_traits<SK, Plane_3, Sphere_3>::result_type v =
             SK().intersect_3_object()(p1, s)) {
-           internal::Point_conversion_visitor<SK, result_type, OutputIterator> visitor(res);
-           return boost::apply_visitor(
+           internal::Point_conversion_visitor<SK, OutputIterator> visitor(res);
+           return std::visit(
              visitor,
              *v);
          }
@@ -419,7 +406,7 @@ namespace CGAL {
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
       Algebraic_kernel().solve_object()(e1, e2, e3, std::back_inserter(solutions));
-      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     template < class SK, class OutputIterator >
@@ -449,13 +436,9 @@ namespace CGAL {
       typedef typename SK::Root_for_spheres_2_3     Root_for_spheres_2_3;
       typedef typename SK::Polynomials_for_circle_3 Equation_circle;
       typedef typename SK::Algebraic_kernel         Algebraic_kernel;
-      typedef typename SK::Circle_3                 Circle_3;
-
-      typedef typename SK3_Intersection_traits<SK, Circle_3, Circle_3>
-        ::type result_type;
 
       if(non_oriented_equal<SK>(c1,c2)) {
-         *res++ = CGAL::internal::sk3_intersection_return<result_type>(c1);
+         *res++ = c1;
          return res;
       }
       Equation_circle e1 = get_equation<SK>(c1);
@@ -464,7 +447,7 @@ namespace CGAL {
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
       Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
-      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     template < class SK, class OutputIterator >
@@ -476,10 +459,6 @@ namespace CGAL {
       typedef typename SK::Root_for_spheres_2_3     Root_for_spheres_2_3;
       typedef typename SK::Polynomials_for_circle_3 Equation_circle;
       typedef typename SK::Polynomials_for_line_3   Equation_line;
-      typedef typename SK::Circle_3                 Circle_3;
-
-      typedef typename SK3_Intersection_traits<SK, Circle_3, typename SK::Line_3>
-        ::type result_type;
 
       typedef typename SK::Algebraic_kernel  Algebraic_kernel;
       CGAL_kernel_precondition(!l.is_degenerate());
@@ -489,7 +468,7 @@ namespace CGAL {
         algebraic_solutions_container;
       algebraic_solutions_container solutions;
       Algebraic_kernel().solve_object()(e1, e2, std::back_inserter(solutions));
-      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK, result_type>());
+      return std::transform(solutions.begin(), solutions.end(), res, internal::pair_transform<SK>());
     }
 
     // At the moment we dont need those functions
