@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Classification/include/CGAL/Classification/Feature/Height_above.h $
-// $Id: Height_above.h 19004a7 2020-08-04T13:41:48+02:00 Simon Giraudot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Classification/include/CGAL/Classification/Feature/Height_above.h $
+// $Id: include/CGAL/Classification/Feature/Height_above.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Florent Lafarge, Simon Giraudot
@@ -100,7 +100,7 @@ public:
         std::size_t J = grid.y(i);
         values[i] = float(dtm(I,J) - get (point_map, *(input.begin() + i)).z());
       }
-      dtm.free();
+      (dtm.free)();
     }
 
   }
