@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Classification/include/CGAL/Classification/Feature_base.h $
-// $Id: Feature_base.h 627584f 2020-09-30T08:38:45+02:00 Simon Giraudot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Classification/include/CGAL/Classification/Feature_base.h $
+// $Id: include/CGAL/Classification/Feature_base.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
@@ -68,7 +68,7 @@ public:
 
   \brief %Handle to a `Feature_base`.
 
-  \cgalModels Handle
+  \cgalModels{Handle}
 */
 class Feature_handle { };
 #else
