@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Combinatorial_map/include/CGAL/Combinatorial_map_iterators_base.h $
-// $Id: Combinatorial_map_iterators_base.h 5ecd852 2021-04-26T21:37:02+01:00 Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Combinatorial_map/include/CGAL/Combinatorial_map_iterators_base.h $
+// $Id: include/CGAL/Combinatorial_map_iterators_base.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Guillaume Damiand <guillaume.damiand@liris.cnrs.fr>
@@ -15,9 +15,11 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/Compact_container.h>
+#include <CGAL/Compact_container_with_index.h>
+
 #include <queue>
-#include <boost/mpl/if.hpp>
-#include <boost/type_traits/is_same.hpp>
+
+#include <type_traits>
 
 namespace CGAL {
 
@@ -25,7 +27,7 @@ namespace CGAL {
    * Basic classes that serve as tools for definition of iterators.
    There are 3 classes:
    *  - CMap_dart_iterator<Map,Const> is the basic generic class defining
-   *    what is an interator on darts.
+   *    what is an iterator on darts.
    *  - CMap_extend_iterator<Map,Ite,Bi> to extend the given iterator by adding
    *    the involution Bi.
    *  - CMap_non_basic_iterator<Map_,Ite> to transform the basic iterator Ite
@@ -61,25 +63,28 @@ namespace CGAL {
    * Class CMap_dart_iterator is a generic iterator. All the combinatorial
    * map iterator classes inherit from this class (or one of its subclass).
    */
-  template < typename Map_,bool Const=false >
-  class CMap_dart_iterator: public boost::mpl::if_c< Const,
+  template < typename Map_,bool Const=false, typename UseIndex=typename Map_::Use_index >
+  class CMap_dart_iterator;
+
+  template < typename Map_,bool Const>
+  class CMap_dart_iterator<Map_, Const, Tag_false>: public std::conditional_t< Const,
       typename Map_::Dart_container::const_iterator,
-      typename Map_::Dart_container::iterator>::type
+      typename Map_::Dart_container::iterator>
     //public internal::CC_iterator<typename Map_::Dart_container,Const>
   {
   public:
     typedef CMap_dart_iterator<Map_,Const> Self;
 
-    typedef typename boost::mpl::if_c< Const,
+    typedef std::conditional_t< Const,
           typename Map_::Dart_container::const_iterator,
-          typename Map_::Dart_container::iterator>::type Base;
+          typename Map_::Dart_container::iterator> Base;
+    // typedef internal::CC_iterator<typename Map_::Dart_container,Const> Base;
 
-    typedef typename boost::mpl::if_c< Const,
-                                       typename Map_::Dart_const_handle,
-                                       typename Map_::Dart_handle>::type
-                                     Dart_handle;
-    typedef typename boost::mpl::if_c< Const, const Map_,
-                                       Map_>::type Map;
+    typedef std::conditional_t< Const,
+                                typename Map_::Dart_const_descriptor,
+                                typename Map_::Dart_descriptor>
+                                     Dart_descriptor;
+    typedef std::conditional_t< Const, const Map_, Map_> Map;
 
     typedef std::input_iterator_tag iterator_category;
     typedef typename Base::value_type value_type;
@@ -94,7 +99,7 @@ namespace CGAL {
 
   public:
     /// Main constructor.
-    CMap_dart_iterator(Map& amap, Dart_handle adart):
+    CMap_dart_iterator(Map& amap, Dart_descriptor adart):
       Base(adart),
       mmap(&amap),
       mfirst_dart(adart),
@@ -104,7 +109,7 @@ namespace CGAL {
     /// == operator.
     bool operator==(const Self& aiterator) const
     {
-      return ( ((*this==mmap->null_handle) && (aiterator==mmap->null_handle)) ||
+      return ( ((*this==mmap->null_descriptor) && (aiterator==mmap->null_descriptor)) ||
                (mfirst_dart == aiterator.mfirst_dart &&
                 static_cast<const Base&>(*this)==
                 static_cast<const Base&>(aiterator)) );
@@ -115,7 +120,7 @@ namespace CGAL {
     { return !operator==(aiterator); }
 
     /// Accessor to the initial dart of the iterator.
-    Dart_handle get_first_dart() const { return mfirst_dart; }
+    Dart_descriptor get_first_dart() const { return mfirst_dart; }
 
     /// Accessor to the combinatorial map.
     Map* get_combinatorial_map() const { return mmap; }
@@ -126,14 +131,14 @@ namespace CGAL {
 
     /// Test if the iterator is at its end.
     bool cont() const
-    { return static_cast<const Base&>(*this)!=mmap->null_handle; }
+    { return static_cast<const Base&>(*this)!=mmap->null_descriptor; }
 
     /// Get the previous operation used for the last ++.
     OperationState prev_operation()  const { return mprev_op; }
 
   protected:
     /// Set the current dart to a given dart
-    void set_current_dart(Dart_handle adart)
+    void set_current_dart(Dart_descriptor adart)
     { Base::operator=(adart); }
 
   private:
@@ -146,28 +151,134 @@ namespace CGAL {
 
   protected:
     /// test if adart->beta(ai) exists and is not marked for amark
-    bool is_unmarked(Dart_handle adart, unsigned int ai, size_type amark) const
+    bool is_unmarked(Dart_descriptor adart, unsigned int ai, size_type amark) const
     { return
         !mmap->is_marked(mmap->beta(adart,ai), amark);
     }
 
     /// test if adart->beta(ai)->beta(aj) exists
-    bool exist_betaij(Dart_handle adart, unsigned int ai, unsigned int aj) const
+    bool exist_betaij(Dart_descriptor adart, unsigned int ai, unsigned int aj) const
     { return !mmap->is_free(adart, ai) && !mmap->is_free(mmap->beta(adart, ai), aj); }
 
     /// test if adart->beta(ai)->beta(aj) exists and is not marked for amark
-    bool is_unmarked2(Dart_handle adart, unsigned int ai, unsigned int aj,
+    bool is_unmarked2(Dart_descriptor adart, unsigned int ai, unsigned int aj,
                       typename Map::size_type amark) const
     { return
         !mmap->is_marked(mmap->beta(adart, ai, aj), amark);
     }
+  protected:
+    /// The map containing the darts to iterate on.
+    Map* mmap;
+
+    /// The initial dart of the iterator.
+    Dart_descriptor mfirst_dart;
+
+    /// The last operation used for the ++ operator.
+    OperationState mprev_op;
+  };
+
+  template < typename Map_,bool Const >
+  class CMap_dart_iterator<Map_, Const, Tag_true>:
+      /*public std::conditional_t< Const,
+      typename Map_::Dart_container::const_iterator,
+      typename Map_::Dart_container::iterator>*/
+    public internal::CC_iterator_with_index<typename Map_::Dart_container,Const>
+  {
+  public:
+    typedef CMap_dart_iterator<Map_,Const> Self;
+
+    /*typedef std::conditional_t< Const,
+          typename Map_::Dart_container::const_iterator,
+          typename Map_::Dart_container::iterator> Base;*/
+    typedef internal::CC_iterator_with_index<typename Map_::Dart_container,Const> Base;
+
+    typedef std::conditional_t< Const,
+                                typename Map_::Dart_const_descriptor,
+                                typename Map_::Dart_descriptor>
+                                     Dart_descriptor;
+    typedef std::conditional_t< Const, const Map_, Map_> Map;
+
+    typedef std::input_iterator_tag iterator_category;
+    typedef typename Base::value_type value_type;
+    typedef typename Base::difference_type difference_type;
+    typedef typename Base::pointer pointer;
+    typedef typename Base::reference reference;
+
+    /// true iff this iterator is basic
+    typedef Tag_true Basic_iterator;
+
+  public:
+    /// Main constructor.
+    CMap_dart_iterator(Map& amap, Dart_descriptor adart):
+      Base(&amap.mdarts, adart),
+      mmap(&amap),
+      mfirst_dart(adart),
+      mprev_op(OP_NONE)
+    {}
+
+    /// == operator.
+    bool operator==(const Self& aiterator) const
+    {
+      return ((*this==mmap->null_descriptor) && (aiterator==mmap->null_descriptor)) ||
+        (mfirst_dart == aiterator.mfirst_dart &&
+         static_cast<const Base&>(*this)==
+         static_cast<const Base&>(aiterator));
+    }
+
+    /// != operator.
+    bool operator!=(const Self& aiterator) const
+    { return !operator==(aiterator); }
+
+    /// Accessor to the initial dart of the iterator.
+    Dart_descriptor get_first_dart() const { return mfirst_dart; }
+
+    /// Accessor to the combinatorial map.
+    Map* get_combinatorial_map() const { return mmap; }
+
+    /// Rewind of the iterator to its beginning.
+    void rewind()
+    { set_current_dart(mfirst_dart); mprev_op = OP_NONE; }
+
+    /// Test if the iterator is at its end.
+    bool cont() const
+    { return this->get_current()!=mmap->null_descriptor; }
+
+    /// Get the previous operation used for the last ++.
+    OperationState prev_operation()  const { return mprev_op; }
+
+  protected:
+    /// Set the current dart to a given dart
+    void set_current_dart(Dart_descriptor adart)
+    { this->set_current(adart); }
+
+  private:
+    /// operator -- in private to invalidate the base operator.
+    Self& operator--()
+    { return *this; }
+    /// operator -- in private to invalidate the base operator.
+    Self operator--(int)
+    { return *this; }
+
+  protected:
+    /// test if adart->beta(ai) exists and is not marked for amark
+    bool is_unmarked(Dart_descriptor adart, unsigned int ai, unsigned amark) const
+    { return !mmap->is_marked(mmap->beta(adart,ai), amark); }
+
+    /// test if adart->beta(ai)->beta(aj) exists
+    bool exist_betaij(Dart_descriptor adart, unsigned int ai, unsigned int aj) const
+    { return !mmap->is_free(adart, ai) && !mmap->is_free(mmap->beta(adart, ai), aj); }
+
+    /// test if adart->beta(ai)->beta(aj) exists and is not marked for amark
+    bool is_unmarked2(Dart_descriptor adart, unsigned int ai, unsigned int aj,
+                      unsigned amark) const
+    { return !mmap->is_marked(mmap->beta(adart, ai, aj), amark); }
 
   protected:
     /// The map containing the darts to iterate on.
     Map* mmap;
 
     /// The initial dart of the iterator.
-    Dart_handle mfirst_dart;
+    Dart_descriptor mfirst_dart;
 
     /// The last operation used for the ++ operator.
     OperationState mprev_op;
@@ -185,24 +296,24 @@ namespace CGAL {
     typedef CMap_extend_iterator<Map_,Ite,Bi, Ite_has_stack> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_true Use_mark;
 
     typedef typename Map::size_type size_type;
 
-    CGAL_static_assertion( (Bi<=Map::dimension &&
-                            boost::is_same<Ite_has_stack,Tag_false>::value) );
+    static_assert(Bi<=Map::dimension &&
+                            std::is_same<Ite_has_stack,Tag_false>::value);
 
   public:
     /// Main constructor.
-    CMap_extend_iterator(Map& amap, Dart_handle adart, size_type amark):
+    CMap_extend_iterator(Map& amap, Dart_descriptor adart, size_type amark):
       Base(amap, adart),
       mmark_number(amark),
       minitial_dart(adart)
     {
-      if ( minitial_dart!=amap.null_handle )
+      if ( minitial_dart!=amap.null_descriptor )
       {
         this->mmap->mark_null_dart(mmark_number);
         this->mmap->mark(minitial_dart, mmark_number);
@@ -219,7 +330,7 @@ namespace CGAL {
     {
       CGAL_assertion(mmark_number != Map::INVALID_MARK);
       Base::operator= ( Base(*this->mmap,minitial_dart) );
-      mto_treat = std::queue<Dart_handle>();
+      mto_treat = std::queue<Dart_descriptor>();
       this->mmap->mark(minitial_dart, mmark_number);
       this->mmap->mark_null_dart(mmark_number);
       if (!this->mmap->is_free(minitial_dart, Bi) &&
@@ -284,13 +395,13 @@ namespace CGAL {
 
   protected:
     /// Queue of darts to process.
-    std::queue<Dart_handle> mto_treat;
+    std::queue<Dart_descriptor> mto_treat;
 
     /// Index of the used mark.
     size_type mmark_number;
 
     /// Initial dart
-    Dart_handle minitial_dart;
+    Dart_descriptor minitial_dart;
   };
   //****************************************************************************
   /* Class CMap_extend_iterator<Map,Ite,Bi> which extend a given iterator by
@@ -304,7 +415,7 @@ namespace CGAL {
     typedef CMap_extend_iterator<Map_,Ite,Bi,Tag_true> Self;
     typedef Ite Base;
 
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
     typedef typename Base::Map Map;
 
     typedef Tag_true Use_mark;
@@ -312,10 +423,10 @@ namespace CGAL {
     typedef typename Map::size_type size_type;
 
     /// Main constructor.
-    CMap_extend_iterator(Map& amap, Dart_handle adart, size_type amark):
+    CMap_extend_iterator(Map& amap, Dart_descriptor adart, size_type amark):
       Base(amap, adart, amark)
     {
-      if ( this->minitial_dart!=amap.null_handle &&
+      if ( this->minitial_dart!=amap.null_descriptor &&
            !this->mmap->is_free(this->minitial_dart, Bi) &&
            this->mmap->beta(this->minitial_dart, Bi)!=this->minitial_dart )
       {
@@ -373,18 +484,18 @@ namespace CGAL {
     typedef Base_ Base;
 
     typedef typename Base::Map Map;
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
 
     /// True iff this iterator is basic
     typedef Tag_false Basic_iterator;
 
     typedef typename Map::size_type size_type;
 
-    CGAL_static_assertion( (boost::is_same<typename Base::Basic_iterator,
-                            Tag_true>::value) );
+    static_assert(std::is_same<typename Base::Basic_iterator,
+                            Tag_true>::value);
 
     /// Main constructor.
-    CMap_non_basic_iterator(Map& amap, Dart_handle adart1):
+    CMap_non_basic_iterator(Map& amap, Dart_descriptor adart1):
       Base(amap, adart1, amap.get_new_mark())
     {}
 
@@ -461,16 +572,16 @@ namespace CGAL {
     typedef Base_ Base;
 
     typedef typename Base::Map Map;
-    typedef typename Base::Dart_handle Dart_handle;
+    typedef typename Base::Dart_descriptor Dart_descriptor;
 
     /// True iff this iterator is basic
     typedef Tag_false Basic_iterator;
 
-    CGAL_static_assertion( (boost::is_same<typename Base::Basic_iterator,
-                            Tag_true>::value) );
+    static_assert(std::is_same<typename Base::Basic_iterator,
+                            Tag_true>::value);
 
     /// Main constructor.
-    CMap_non_basic_iterator(Map& amap, Dart_handle adart):
+    CMap_non_basic_iterator(Map& amap, Dart_descriptor adart):
       Base(amap, adart)
     {}
   };
@@ -481,13 +592,13 @@ namespace CGAL {
   {
     typedef It iterator;
     typedef Const_it const_iterator;
-    CMap_range(Map_ &amap, typename Map_::Dart_handle adart) :
+    CMap_range(Map_ &amap, typename Map_::Dart_descriptor adart) :
       mmap(amap), mdart(adart), msize(0)
     {}
     iterator begin()             { return iterator(mmap,mdart); }
-    iterator end()               { return iterator(mmap,mmap.null_handle); }
+    iterator end()               { return iterator(mmap,mmap.null_descriptor); }
     const_iterator begin() const { return const_iterator(mmap,mdart); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -499,7 +610,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     Map_ & mmap;
-    typename Map_::Dart_handle mdart;
+    typename Map_::Dart_descriptor mdart;
     mutable typename Map_::size_type msize;
   };
   //****************************************************************************
@@ -512,13 +623,13 @@ namespace CGAL {
 
     typedef typename Map_::size_type size_type;
 
-    CMap_range(Map_ &amap, typename Map_::Dart_handle adart, size_type amark=Map_::INVALID_MARK):
+    CMap_range(Map_ &amap, typename Map_::Dart_descriptor adart, size_type amark=Map_::INVALID_MARK):
       mmap(amap), mdart(adart), msize(0), mmark(amark)
     {}
     iterator begin()             { return iterator(mmap,mdart,mmark); }
-    iterator end()               { return iterator(mmap,mmap.null_handle,mmark); }
+    iterator end()               { return iterator(mmap,mmap.null_descriptor,mmark); }
     const_iterator begin() const { return const_iterator(mmap,mdart,mmark); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle,mmark); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor,mmark); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -531,7 +642,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     Map_ & mmap;
-    typename Map_::Dart_handle mdart;
+    typename Map_::Dart_descriptor mdart;
     mutable typename Map_::size_type msize;
     size_type mmark;
   };
@@ -541,11 +652,11 @@ namespace CGAL {
   struct CMap_const_range
   {
     typedef Const_it const_iterator;
-    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_handle adart):
+    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_descriptor adart):
       mmap(amap), mdart(adart), msize(0)
     {}
     const_iterator begin() const { return const_iterator(mmap,mdart); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -557,7 +668,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     const Map_ & mmap;
-    typename Map_::Dart_const_handle mdart;
+    typename Map_::Dart_const_descriptor mdart;
     mutable typename Map_::size_type msize;
   };
   //****************************************************************************
@@ -566,12 +677,12 @@ namespace CGAL {
   {
     typedef Const_it const_iterator;
     typedef typename Map_::size_type size_type;
-    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_handle adart,
+    CMap_const_range(const Map_ &amap, typename Map_::Dart_const_descriptor adart,
                      size_type amark=Map_::INVALID_MARK):
       mmap(amap), mdart(adart), msize(0), mmark(amark)
     {}
     const_iterator begin() const { return const_iterator(mmap,mdart,mmark); }
-    const_iterator end() const   { return const_iterator(mmap,mmap.null_handle,mmark); }
+    const_iterator end() const   { return const_iterator(mmap,mmap.null_descriptor,mmark); }
     typename Map_::size_type size() const
     {
       if (msize==0)
@@ -584,7 +695,7 @@ namespace CGAL {
     { return mmap.is_empty(); }
   private:
     const Map_ & mmap;
-    typename Map_::Dart_const_handle mdart;
+    typename Map_::Dart_const_descriptor mdart;
     mutable typename Map_::size_type msize;
     size_type mmark;
   };
