@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Convex_hull_2/include/CGAL/Convex_hull_2/ch_eddy_impl.h $
-// $Id: ch_eddy_impl.h c4ad713 2021-01-05T11:40:22+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_2/include/CGAL/Convex_hull_2/ch_eddy_impl.h $
+// $Id: include/CGAL/Convex_hull_2/ch_eddy_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,7 +20,7 @@
 #include <CGAL/convexity_check_2.h>
 #endif // CGAL_CH_NO_POSTCONDITIONS
 
-#include <CGAL/Convex_hull_2/ch_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/ch_selected_extreme_points_2.h>
 #include <CGAL/algorithm.h>
 #include <list>
@@ -34,27 +34,39 @@ ch__recursive_eddy(List& L,
                         ListIterator  a_it, ListIterator  b_it,
                         const Traits& ch_traits)
 {
-  using namespace boost;
+  typedef typename Traits::Point_2                            Point_2;
 
-  typedef  typename Traits::Point_2                         Point_2;
-  typedef  typename Traits::Left_turn_2                     Left_turn_2;
-  typedef  typename Traits::Less_signed_distance_to_line_2  Less_dist;
+  typedef typename Traits::Compare_signed_distance_to_line_2  Compare_dist_2;
+  typedef typename Traits::Less_xy_2                          Less_xy_2;
+  typedef typename Traits::Left_turn_2                        Left_turn_2;
 
-  Left_turn_2 left_turn    = ch_traits.left_turn_2_object();
+  Compare_dist_2 cmp_dist = ch_traits.compare_signed_distance_to_line_2_object();
+  Left_turn_2 left_turn = ch_traits.left_turn_2_object();
+  Less_xy_2 less_xy = ch_traits.less_xy_2_object();
 
-  CGAL_ch_precondition( \
+  CGAL_precondition( \
     std::find_if(a_it, b_it, \
                  [&left_turn, a_it, b_it](const Point_2& p)
                  { return left_turn(*b_it, *a_it, p); }) \
     != b_it );
 
+  const Point_2& a = *a_it;
+  const Point_2& b = *b_it;
 
   ListIterator f_it = std::next(a_it);
-  Less_dist less_dist = ch_traits.less_signed_distance_to_line_2_object();
-  ListIterator
-      c_it = std::min_element( f_it, b_it,  // max before
-                               [&less_dist, a_it, b_it](const Point_2& p1, const Point_2& p2)
-                               { return less_dist(*a_it, *b_it, p1, p2); });
+
+  // We need the farthest point, but since we are on the right side of the line,
+  // signed distances are negative. Hence std::min_element.
+  auto less_dist = [&a, &b, &cmp_dist, &less_xy](const Point_2&p1, const Point_2& p2) -> bool
+  {
+    CGAL::Comparison_result res = cmp_dist(a, b, p1, p2);
+    if(res == CGAL::EQUAL)
+      return less_xy(p1, p2);
+
+    return (res == CGAL::SMALLER);
+  };
+
+  ListIterator c_it = std::min_element( f_it, b_it, less_dist);
   Point_2 c = *c_it;
 
   c_it = std::partition(f_it, b_it, [&left_turn, &c, a_it](const Point_2& p)
@@ -80,8 +92,6 @@ ch_eddy(InputIterator first, InputIterator last,
              OutputIterator  result,
              const Traits& ch_traits)
 {
-  using namespace boost;
-
   typedef  typename Traits::Point_2                         Point_2;
   typedef  typename Traits::Left_turn_2                     Left_turn_2;
   typedef  typename Traits::Equal_2                         Equal_2;
@@ -127,9 +137,9 @@ ch_eddy(InputIterator first, InputIterator last,
   ch__recursive_eddy( L, e, w, ch_traits);
 
 
-  CGAL_ch_postcondition( \
+  CGAL_postcondition( \
       is_ccw_strongly_convex_2( L.begin(), w, ch_traits) );
-  CGAL_ch_expensive_postcondition( \
+  CGAL_expensive_postcondition( \
       ch_brute_force_check_2( first, last, \
                                    L.begin(), w, ch_traits ) );
 
