@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Convex_hull_2/include/CGAL/Convex_hull_2/ch_jarvis_impl.h $
-// $Id: ch_jarvis_impl.h 21755b1 2021-03-24T15:05:41+01:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_2/include/CGAL/Convex_hull_2/ch_jarvis_impl.h $
+// $Id: include/CGAL/Convex_hull_2/ch_jarvis_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,7 +21,7 @@
 #endif // CGAL_CH_NO_POSTCONDITIONS
 
 #include <CGAL/IO/Tee_for_output_iterator.h>
-#include <CGAL/Convex_hull_2/ch_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/ch_selected_extreme_points_2.h>
 #include <algorithm>
 
@@ -36,8 +36,6 @@ ch_jarvis_march(ForwardIterator first, ForwardIterator last,
                 OutputIterator  result,
                 const Traits& ch_traits)
 {
-  using namespace boost;
-
   if (first == last) return result;
   typedef   typename Traits::Less_rotate_ccw_2     Less_rotate_ccw;
   typedef   typename Traits::Equal_2               Equal_2;
@@ -50,16 +48,16 @@ ch_jarvis_march(ForwardIterator first, ForwardIterator last,
   typedef   typename Traits::Point_2               Point_2;
   Tee_for_output_iterator<OutputIterator,Point_2> res(result);
   #endif // no postconditions ...
-  CGAL_ch_assertion_code( \
+  CGAL_assertion_code( \
       int count_points = 0; )
-  CGAL_ch_assertion_code( \
+  CGAL_assertion_code( \
       for (ForwardIterator fit = first; fit!= last; ++fit) ++count_points; )
   Less_rotate_ccw
       rotation_predicate = ch_traits.less_rotate_ccw_2_object( );
   *res = start_p;  ++res;
-  CGAL_ch_assertion_code( \
+  CGAL_assertion_code( \
       int constructed_points = 1; )
-  CGAL_ch_exactness_assertion_code( \
+  CGAL_exactness_assertion_code( \
       Point previous_point = start_p; )
 
   ForwardIterator it = std::min_element( first, last,
@@ -67,26 +65,26 @@ ch_jarvis_march(ForwardIterator first, ForwardIterator last,
                                          {return rotation_predicate(start_p, p1, p2);} );
   while (! equal_points(*it, stop_p) )
   {
-      CGAL_ch_exactness_assertion( \
+      CGAL_exactness_assertion( \
           *it != previous_point );
-      CGAL_ch_exactness_assertion_code( \
+      CGAL_exactness_assertion_code( \
           previous_point = *it; )
 
       *res = *it;  ++res;
-      CGAL_ch_assertion_code( \
+      CGAL_assertion_code( \
           ++constructed_points;)
-      CGAL_ch_assertion( \
+      CGAL_assertion( \
           constructed_points <= count_points + 1 );
 
       it = std::min_element( first, last,
                              [it, &rotation_predicate](const Point& p1, const Point& p2)
                              {return rotation_predicate(*it, p1, p2);} );
   }
-  CGAL_ch_postcondition( \
+  CGAL_postcondition( \
       is_ccw_strongly_convex_2( res.output_so_far_begin(), \
                                      res.output_so_far_end(), \
                                      ch_traits));
-  CGAL_ch_expensive_postcondition( \
+  CGAL_expensive_postcondition( \
       ch_brute_force_check_2(
           first, last, \
           res.output_so_far_begin(), res.output_so_far_end(), \
