@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_3.h $
-// $Id: halfspace_intersection_3.h 47e728f 2023-12-22T17:14:12+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_3.h $
+// $Id: include/CGAL/Convex_hull_3/dual/halfspace_intersection_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -32,7 +32,6 @@
 #include <CGAL/Number_types/internal/Exact_type_selector.h>
 
 #include <unordered_map>
-#include <boost/type_traits/is_floating_point.hpp>
 #include <deque>
 
 namespace CGAL
@@ -69,7 +68,7 @@ namespace CGAL
               // Typedefs for intersection
               typedef typename Kernel::Plane_3 Plane_3;
               typedef typename Kernel::Line_3 Line_3;
-              typedef boost::optional< boost::variant< Point_3,
+              typedef std::optional< std::variant< Point_3,
                                                        Line_3,
                                                        Plane_3 > > result_inter;
 
@@ -99,10 +98,10 @@ namespace CGAL
                 result_inter result = CGAL::intersection(pp1, pp2, pp3);
                 CGAL_assertion_msg(bool(result),
                                    "halfspace_intersection_3: no intersection");
-                CGAL_assertion_msg(boost::get<Point_3>(& *result) != nullptr,
+                CGAL_assertion_msg(std::get_if<Point_3>(& *result) != nullptr,
                                    "halfspace_intersection_3: intersection is not a point");
 
-                const Point_3* pp = boost::get<Point_3>(& *result);
+                const Point_3* pp = std::get_if<Point_3>(& *result);
 
                 // Primal vertex associated to the current dual plane
                 Point_3 ppp(origin.x() + pp->x(),
@@ -230,9 +229,9 @@ namespace CGAL
     template <class PlaneIterator, class Polyhedron>
     void halfspace_intersection_3 (PlaneIterator begin, PlaneIterator end,
                                    Polyhedron &P,
-                                   boost::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> origin
+                                   std::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> origin
 #ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
-                                   = boost::none
+                                   = std::nullopt
 #endif
     ) {
         // Checks whether the intersection is a polyhedron
@@ -250,8 +249,8 @@ namespace CGAL
           origin = halfspace_intersection_interior_point_3(begin, end);
 #endif
 
-          CGAL_assertion_msg(origin!=boost::none, "halfspace_intersection_3: problem when determining a point inside the intersection");
-          if (origin==boost::none)
+          CGAL_assertion_msg(origin!=std::nullopt, "halfspace_intersection_3: problem when determining a point inside the intersection");
+          if (origin==std::nullopt)
             return;
         }
 
@@ -269,7 +268,7 @@ namespace CGAL
         // The check is done only if the number type is not float or double because in that
         // case we know the construction of dual points is not exact
         CGAL_assertion_msg(
-          boost::is_floating_point<typename K::FT>::value ||
+          std::is_floating_point<typename K::FT>::value ||
           Convex_hull_3::internal::point_inside_convex_polyhedron(P, *origin),
           "halfspace_intersection_3: origin not in the polyhedron"
         );
@@ -281,7 +280,7 @@ namespace CGAL
   void halfspace_intersection_3 (PlaneIterator begin, PlaneIterator end,
                                  Polyhedron &P,
                                  typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3 const& origin) {
-    halfspace_intersection_3(begin, end , P, boost::make_optional(origin));
+    halfspace_intersection_3(begin, end , P, std::make_optional(origin));
   }
   #endif
 } // namespace CGAL
