@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_with_constructions_3.h $
-// $Id: halfspace_intersection_with_constructions_3.h 4ffc949 2022-02-03T17:11:20+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_3/include/CGAL/Convex_hull_3/dual/halfspace_intersection_with_constructions_3.h $
+// $Id: include/CGAL/Convex_hull_3/dual/halfspace_intersection_with_constructions_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -23,7 +23,9 @@
 #include <CGAL/assertions.h>
 
 // For interior_polyhedron_3
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
 #include <CGAL/Convex_hull_3/dual/halfspace_intersection_interior_point_3.h>
+#endif
 #include <CGAL/Number_types/internal/Exact_type_selector.h>
 
 #include <unordered_map>
@@ -90,7 +92,7 @@ namespace CGAL
           void halfspace_intersection_with_constructions_3(PlaneIterator pbegin,
                                                            PlaneIterator pend,
                                                            Polyhedron &P,
-                                                           boost::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> origin,
+                                                           std::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> origin,
                                                            const Traits & ch_traits) {
           typedef typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel K;
           typedef typename K::Point_3 Point;
@@ -99,10 +101,12 @@ namespace CGAL
           // if a point inside is not provided find one using linear programming
           if (!origin) {
             // find a point inside the intersection
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
             origin = halfspace_intersection_interior_point_3(pbegin, pend);
+#endif
 
-            CGAL_assertion_msg(origin!=boost::none, "halfspace_intersection_with_constructions_3: problem when determing a point inside the intersection");
-            if (origin==boost::none)
+            CGAL_assertion_msg(origin!=std::nullopt, "halfspace_intersection_with_constructions_3: problem when determining a point inside the intersection");
+            if (origin==std::nullopt)
               return;
           }
 
@@ -134,7 +138,11 @@ namespace CGAL
           void halfspace_intersection_with_constructions_3 (PlaneIterator pbegin,
                                                             PlaneIterator pend,
                                                             Polyhedron &P,
-                                                            boost::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> const& origin = boost::none) {
+                                                            std::optional<typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel::Point_3> const& origin
+#ifndef CGAL_CH3_DUAL_WITHOUT_QP_SOLVER
+                                                            = std::nullopt
+#endif
+        ) {
           typedef typename Kernel_traits<typename std::iterator_traits<PlaneIterator>::value_type>::Kernel K;
           typedef typename K::Point_3 Point_3;
           typedef typename Convex_hull_3::internal::Default_traits_for_Chull_3<Point_3>::type Traits;
