@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Convex_hull_2/include/CGAL/Convex_hull_traits_adapter_2.h $
-// $Id: Convex_hull_traits_adapter_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_2/include/CGAL/Convex_hull_traits_adapter_2.h $
+// $Id: include/CGAL/Convex_hull_traits_adapter_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Sebastien Loriot
 
@@ -13,16 +13,15 @@
 #ifndef CGAL_CONVEX_HULL_TRAITS_ADAPTER_2_H
 #define CGAL_CONVEX_HULL_TRAITS_ADAPTER_2_H
 
-#include <CGAL/disable_warnings.h>
+#include <CGAL/license/Convex_hull_2.h>
+
 
 #include <boost/call_traits.hpp>
 
 #include <CGAL/property_map.h>
 
-
 namespace CGAL{
 
-
 template<class Base_traits,class PointPropertyMap>
 class Convex_hull_traits_adapter_2:public Base_traits{
   PointPropertyMap ppmap_;
@@ -90,12 +89,12 @@ public:
     }
   };
 
-  struct Less_signed_distance_to_line_2 : public Base_traits::Less_signed_distance_to_line_2{
-    Less_signed_distance_to_line_2(const PointPropertyMap& ppmap,const typename Base_traits::Less_signed_distance_to_line_2& base):
-      Base_traits::Less_signed_distance_to_line_2(base),ppmap_(ppmap){}
+  struct Compare_signed_distance_to_line_2 : public Base_traits::Compare_signed_distance_to_line_2{
+    Compare_signed_distance_to_line_2(const PointPropertyMap& ppmap,const typename Base_traits::Compare_signed_distance_to_line_2& base):
+      Base_traits::Compare_signed_distance_to_line_2(base),ppmap_(ppmap){}
     const PointPropertyMap& ppmap_;
     bool operator()(Arg_type p,Arg_type q, Arg_type r, Arg_type s) const {
-      return static_cast<const typename Base_traits::Less_signed_distance_to_line_2*>(this)->operator()(get(ppmap_,p),get(ppmap_,q),get(ppmap_,r),get(ppmap_,s));
+      return static_cast<const typename Base_traits::Compare_signed_distance_to_line_2*>(this)->operator()(get(ppmap_,p),get(ppmap_,q),get(ppmap_,r),get(ppmap_,s));
     }
   };
 
@@ -103,7 +102,7 @@ public:
   Left_turn_2 left_turn_2_object () const {return Left_turn_2(ppmap_,static_cast<const Gt*>(this)->left_turn_2_object() );}
   Orientation_2 orientation_2_object () const {return Orientation_2(ppmap_,static_cast<const Gt*>(this)->orientation_2_object() );}
   Less_rotate_ccw_2   less_rotate_ccw_2_object () const {return Less_rotate_ccw_2(ppmap_,static_cast<const Gt*>(this)->less_rotate_ccw_2_object() );}
-  Less_signed_distance_to_line_2   less_signed_distance_to_line_2_object () const {return Less_signed_distance_to_line_2(ppmap_,static_cast<const Gt*>(this)->less_signed_distance_to_line_2_object() );}
+  Compare_signed_distance_to_line_2 compare_signed_distance_to_line_2_object () const {return Compare_signed_distance_to_line_2(ppmap_,static_cast<const Gt*>(this)->compare_signed_distance_to_line_2_object() );}
   Less_xy_2 less_xy_2_object () const {return Less_xy_2(ppmap_,static_cast<const Gt*>(this)->less_xy_2_object() );}
   Less_yx_2 less_yx_2_object () const {return Less_yx_2(ppmap_,static_cast<const Gt*>(this)->less_yx_2_object() );}
 
@@ -113,6 +112,4 @@ public:
 
 } //namespace CGAL
 
-#include <CGAL/enable_warnings.h>
-
 #endif //CGAL_CONVEX_HULL_TRAITS_ADAPTER_2_H
