@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Convex_hull_3/include/CGAL/Convex_hull_vertex_base_2.h $
-// $Id: Convex_hull_vertex_base_2.h 9ecb90c 2022-01-26T19:07:34+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Convex_hull_3/include/CGAL/Convex_hull_vertex_base_2.h $
+// $Id: include/CGAL/Convex_hull_vertex_base_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,6 +18,7 @@
 #include <CGAL/license/Convex_hull_3.h>
 
 #include <CGAL/Triangulation_ds_vertex_base_2.h>
+#include <CGAL/IO/io.h>
 
 #include <iostream>
 
@@ -77,7 +78,7 @@ template <typename GT, typename Vb>
 std::ostream&
 operator<<(std::ostream &os, const Convex_hull_vertex_base_2<GT, Vb>& v)
 {
-  return os << static_cast<const Vb&>(v) << v.point();
+  return os << static_cast<const Vb&>(v) << IO::serialize(v.point());
 }
 
 } //namespace CGAL
