@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Make_x_monotone_2.h $
-// $Id: Make_x_monotone_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Make_x_monotone_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/Make_x_monotone_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Eric Berberich <eric@mpi-inf.mpg.de>
@@ -17,6 +17,9 @@
 #ifndef CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_MAKE_X_MONOTONE_2_H
 #define CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_MAKE_X_MONOTONE_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
 /*!\file include/CGAL/Curved_kernel_via_analysis_2/Make_x_monotone_2.h
  * \brief defines \c Make_x_monotone_2 functor
  */
@@ -54,11 +57,11 @@ struct Make_x_monotone_2 :
     public CGAL::cpp98::binary_function<
         typename CurvedKernelViaAnalysis_2::Curve_2,
         CGAL::cpp98::iterator<std::output_iterator_tag,
-                              boost::variant<
+                              std::variant<
                                 typename CurvedKernelViaAnalysis_2::Point_2,
                                 typename CurvedKernelViaAnalysis_2::Arc_2> >,
         CGAL::cpp98::iterator<std::output_iterator_tag,
-                              boost::variant<
+                              std::variant<
                                 typename CurvedKernelViaAnalysis_2::Point_2,
                                 typename CurvedKernelViaAnalysis_2::Arc_2> > >
 {
@@ -132,7 +135,7 @@ struct Make_x_monotone_2 :
   template <typename OutputIterator>
   OutputIterator operator()(Curve_analysis_2 curve, OutputIterator oi)
   {
-    typedef boost::variant<Point_2, Arc_2>      Make_x_monotone_result;
+    typedef std::variant<Point_2, Arc_2>      Make_x_monotone_result;
 
     Construct_arc_2 construct_arc_2 =
       _m_curved_kernel->construct_arc_2_object();
@@ -290,7 +293,7 @@ private:
                                 Coordinate_1 x, std::vector<Point_2> pts,
                                 OutputIterator oi) const
   {
-    typedef boost::variant<Point_2, Arc_2>      Make_x_monotone_result;
+    typedef std::variant<Point_2, Arc_2>      Make_x_monotone_result;
 
     Construct_arc_2 construct_arc_2 =
       _m_curved_kernel->construct_arc_2_object();
