@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Point_2.h $
-// $Id: Point_2.h a3d1765 2021-07-19T14:18:40+02:00 Maxime Gimeno
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/Point_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/Point_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Eric Berberich <eric@mpi-inf.mpg.de>
@@ -14,6 +14,9 @@
 #ifndef CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_POINT_2_H
 #define CGAL_CURVED_KERNEL_VIA_ANALYSIS_2_POINT_2_H
 
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
+
 /*!\file include/CGAL/Curved_kernel_via_analysis_2/Point_2.h
  * \brief defines class \c Point_2 that represents a point on a curve that can
  * be analyzed.
@@ -21,9 +24,8 @@
 
 #include <CGAL/config.h>
 
-#include <boost/optional.hpp>
+#include <optional>
 #include <boost/optional/optional_io.hpp>
-#include <boost/type_traits/is_same.hpp>
 
 #include <CGAL/Handle_with_policy.h>
 
@@ -31,6 +33,8 @@
 
 #include <CGAL/Curved_kernel_via_analysis_2/Curved_kernel_via_analysis_2_functors.h>
 
+#include <type_traits>
+
 namespace CGAL {
 
 namespace internal {
@@ -75,8 +79,7 @@ public:
     typedef typename Curve_kernel_2::Curve_analysis_2 Curve_analysis_2;
 
     //! default constructor
-    Point_2_rep() {
-    }
+    Point_2_rep() : _m_location(CGAL::ARR_INTERIOR) {}
 
     //! constructs a "finite" point on curve,
     //! implies CGAL::NO_BOUNDARY in x/y
@@ -106,22 +109,22 @@ public:
     //! curve point finite coordinates. They are valid only if boundary in y
     //! is not set (CGAL::NO_BOUNDARY), otherwise only x-coordinate is
     //! accessible, i.e., point is in interior
-    boost::optional< Coordinate_2 > _m_xy;
+    std::optional< Coordinate_2 > _m_xy;
 
     //! x-coordinate of a curve point
-    boost::optional< Coordinate_1 > _m_x;
+    std::optional< Coordinate_1 > _m_x;
 
     //! curve of point at boundary
-    boost::optional< Curve_analysis_2 > _m_curve;
+    std::optional< Curve_analysis_2 > _m_curve;
 
     //! arc of point at boundary
-    boost::optional< int > _m_arcno;
+    std::optional< int > _m_arcno;
 
     //! location of a point in parameter space
     mutable CGAL::Arr_parameter_space _m_location;
 
     //! store a double approximation of point
-    mutable boost::optional< std::pair< double, double > > _m_doubles;
+    mutable std::optional< std::pair< double, double > > _m_doubles;
 };
 
 /*!\brief
@@ -170,7 +173,7 @@ public:
     //!@}
 
     #if !defined(CGAL_NO_ASSERTIONS)
-    static const bool Kernel_point_2_equals_Point_2 = boost::is_same<Point_2, Kernel_point_2>::value;
+    static const bool Kernel_point_2_equals_Point_2 = std::is_same<Point_2, Kernel_point_2>::value;
     #endif
 
 public:
@@ -325,7 +328,7 @@ protected:
     //!@{
 
     /*!\brief
-     * constructs from a given represenation
+     * constructs from a given representation
      */
     /*!\brief
      * Constructor for for rebind
@@ -700,14 +703,13 @@ public:
         default:
           // ASCII
           os << "Point_2(";
-
-          os << this->ptr()->_m_xy;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_xy);
           os << ",";
-          os << this->ptr()->_m_x;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_x);
           os << ",";
-          os << this->ptr()->_m_curve;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_curve);
           os << ",";
-          os << this->ptr()->_m_arcno;
+          os << ::CGAL::IO::oformat(this->ptr()->_m_arcno);
           os << ",";
           os << this->ptr()->_m_location;
 
@@ -737,13 +739,13 @@ public:
     swallow(is, '(');
 
     // read values
-    is >> rep._m_xy;
+    is >> IO::iformat(rep._m_xy);
     swallow(is, ',');
-    is >> rep._m_x;
+    is >> IO::iformat(rep._m_x);
     swallow(is, ',');
-    is >> rep._m_curve;
+    is >> IO::iformat(rep._m_curve);
     swallow(is, ',');
-    is >> rep._m_arcno;
+    is >> IO::iformat(rep._m_arcno);
     swallow(is, ',');
     is >> rep._m_location;
 
