@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h $
-// $Id: Subdivision_2.h 26355e2 2020-06-25T12:31:21+02:00 Mael Rouxel-Labbé
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Arrangement_on_surface_2/include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h $
+// $Id: include/CGAL/Curved_kernel_via_analysis_2/gfx/Subdivision_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pavel Emeliyanenko <asm@mpi-sb.mpg.de>
 //
@@ -17,7 +17,10 @@
  */
 
 #ifndef CGAL_CKVA_SUBDIVISION_2_H
-#define CGAL_CKVA_SUBDIVISION_2_H 1
+#define CGAL_CKVA_SUBDIVISION_2_H
+
+#include <CGAL/license/Arrangement_on_surface_2.h>
+
 
 #warning this file is considered obsolete
 
@@ -166,7 +169,7 @@ private:
         void precompute();
         //! \brief switches to another cache instance depending on the
         //! supporting curve of a segment
-                //! \brief evalutates the ith derivative at certain x
+                //! \brief evaluates the ith derivative at certain x
         //!
         //! \c cache_it - an intetator pointing to the end of an array of
         //! polynomial coefficients, \c der_it - an iterator for derivative
@@ -179,7 +182,7 @@ private:
                         val = val * x + (*cache_it--) * (*der_it);
                 return val;
         }
-        //! evalutates a function at a certain x
+        //! evaluates a function at a certain x
         NT evaluate(const Poly_1& poly, const NT& x)
         {
                 const_iterator_1 it = poly.end() - 1, begin = poly.begin();
