@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Kernel_23/include/CGAL/Direction_2.h $
-// $Id: Direction_2.h e7357ac 2021-07-19T14:53:27+02:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Direction_2.h $
+// $Id: include/CGAL/Direction_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,7 +18,6 @@
 #define CGAL_DIRECTION_2_H
 
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/kernel_assertions.h>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/representation_tags.h>
@@ -39,7 +38,7 @@ class Direction_2 : public R_::Kernel_base::Direction_2
   typedef typename R_::Kernel_base::Direction_2      RDirection_2;
 
   typedef Direction_2                        Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Direction_2>::value));
+  static_assert(std::is_same<Self, typename R_::Direction_2>::value);
 
 public:
 
