@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Solver_interface/include/CGAL/Eigen_svd.h $
-// $Id: Eigen_svd.h a98b548 2022-05-12T16:03:53+02:00 Sven Oesau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Solver_interface/include/CGAL/Eigen_svd.h $
+// $Id: include/CGAL/Eigen_svd.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Gael Guennebaud
@@ -31,7 +31,7 @@ The class `Eigen_svd` provides an algorithm to solve in the least
 square sense a linear system with a singular value decomposition using
 \ref thirdpartyEigen.
 
-\cgalModels `SvdTraits`
+\cgalModels{SvdTraits}
 
 */
 class Eigen_svd
