@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/Exact_algebraic.h $
-// $Id: Exact_algebraic.h 350b917 2021-04-11T14:50:44+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Number_types/include/CGAL/Exact_algebraic.h $
+// $Id: include/CGAL/Exact_algebraic.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -37,10 +37,7 @@ It is a typedef of another number type. Its exact definition depends on
 the availability the third-party libraries \core, and \leda. \cgal must
 be configured with at least one of those libraries.
 
-\cgalModels `FieldWithSqrt`
-\cgalModels `RealEmbeddable`
-\cgalModels `Fraction`
-\cgalModels `FromDoubleConstructible`
+\cgalModels{FieldWithSqrt,RealEmbeddable,Fraction,FromDoubleConstructible}
 
 */
 #if DOXYGEN_RUNNING
