@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Filtered_kernel/include/CGAL/Filtered_predicate_with_state.h $
-// $Id: Filtered_predicate_with_state.h 74c029c 2021-09-09T11:44:36+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Filtered_kernel/include/CGAL/Filtered_predicate_with_state.h $
+// $Id: include/CGAL/Filtered_predicate_with_state.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,7 +18,7 @@
 #include <CGAL/Interval_nt.h>
 #include <CGAL/Uncertain.h>
 #include <CGAL/Profile_counter.h>
-#include <boost/optional.hpp>
+#include <optional>
 
 namespace CGAL {
 
@@ -31,7 +31,7 @@ class Filtered_predicate_with_state
   C2E c2e;
   C2A c2a;
   O1  o1;
-  mutable boost::optional<EP>  oep;
+  mutable std::optional<EP>  oep;
   AP  ap;
   typedef typename AP::result_type  Ares;
 
