@@ -7,12 +7,13 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polygon/include/CGAL/General_polygon_with_holes_2.h $
-// $Id: General_polygon_with_holes_2.h 2a30075 2022-01-10T11:01:31+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon/include/CGAL/General_polygon_with_holes_2.h $
+// $Id: include/CGAL/General_polygon_with_holes_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
-// Author(s)     : Baruch Zukerman <baruchzu@post.tau.ac.il>
+// Author(s): Baruch Zukerman <baruchzu@post.tau.ac.il>
+//            Efi Fogel <efifogel@gmail.com>
 
 #ifndef CGAL_GENERAL_POLYGON_WITH_HOLES_2_H
 #define CGAL_GENERAL_POLYGON_WITH_HOLES_2_H
@@ -27,13 +28,13 @@ namespace CGAL {
  *
  * The class `General_polygon_with_holes_2` models the concept
  * `GeneralPolygonWithHoles_2`. It represents a general polygon with holes.
- * It is parameterized with a type `Polygon` used to define the exposed
- * type `Polygon_2`. This type represents the outer boundary of the general
+ * It is parameterized with a type `Polygon_` used to define the exposed
+ * type `%Polygon_2`. This type represents the outer boundary of the general
  * polygon and each hole.
  *
  * \tparam Polygon_ must have input and output operators.
  *
- * \cgalModels `GeneralPolygonWithHoles_2`
+ * \cgalModels{GeneralPolygonWithHoles_2}
  */
 template <typename Polygon_>
 class General_polygon_with_holes_2 {
@@ -56,13 +57,17 @@ public:
 
   typedef unsigned int                                Size;
 
-  General_polygon_with_holes_2() : m_pgn() {}
+  General_polygon_with_holes_2() = default;
 
 
   explicit General_polygon_with_holes_2(const Polygon_2& pgn_boundary) :
     m_pgn(pgn_boundary)
   {}
 
+  explicit General_polygon_with_holes_2(Polygon_2&& pgn_boundary) :
+    m_pgn(std::move(pgn_boundary))
+  {}
+
   template <typename HolesInputIterator>
   General_polygon_with_holes_2(const Polygon_2& pgn_boundary,
                                HolesInputIterator h_begin,
@@ -71,6 +76,14 @@ public:
     m_holes(h_begin, h_end)
   {}
 
+  template <typename HolesInputIterator>
+  General_polygon_with_holes_2(Polygon_2&& pgn_boundary,
+                               HolesInputIterator h_begin,
+                               HolesInputIterator h_end) :
+    m_pgn(std::move(pgn_boundary)),
+    m_holes(h_begin, h_end)
+  {}
+
   Holes_container& holes() { return m_holes; }
 
   const Holes_container& holes() const { return m_holes; }
@@ -91,8 +104,14 @@ public:
 
   void add_hole(const Polygon_2& pgn_hole) { m_holes.push_back(pgn_hole); }
 
+  void add_hole(Polygon_2&& pgn_hole) { m_holes.emplace_back(std::move(pgn_hole)); }
+
   void erase_hole(Hole_iterator hit) { m_holes.erase(hit); }
 
+  void clear_outer_boundary() { m_pgn.clear(); }
+
+  void clear_holes() { m_holes.clear(); }
+
   bool has_holes() const { return (!m_holes.empty()); }
 
   Size number_of_holes() const { return static_cast<Size>(m_holes.size()); }
@@ -104,6 +123,19 @@ public:
 
   bool is_plane() const { return (m_pgn.is_empty() && m_holes.empty()); }
 
+  bool is_empty() const
+  {
+    if(! outer_boundary().is_empty()) {
+        return false;
+      }
+    for(const auto& h : holes()){
+      if(! h.is_empty()){
+        return false;
+      }
+    }
+    return true;
+  }
+
 protected:
   Polygon_2 m_pgn;
   Holes_container m_holes;
@@ -113,10 +145,10 @@ protected:
 //                          operator<<
 //-----------------------------------------------------------------------//
 /*!
-This operator exports a General_polygon_with_holes_2 to the output stream `out`.
+This operator exports a `General_polygon_with_holes_2` to the output stream `os`.
 
 An \ascii and a binary format exist. The format can be selected with
-the \cgal modifiers for streams, `set_ascii_mode(0` and `set_binary_mode()`
+the \cgal modifiers for streams, `set_ascii_mode()` and `set_binary_mode()`,
 respectively. The modifier `set_pretty_mode()` can be used to allow for (a
 few) structuring comments in the output. Otherwise, the output would
 be free of comments. The default for writing is \ascii without comments.
@@ -164,9 +196,9 @@ operator<<(std::ostream& os, const General_polygon_with_holes_2<Polygon_>& p) {
 //-----------------------------------------------------------------------//
 
 /*!
-This operator imports a General_polygon_with_holes_2 from the input stream `in`.
+This operator imports a `General_polygon_with_holes_2` from the input stream `is`.
 
-Both ASCII and binary formats are supported, and the format is automatically detected.
+Both \ascii and binary formats are supported, and the format is automatically detected.
 
 The format consists of the number of curves of the outer boundary
 followed by the curves themselves, followed
@@ -187,7 +219,7 @@ operator>>(std::istream& is, General_polygon_with_holes_2<Polygon_>& p) {
     Polygon_ pgn_hole;
     for (unsigned int i=0; i<n_holes; ++i) {
       is >> pgn_hole;
-      p.add_hole(pgn_hole);
+      p.add_hole(std::move(pgn_hole));
     }
   }
 
