@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Mesh_3/include/CGAL/IO/File_medit.h $
-// $Id: File_medit.h 70058db 2021-05-03T15:30:52+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/SMDS_3/include/CGAL/IO/File_medit.h $
+// $Id: include/CGAL/IO/File_medit.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -14,17 +14,18 @@
 #ifndef CGAL_IO_FILE_MEDIT_H
 #define CGAL_IO_FILE_MEDIT_H
 
-#include <CGAL/license/Triangulation_3.h>
+#include <CGAL/license/SMDS_3.h>
 
-#include <CGAL/Mesh_3/config.h>
-#include <CGAL/Mesh_3/Mesh_complex_3_in_triangulation_3_fwd.h>
+#include <CGAL/SMDS_3/Mesh_complex_3_in_triangulation_3_fwd.h>
+#include <CGAL/Mesh_complex_3_in_triangulation_3.h>
+#include <CGAL/SMDS_3/tet_soup_to_c3t3.h>
 
 #include <CGAL/utility.h>
 #include <CGAL/basic.h>
+#include <CGAL/Named_function_parameters.h>
+#include <CGAL/boost/graph/named_params_helper.h>
 
-#include <boost/type_traits/is_same.hpp>
 #include <boost/unordered_map.hpp>
-#include <boost/utility/enable_if.hpp>
 
 #include <iomanip>
 #include <iostream>
@@ -32,10 +33,12 @@
 #include <set>
 #include <string>
 #include <vector>
+#include <unordered_map>
+#include <type_traits>
 
 namespace CGAL {
 
-namespace Mesh_3 {
+namespace SMDS_3 {
 
 //-------------------------------------------------------
 // Needed in verbose mode
@@ -65,14 +68,9 @@ public:
   Rebind_cell_pmap(const C3T3& c3t3)
     : r_c3t3_(c3t3)
   {
-    typedef typename C3T3::Cells_in_complex_iterator Cell_iterator;
+    int index_counter = 1;
 
-    int first_index = 0;
-    int index_counter = first_index + 1;
-
-    for( Cell_iterator cell_it = r_c3t3_.cells_in_complex_begin();
-         cell_it != r_c3t3_.cells_in_complex_end();
-         ++cell_it)
+    for( Cell_handle cell_it : r_c3t3_.cells_in_complex())
     {
       // Add subdomain index in internal map if needed
       std::pair<typename Subdomain_map::iterator, bool> is_insert_successful =
@@ -84,7 +82,7 @@ public:
     }
 
     // Rebind indices in alphanumeric order
-    index_counter = first_index + 1;
+    index_counter = 1;
     for ( typename Subdomain_map::iterator mit = subdomain_map_.begin() ;
           mit != subdomain_map_.end() ;
           ++mit )
@@ -125,7 +123,7 @@ private:
     if ( elt_it != subdomain_map_.end() )
       return elt_it->second;
     else
-      return -1;
+      return 0;
   }
 
 private:
@@ -170,12 +168,9 @@ public:
 
   size_type subdomain_number() const
   {
-    typedef typename C3T3::Cells_in_complex_iterator Cell_iterator;
     std::set<Subdomain_index> subdomain_set;
 
-    for( Cell_iterator cell_it = r_c3t3_.cells_in_complex_begin();
-        cell_it != r_c3t3_.cells_in_complex_end();
-        ++cell_it)
+    for( Cell_handle cell_it : r_c3t3_.cells_in_complex())
     {
       // Add subdomain index in set
       subdomain_set.insert(subdomain_index(cell_it));
@@ -214,30 +209,23 @@ public:
     : r_c3t3_(c3t3)
     , cell_pmap_(cell_pmap)
   {
-    typedef typename C3T3::Facets_in_complex_iterator Facet_iterator;
-
     int first_index = 1;
     int index_counter = first_index;
 
-    for( Facet_iterator facet_it = r_c3t3_.facets_in_complex_begin();
-        facet_it != r_c3t3_.facets_in_complex_end();
-        ++facet_it)
+    for( Facet facet_it : r_c3t3_.facets_in_complex())
     {
       // Add surface index in internal map if needed
       std::pair<typename Surface_map::iterator, bool> is_insert_successful =
-          surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(*facet_it),
+          surface_map_.insert(std::make_pair(r_c3t3_.surface_patch_index(facet_it),
                                              index_counter));
       if(is_insert_successful.second)
         ++index_counter;
     }
 
     // Find cell_pmap_ unused indices
-    typedef typename C3T3::Cells_in_complex_iterator Cell_iterator;
     std::set<int> cell_label_set;
 
-    for( Cell_iterator cell_it = r_c3t3_.cells_in_complex_begin();
-        cell_it != r_c3t3_.cells_in_complex_end();
-        ++cell_it)
+    for( typename C3T3::Cell_handle cell_it : r_c3t3_.cells_in_complex())
     {
       // Add subdomain index in set
       cell_label_set.insert(get(cell_pmap_, cell_it));
@@ -588,7 +576,7 @@ public:
       break;
 
     default:
-      // should not happen
+      // must not happen
       return -1;
       break;
     }
@@ -703,7 +691,9 @@ struct Medit_pmap_generator<C3T3, false, false>
 template <class C3T3, bool rebind, bool no_patch>
 void
 output_to_medit(std::ostream& os,
-                const C3T3& c3t3)
+                const C3T3& c3t3,
+                const bool all_vertices,
+                const bool all_cells)
 {
 #ifdef CGAL_MESH_3_IO_VERBOSE
   std::cerr << "Output to medit:\n";
@@ -726,7 +716,9 @@ output_to_medit(std::ostream& os,
                   facet_pmap,
                   cell_pmap,
                   facet_pmap_twice,
-                  Generator().print_twice());
+                  Generator().print_twice(),
+                  all_vertices,
+                  all_cells);
 
 #ifdef CGAL_MESH_3_IO_VERBOSE
   std::cerr << "done.\n";
@@ -747,14 +739,14 @@ output_to_medit(std::ostream& os,
                 const Facet_index_property_map& facet_pmap,
                 const Cell_index_property_map& cell_pmap,
                 const Facet_index_property_map_twice& facet_twice_pmap = Facet_index_property_map_twice(),
-                const bool print_each_facet_twice = false)
+                const bool print_each_facet_twice = false,
+                const bool all_vertices = true,
+                const bool all_cells = false)
 {
   typedef typename C3T3::Triangulation Tr;
-  typedef typename C3T3::Facets_in_complex_iterator Facet_iterator;
-  typedef typename C3T3::Cells_in_complex_iterator Cell_iterator;
 
-  typedef typename Tr::Finite_vertices_iterator Finite_vertices_iterator;
   typedef typename Tr::Vertex_handle Vertex_handle;
+  typedef typename Tr::Cell_handle   Cell_handle;
   typedef typename Tr::Point Point; //can be weighted or not
 
   const Tr& tr = c3t3.triangulation();
@@ -770,32 +762,61 @@ output_to_medit(std::ostream& os,
 
   os << "MeshVersionFormatted 1\n"
      << "Dimension 3\n";
-
+  os << "# CGAL::Mesh_complex_3_in_triangulation_3\n";
 
   //-------------------------------------------------------
   // Vertices
   //-------------------------------------------------------
-  os << "Vertices\n" << tr.number_of_vertices() << '\n';
 
-  boost::unordered_map<Vertex_handle, int> V;
+  std::unordered_map<Vertex_handle, int> V;
   int inum = 1;
-  for( Finite_vertices_iterator vit = tr.finite_vertices_begin();
-       vit != tr.finite_vertices_end();
-       ++vit)
+  if (all_vertices || all_cells)
   {
-    V[vit] = inum++;
-    Point p = tr.point(vit);
-    os << CGAL::to_double(p.x()) << ' '
-       << CGAL::to_double(p.y()) << ' '
-       << CGAL::to_double(p.z()) << ' '
-       << get(vertex_pmap, vit)
-       << '\n';
+    os << "Vertices\n" << tr.number_of_vertices() << '\n';
+
+    for (typename Tr::Finite_vertices_iterator vit = tr.finite_vertices_begin();
+         vit != tr.finite_vertices_end();
+         ++vit)
+    {
+      V[vit] = inum++;
+      const Point& p = tr.point(vit);
+      os << CGAL::to_double(p.x()) << ' '
+        << CGAL::to_double(p.y()) << ' '
+        << CGAL::to_double(p.z()) << ' '
+        << get(vertex_pmap, vit)
+        << '\n';
+    }
+  }
+  else
+  {
+    std::ostringstream oss;
+    for (Cell_handle c : c3t3.cells_in_complex())
+    {
+      for (int i = 0; i < 4; ++i)
+      {
+        Vertex_handle vit = c->vertex(i);
+        if (V.find(vit) == V.end())
+        {
+          V[vit] = inum++;
+          const Point& p = tr.point(vit);
+          oss << CGAL::to_double(p.x()) << ' '
+            << CGAL::to_double(p.y()) << ' '
+            << CGAL::to_double(p.z()) << ' '
+            << get(vertex_pmap, vit)
+            << '\n';
+        }
+      }
+    }
+    os << "Vertices\n" << V.size() << "\n";
+    os << oss.str();
   }
 
   //-------------------------------------------------------
   // Facets
   //-------------------------------------------------------
-  typename C3T3::size_type number_of_triangles = c3t3.number_of_facets_in_complex();
+  typename C3T3::size_type number_of_triangles
+    = std::distance(c3t3.facets_in_complex_begin(),
+                    c3t3.facets_in_complex_end());
 
   if ( print_each_facet_twice )
     number_of_triangles += number_of_triangles;
@@ -803,12 +824,8 @@ output_to_medit(std::ostream& os,
   os << "Triangles\n"
      << number_of_triangles << '\n';
 
-  for( Facet_iterator fit = c3t3.facets_in_complex_begin();
-       fit != c3t3.facets_in_complex_end();
-       ++fit)
+  for(typename C3T3::Facet f : c3t3.facets_in_complex())
   {
-    typename C3T3::Facet f = (*fit);
-
     // Apply priority among subdomains, to get consistent facet orientation per subdomain-pair interface.
     if ( print_each_facet_twice )
     {
@@ -827,30 +844,47 @@ output_to_medit(std::ostream& os,
       std::swap(vh2, vh3);
 
     os << V[vh1] << ' ' << V[vh2] << ' ' << V[vh3] << ' ';
-    os << get(facet_pmap, *fit) << '\n';
+    os << get(facet_pmap, f) << '\n';
 
     // Print triangle again if needed, with opposite orientation
     if ( print_each_facet_twice )
     {
       os << V[vh3] << ' ' << V[vh2] << ' ' << V[vh1] << ' ';
-      os << get(facet_twice_pmap, *fit) << '\n';
+      os << get(facet_twice_pmap, f) << '\n';
     }
   }
 
   //-------------------------------------------------------
   // Tetrahedra
   //-------------------------------------------------------
+  typename C3T3::size_type number_of_cells
+    = all_cells
+    ? c3t3.triangulation().number_of_finite_cells()
+    : std::distance(c3t3.cells_in_complex_begin(), c3t3.cells_in_complex_end());;
   os << "Tetrahedra\n"
-     << c3t3.number_of_cells_in_complex() << '\n';
+     << number_of_cells << '\n';
 
-  for( Cell_iterator cit = c3t3.cells_in_complex_begin() ;
-       cit != c3t3.cells_in_complex_end() ;
-       ++cit )
+  if (all_cells)
   {
-    for (int i=0; i<4; i++)
-      os << V[cit->vertex(i)] << ' ';
+    for (auto cit = c3t3.triangulation().finite_cells_begin();
+         cit != c3t3.triangulation().finite_cells_end();
+         ++cit)
+    {
+      for (int i = 0; i < 4; i++)
+        os << V[cit->vertex(i)] << ' ';
 
-    os << get(cell_pmap, cit) << '\n';
+      os << get(cell_pmap, cit) << '\n';
+    }
+  }
+  else
+  {
+    for (Cell_handle cit : c3t3.cells_in_complex())
+    {
+      for (int i = 0; i < 4; i++)
+        os << V[cit->vertex(i)] << ' ';
+
+      os << get(cell_pmap, cit) << '\n';
+    }
   }
 
   //-------------------------------------------------------
@@ -865,53 +899,248 @@ output_to_medit(std::ostream& os,
 namespace IO {
 
 /**
- * @brief outputs mesh to medit format
- * @param os the stream
- * @param c3t3 the mesh
- * @param rebind if true, labels of cells are rebinded into [1..nb_of_labels]
- * @param show_patches if true, patches are labeled with different labels than
- * cells. If false, each surface facet is written twice, using label of
- * each adjacent cell.
+ * @ingroup PkgSMDS3IOFunctions
+ * @deprecated This function is deprecated. Users should instead use `CGAL::IO::write_MEDIT()`
+ * @brief outputs a mesh complex to the medit (`.mesh`) file format.
+        See \cgalCite{frey:inria-00069921} for a comprehensive description of this file format.
+ * @param os the output stream
+ * @param c3t3 the mesh complex
+ * @param rebind if `true`, labels of cells are rebinded into `[1..nb_of_labels]`
+ * @param show_patches if `true`, patches are labeled with different labels than
+ *                     cells. If `false`, each surface facet is written twice,
+ *                     using the label of each adjacent cell.
  * \see \ref IOStreamMedit
  */
 template <class C3T3>
 void
 output_to_medit(std::ostream& os,
                 const C3T3& c3t3,
-                bool rebind = false,
-                bool show_patches = false)
+                bool rebind,      // = false,
+                bool show_patches // = false
+#ifndef DOXYGEN_RUNNING
+              , bool all_vertices // = true
+              , bool all_cells    // = false
+#endif
+)
 {
   if ( rebind )
   {
     if ( show_patches )
-      Mesh_3::output_to_medit<C3T3,true,false>(os,c3t3);
+      CGAL::SMDS_3::output_to_medit<C3T3,true,false>(os, c3t3,
+        all_vertices, all_cells);
     else
-      Mesh_3::output_to_medit<C3T3,true,true>(os,c3t3);
+      CGAL::SMDS_3::output_to_medit<C3T3,true,true>(os, c3t3,
+        all_vertices, all_cells);
   }
   else
   {
     if ( show_patches )
-      Mesh_3::output_to_medit<C3T3,false,false>(os,c3t3);
+      CGAL::SMDS_3::output_to_medit<C3T3,false,false>(os, c3t3,
+        all_vertices, all_cells);
     else
-      Mesh_3::output_to_medit<C3T3,false,true>(os,c3t3);
+      CGAL::SMDS_3::output_to_medit<C3T3,false,true>(os, c3t3,
+        all_vertices, all_cells);
   }
 }
 
-
-template<typename T3>
-void write_MEDIT(std::ostream& os, const T3& t3)
+/**
+ * @ingroup PkgSMDS3IOFunctions
+ * @brief outputs a mesh complex to the medit (`.mesh`) file format.
+ *      See \cgalCite{frey:inria-00069921} for a comprehensive description of this file format.
+ * @tparam T3 can be instantiated with any 3D triangulation of \cgal provided that its
+ *  vertex and cell base class are models of the concepts `SimplicialMeshVertexBase_3`
+ * and `SimplicialMeshCellBase_3`, respectively.
+ * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
+ *
+ * @param os the output stream
+ * @param t3 the triangulation
+ * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
+ *
+ * \cgalNamedParamsBegin
+ * \cgalParamNBegin{all_cells}
+ *   \cgalParamDescription{If `true`, all the cells in `t3` are written in `os`,
+ *        whether they belong to the complex or not.
+ *        Otherwise, only the cells `c` for which
+ *        `c->subdomain_index() != Subdomain_index()` are written.}
+ *   \cgalParamType{Boolean}
+ *   \cgalParamDefault{`true`}
+ *   \cgalParamExtra{This parameter must be set to `true` for the file to be readable by `read_MEDIT()`.}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{all_vertices}
+ *   \cgalParamDescription{If `true`, all the finite vertices in `t3` are written in `os`.
+ *                         Otherwise, only the vertices that belong to a cell `c` for which
+ *                         `c->subdomain_index() != Subdomain_index()` are written}
+ *   \cgalParamType{Boolean}
+ *   \cgalParamDefault{`true`}
+ *   \cgalParamExtra{If `all_cells` is `true`, the value of this parameter is ignored and
+                     all vertices are written in `os`. It must be
+ *                   set to `true` for the file to be readable by `read_MEDIT()`.}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{rebind_labels}
+ *  \cgalParamDescription{If `true`, labels of cells are rebinded into `[1..nb_of_labels]`}
+ *  \cgalParamType{Boolean}
+ *  \cgalParamDefault{`false`}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{show_patches}
+ *  \cgalParamDescription{If `true`, patches are labeled with different labels than
+ *                        cells. If `false`, each surface facet is written twice,
+ *                        using the label of each adjacent cell.}
+ *  \cgalParamType{Boolean}
+ *  \cgalParamDefault{`true`}
+ * \cgalParamNEnd
+ * \cgalNamedParamsEnd
+ * \see \ref IOStreamMedit
+ */
+template<typename T3, typename NamedParameters = parameters::Default_named_parameters>
+void write_MEDIT(std::ostream& os,
+                 const T3& t3,
+                 const NamedParameters& np = parameters::default_values())
 {
   CGAL::Mesh_complex_3_in_triangulation_3<T3, int, int> c3t3;
   c3t3.triangulation() = t3;
   c3t3.rescan_after_load_of_triangulation();
-  output_to_medit(os, c3t3);
+
+  using parameters::get_parameter;
+  using parameters::choose_parameter;
+
+  bool rebind = choose_parameter(get_parameter(np, internal_np::rebind_labels), false);;
+  bool show_patches = choose_parameter(get_parameter(np, internal_np::show_patches), true);
+  bool all_c = choose_parameter(get_parameter(np, internal_np::all_cells), true);
+  bool all_v = all_c || choose_parameter(get_parameter(np, internal_np::all_vertices), true);
+
+  output_to_medit(os, c3t3, rebind, show_patches, all_v, all_c);
 }
 
-template<typename T3>
-bool read_MEDIT(std::istream& in, T3& t3)
+/**
+ * @ingroup PkgSMDS3IOFunctions
+ * @brief outputs a mesh complex to the medit (`.mesh`) file format.
+ *      See \cgalCite{frey:inria-00069921} for a comprehensive description of this file format.
+ * @tparam T3 can be instantiated with any 3D triangulation of \cgal provided that its
+ *  vertex and cell base class are models of the concepts `MeshVertexBase_3` and `MeshCellBase_3`, respectively.
+ * @tparam CornerIndex is the type of the indices for corners
+ * @tparam CurveIndex is the type of the indices for curves
+ * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
+
+ * @param os the output stream
+ * @param c3t3 the mesh complex
+ * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
+ *
+ * \cgalNamedParamsBegin
+ * \cgalParamNBegin{all_cells}
+ *   \cgalParamDescription{If `true`, all the cells in `t3` are written in `os`,
+ *        whether they belong to the complex or not.
+ *        Otherwise, only the cells `c` for which
+ *        `c->subdomain_index() != Subdomain_index()` are written.}
+ *   \cgalParamType{Boolean}
+ *   \cgalParamDefault{`true`}
+ *   \cgalParamExtra{If the complex does not form a topological sphere,
+ *        this parameter must be set to `true` for the file to be readable by `read_MEDIT()`.
+ *        Otherwise the underlying triangulation data structure will not be valid.}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{all_vertices}
+ *   \cgalParamDescription{If `true`, all the vertices in `t3` are written in `os`.
+ *                         Otherwise, only the vertices that belong to a cell `c` for which
+ *                         `c->subdomain_index() != Subdomain_index()` are written}
+ *   \cgalParamType{Boolean}
+ *   \cgalParamDefault{`true`}
+ *   \cgalParamExtra{If `all_cells` is `true`, the value of this parameter is ignored
+          and all vertices are written in `os`. If the complex does not
+          form a topological sphere, it must be
+ *        set to `true` for the file to be readable by `read_MEDIT()`.
+ *        Otherwise the underlying triangulation data structure will not be valid.}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{rebind_labels}
+ *  \cgalParamDescription{If `true`, labels of cells are rebinded into `[1..nb_of_labels]`}
+ *  \cgalParamType{Boolean}
+ *  \cgalParamDefault{`false`}
+ * \cgalParamNEnd
+ *
+ * \cgalParamNBegin{show_patches}
+ *  \cgalParamDescription{If `true`, patches are labeled with different labels than
+ *                        cells. If `false`, each surface facet is written twice,
+ *                        using the label of each adjacent cell.}
+ *  \cgalParamType{Boolean}
+ *  \cgalParamDefault{`true`}
+ * \cgalParamNEnd
+ * \cgalNamedParamsEnd
+ *
+ * \see \ref IOStreamMedit
+ */
+template<typename T3,
+         typename CornerIndex,
+         typename CurveIndex,
+         typename NamedParameters = parameters::Default_named_parameters>
+void write_MEDIT(std::ostream& os,
+  const CGAL::Mesh_complex_3_in_triangulation_3<T3, CornerIndex, CurveIndex>& c3t3,
+  const NamedParameters& np = parameters::default_values())
 {
-  CGAL_assertion(!(!in));
-  return CGAL::build_triangulation_from_file<T3, true>(in, t3);
+  return write_MEDIT(os, c3t3.triangulation(), np);
+}
+
+/**
+ * @ingroup PkgSMDS3IOFunctions
+ * @brief reads a mesh complex written in the medit (`.mesh`) file format.
+ *   See \cgalCite{frey:inria-00069921} for a comprehensive description of this file format.
+ * @tparam T3 can be instantiated with any 3D triangulation of \cgal provided that its
+ *  vertex and cell base class are models of the concepts `MeshVertexBase_3` and `MeshCellBase_3`,
+ *  respectively.
+ * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
+ *
+ * @param in the input stream
+ * @param t3 the triangulation
+ * @param np optional \ref bgl_namedparameters "Named Parameters" described below
+ *
+ * \cgalNamedParamsBegin
+ *   \cgalParamNBegin{verbose}
+ *     \cgalParamDescription{indicates whether output warnings and error messages should be printed or not.}
+ *     \cgalParamType{Boolean}
+ *     \cgalParamDefault{`false`}
+ *   \cgalParamNEnd
+ *   \cgalParamNBegin{allow_non_manifold}
+ *     \cgalParamDescription{allows the construction of a triangulation with non-manifold edges
+ *       and non manifold vertices. The triangulation is invalid if this situation is met,
+ *       so it should be used only in advanced cases, and the triangulation will be hardly usable.}
+ *     \cgalParamType{bool}
+ *     \cgalParamDefault{false}
+ *   \cgalParamNEnd
+ * \cgalNamedParamsEnd
+ *
+ * @returns `true` if the connectivity of the triangulation could be built consistently
+ * from \p in,
+ * and `false` if the triangulation is empty, or if the connectivity
+ * of \p t3 could not be built.
+ * If `false` is returned, \p t3 is empty when the function returns.
+ *
+ * This function reads the data about vertices, surface facets, and
+ * triangulation cells from `in`, and builds a valid `T3` from it.
+ *
+ * Note that a valid 3D triangulation of \cgal must have a valid
+ * data structure (see `TriangulationDataStructure_3 `),
+ * positively oriented cells,
+ * and cover the geometric convex hull of all points in `t3`.
+ */
+template<typename T3, typename CGAL_NP_TEMPLATE_PARAMETERS>
+bool read_MEDIT(std::istream& in,
+                T3& t3,
+                const CGAL_NP_CLASS& np = parameters::default_values())
+{
+  using parameters::choose_parameter;
+  using parameters::get_parameter;
+
+  // Default non_manifold value is true if the triangulation periodic, false otherwise
+  const bool non_manifold = choose_parameter(get_parameter(np, internal_np::allow_non_manifold),
+                                             std::is_same<typename T3::Periodic_tag, Tag_true>::value);
+  const bool verbose = choose_parameter(get_parameter(np, internal_np::verbose), false);
+
+  bool b = CGAL::SMDS_3::build_triangulation_from_file(in, t3, verbose, false /*replace_domain_0*/, non_manifold);
+  if(!b)
+    t3.clear();
+  return b;
 }
 
 } // namespace IO
