@@ -6,8 +6,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Stream_support/include/CGAL/IO/WKT.h $
-// $Id: WKT.h aa8da89 2022-12-08T16:23:10+00:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Stream_support/include/CGAL/IO/WKT.h $
+// $Id: include/CGAL/IO/WKT.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Maxime Gimeno
@@ -19,6 +19,7 @@
 #include <CGAL/Point_3.h>
 #include <CGAL/Polygon_2.h>
 #include <CGAL/Polygon_with_holes_2.h>
+#include <CGAL/Multipolygon_with_holes_2.h>
 
 #include <CGAL/IO/WKT/traits_point.h>
 #include <CGAL/IO/WKT/traits_point_3.h>
@@ -67,7 +68,7 @@ void pop_back_if_equal_to_front(CGAL::Polygon_with_holes_2<K>& pwh)
 //!
 //! \tparam Point can be a `CGAL::Point_2` or `CGAL::Point_3`.
 //!
-//! \attention Only Cartesian Kernels with double or float as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float as `FT` are supported.
 //!
 //! \see `CGAL::Point_2`
 //! \see `CGAL::Point_3`
@@ -112,10 +113,10 @@ bool read_point_WKT(std::istream& in,
 //! and have:
 //! - a function `push_back()` that takes the same point type,
 //! - a function `clear()`,
-//! - a function `resize()` that takes an `size_type`
+//! - a function `resize()` that takes a `size_type`
 //! - an `operator[]()` that takes a `size_type`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::Point_2`
 //! \see `CGAL::Point_3`
@@ -159,10 +160,10 @@ bool read_multi_point_WKT(std::istream& in,
 //! and have:
 //! - a function `push_back()` that takes a `CGAL::Point_2`.
 //! - a function `clear()`,
-//! - a function `resize()` that takes an `size_type`
+//! - a function `resize()` that takes a `size_type`
 //! - an `operator[]()` that takes a `size_type`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::Point_2`
 template<typename LineString>
@@ -203,10 +204,10 @@ bool read_linestring_WKT(std::istream& in,
 //! and have:
 //! - a function `push_back()` that takes a `Linestring`,
 //! - a function `clear()`,
-//! - a function `resize()` that takes an `size_type`
+//! - a function `resize()` that takes a `size_type`
 //! - an `operator[]()` that takes a `size_type`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::Point_2`
 template<typename MultiLineString>
@@ -258,7 +259,7 @@ bool read_multi_linestring_WKT(std::istream& in,
 //!
 //! \tparam Polygon is a `CGAL::General_polygon_with_holes_2`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::General_polygon_with_holes_2`
 template<typename Polygon>
@@ -302,10 +303,10 @@ bool read_polygon_WKT(std::istream& in,
 //! and have:
 //! - a function `push_back()` that takes a `CGAL::General_polygon_with_holes_2`,
 //! - a function `clear()`,
-//! - a function `resize()` that takes an `size_type`
+//! - a function `resize()` that takes a `size_type`
 //! - an `operator[]()` that takes a `size_type`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::General_polygon_with_holes_2`
 template<typename MultiPolygon>
@@ -345,13 +346,22 @@ bool read_multi_polygon_WKT(std::istream& in,
   return !in.fail();
 }
 
+
+template<typename Kernel, typename Container>
+bool read_multi_polygon_WKT(std::istream& in,
+                            Multipolygon_with_holes_2<Kernel,Container>& mp)
+{
+  return read_multi_polygon_WKT(in, mp.polygons_with_holes());
+}
+
+
 //! \ingroup PkgStreamSupportIoFuncsWKT
 //!
 //! \brief writes `point` into a WKT stream.
 //!
 //! \tparam Point is a `CGAL::Point_2`
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::Point_2`
 template<typename Point>
@@ -371,7 +381,7 @@ std::ostream& write_point_WKT(std::ostream& out,
 //!
 //! \tparam Polygon must be a `CGAL::General_polygon_with_holes_2`
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::General_polygon_with_holes_2`
 template<typename Polygon>
@@ -391,7 +401,7 @@ std::ostream& write_polygon_WKT(std::ostream& out,
 //!
 //! \tparam LineString must be a `RandomAccessRange` of `CGAL::Point_2`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //!\see `CGAL::Point_2`
 template<typename LineString>
@@ -412,7 +422,7 @@ std::ostream& write_linestring_WKT(std::ostream& out,
 //!
 //! \tparam MultiPoint must be a `RandomAccessRange` of `CGAL::Point_2`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //!\see `CGAL::Point_2`
 template<typename MultiPoint>
@@ -433,7 +443,7 @@ std::ostream& write_multi_point_WKT(std::ostream& out,
 //!
 //! \tparam MultiPolygon must be a `RandomAccessRange` of `CGAL::General_polygon_with_holes_2`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //!\see `CGAL::General_polygon_with_holes_2`
 template<typename MultiPolygon>
@@ -448,13 +458,20 @@ std::ostream& write_multi_polygon_WKT(std::ostream& out,
   return out;
 }
 
+template<typename Kernel, typename Container>
+std::ostream& write_multi_polygon_WKT(std::ostream& out,
+                                      Multipolygon_with_holes_2<Kernel,Container>& mp)
+{
+  return write_multi_polygon_WKT(out, mp.polygons_with_holes());
+}
+
 //! \ingroup PkgStreamSupportIoFuncsWKT
 //!
 //! \brief writes the content of `mls` into a WKT stream.
 //!
 //! \tparam MultiLineString must be a `RandomAccessRange` of `LineString`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::IO::write_linestring_WKT()`
 template<typename MultiLineString>
@@ -489,7 +506,7 @@ std::ostream& write_multi_linestring_WKT(std::ostream& out,
 //! \tparam MultiLineString must be a `RandomAccessRange` of `Linestring`.
 //! \tparam MultiPolygon must be a model of `RandomAccessRange` of `CGAL::General_polygon_with_holes_2`.
 //!
-//! \attention Only Cartesian Kernels with double or float  as `FT` are supported.
+//! \attention Only %Cartesian Kernels with double or float  as `FT` are supported.
 //!
 //! \see `CGAL::IO::read_linestring_WKT()`
 template<typename MultiPoint,
