@@ -5,8 +5,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Mesh_2/include/CGAL/IO/write_VTU.h $
-// $Id: write_VTU.h e0a4dd0 2021-05-18T17:31:40+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_2/include/CGAL/IO/write_VTU.h $
+// $Id: include/CGAL/IO/write_VTU.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,6 +20,7 @@
 #include <CGAL/assertions.h>
 #include <CGAL/IO/io.h>
 #include <CGAL/IO/VTK/VTK_writer.h>
+#include <CGAL/Triangulation_2/internal/In_domain.h>
 
 #include <iostream>
 #include <vector>
@@ -35,10 +36,11 @@ namespace internal {
 
 // writes the cells tags before binary data is appended
 
-template <class CDT>
+  template <class CDT, class InDomainPmap>
 void
 write_cells_tag_2(std::ostream& os,
                   const CDT & tr,
+                  InDomainPmap in_domain,
                   std::size_t number_of_triangles,
                   std::map<typename CDT::Vertex_handle, std::size_t> & V,
                   bool binary,
@@ -73,8 +75,8 @@ write_cells_tag_2(std::ostream& os,
             fit = tr.finite_faces_begin(),
             end = tr.finite_faces_end();
           fit != end; ++fit)
-      {
-      if(fit->is_in_domain())
+    {
+      if(get(in_domain, fit))
       {
         os << V[fit->vertex(0)] << " ";
         os << V[fit->vertex(2)] << " ";
@@ -114,7 +116,7 @@ write_cells_tag_2(std::ostream& os,
         fit != tr.finite_faces_end() ;
         ++fit )
     {
-      if(fit->is_in_domain())
+      if(get(in_domain, fit))
       {
         cells_offset += 3;
         os << cells_offset << " ";
@@ -149,7 +151,7 @@ write_cells_tag_2(std::ostream& os,
         fit != tr.finite_faces_end() ;
         ++fit )
     {
-      if(fit->is_in_domain())
+      if(get(in_domain, fit))
       {
         os << "5 ";
       }
@@ -166,10 +168,11 @@ write_cells_tag_2(std::ostream& os,
 }
 
 // writes the cells appended data at the end of the .vtu file
-template <class CDT>
+  template <class CDT, class InDomainPmap>
 void
 write_cells_2(std::ostream& os,
               const CDT & tr,
+              InDomainPmap in_domain,
               std::size_t number_of_triangles,
               std::map<typename CDT::Vertex_handle, std::size_t> & V)
 {
@@ -185,7 +188,7 @@ write_cells_2(std::ostream& os,
       end = tr.finite_faces_end();
       fit != end; ++fit)
   {
-    if(fit->is_in_domain())
+    if(get(in_domain, fit))
     {
       off += 3;
       offsets.push_back(off);
@@ -324,11 +327,12 @@ write_attributes_2(std::ostream& os,
   write_vector(os,att);
 }
 
-template <class CDT>
+template <class CDT, class InDomainPmap>
 void write_VTU_with_attributes(std::ostream& os,
-               const CDT& tr,
-               std::vector<std::pair<const char*, const std::vector<double>*> >& attributes,
-               Mode mode = BINARY)
+                               const CDT& tr,
+                               InDomainPmap in_domain,
+                               std::vector<std::pair<const char*, const std::vector<double>*> >& attributes,
+                               Mode mode = BINARY)
 {
   typedef typename CDT::Vertex_handle Vertex_handle;
   std::map<Vertex_handle, std::size_t> V;
@@ -355,14 +359,14 @@ void write_VTU_with_attributes(std::ostream& os,
       end = tr.finite_faces_end();
       fit != end; ++fit)
   {
-    if(fit->is_in_domain()) ++number_of_triangles;
+    if(get(in_domain, fit)) ++number_of_triangles;
   }
   os << "  <Piece NumberOfPoints=\"" << tr.number_of_vertices()
      << "\" NumberOfCells=\"" << number_of_triangles + std::distance(tr.constrained_edges_begin(), tr.constrained_edges_end()) << "\">\n";
   std::size_t offset = 0;
   const bool binary = (mode == BINARY);
   write_cdt_points_tag(os,tr,V,binary,offset);
-  write_cells_tag_2(os,tr,number_of_triangles, V,binary,offset);
+  write_cells_tag_2(os,tr, in_domain, number_of_triangles, V,binary,offset);
   if(attributes.empty())
       os << "    <CellData >\n";
   else
@@ -377,7 +381,7 @@ void write_VTU_with_attributes(std::ostream& os,
   if (binary) {
     os << "<AppendedData encoding=\"raw\">\n_";
     write_cdt_points(os,tr,V);  // write points before cells to fill the std::map V
-    write_cells_2(os,tr, number_of_triangles, V);
+    write_cells_2(os, tr, in_domain, number_of_triangles, V);
     for(std::size_t i = 0; i< attributes.size(); ++i)
       write_attributes_2(os, *attributes[i].second);
   }
@@ -386,15 +390,26 @@ void write_VTU_with_attributes(std::ostream& os,
 
 } // namespace internal
 
+template <class CDT, class InDomainPmap>
+void write_VTU(std::ostream& os,
+               const CDT& tr,
+               InDomainPmap ipm,
+               Mode mode = BINARY)
+{
+  std::vector<std::pair<const char*, const std::vector<double>*> > dummy_atts;
+  internal::write_VTU_with_attributes(os, tr, ipm, dummy_atts, mode);
+}
+
 template <class CDT>
 void write_VTU(std::ostream& os,
                const CDT& tr,
                Mode mode = BINARY)
 {
-  std::vector<std::pair<const char*, const std::vector<double>*> > dummy_atts;
-  internal::write_VTU_with_attributes(os, tr, dummy_atts, mode);
+  CGAL::internal::In_domain<CDT> in_domain;
+  write_VTU(os, tr, in_domain, mode);
 }
 
+
 } // namespace IO
 
 #ifndef CGAL_NO_DEPRECATED_CODE
