@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Point_set_processing_3/include/CGAL/IO/write_ply_points.h $
-// $Id: write_ply_points.h d3b13fb 2022-12-05T19:00:39+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Point_set_processing_3/include/CGAL/IO/write_ply_points.h $
+// $Id: include/CGAL/IO/write_ply_points.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Simon Giraudot
@@ -353,12 +353,7 @@ bool write_ply_points(std::ostream& os, ///< output stream.
 
 /// \endcond
 
-/**
-\ingroup PkgPointSetProcessing3IODeprecated
 
-\deprecated This function is deprecated since \cgal 5.3,
-            \link PkgPointSetProcessing3IOPly `CGAL::IO::write_PLY_with_properties()` \endlink should be used instead.
-*/
 template <typename PointRange,
           typename ... PropertyHandler>
 CGAL_DEPRECATED bool write_ply_points_with_properties(std::ostream& os, ///< output stream.
@@ -368,12 +363,7 @@ CGAL_DEPRECATED bool write_ply_points_with_properties(std::ostream& os, ///< out
   return IO::write_PLY_with_properties(os, points, std::forward<PropertyHandler>(properties)...);
 }
 
-/**
-\ingroup PkgPointSetProcessing3IODeprecated
 
-\deprecated This function is deprecated since \cgal 5.3,
-            \link PkgPointSetProcessing3IOPly `CGAL::IO::write_PLY()` \endlink should be used instead.
-*/
 template <typename PointRange, typename CGAL_NP_TEMPLATE_PARAMETERS>
 CGAL_DEPRECATED bool write_ply_points(std::ostream& os, const PointRange& points, const CGAL_NP_CLASS& np = parameters::default_values())
 {
