@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Intersections_2/include/CGAL/Intersection_traits.h $
-// $Id: Intersection_traits.h 3a4e230 2022-11-22T12:22:42+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersection_traits.h $
+// $Id: include/CGAL/Intersection_traits.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,24 +18,24 @@
 #include <CGAL/assertions.h>
 #include <CGAL/Dimension.h>
 
-#include <boost/variant.hpp>
+#include <variant>
 
 #include <type_traits>
 
 #define CGAL_INTERSECTION_TRAITS_2(A, B, R1, R2)                \
   template<typename K>     \
   struct Intersection_traits<K, typename K::A, typename K::B>  { \
-    typedef typename boost::variant<typename K::R1, typename K::R2 >    \
+    typedef typename std::variant<typename K::R1, typename K::R2 >    \
                      variant_type;                                      \
-    typedef typename boost::optional< variant_type > result_type;       \
+    typedef typename std::optional< variant_type > result_type;       \
   };
 
 #define CGAL_INTERSECTION_TRAITS_3(A, B, R1, R2, R3)            \
   template<typename K>     \
   struct Intersection_traits<K, typename K::A, typename K::B>  { \
-    typedef typename boost::variant<typename K::R1, typename K::R2,     \
+    typedef typename std::variant<typename K::R1, typename K::R2,     \
                                     typename K::R3> variant_type;       \
-    typedef typename boost::optional< variant_type > result_type;       \
+    typedef typename std::optional< variant_type > result_type;       \
   };
 
 #define CGAL_INTERSECTION_FUNCTION(A, B, DIM)                           \
@@ -118,16 +118,16 @@ const T* intersect_get(const CGAL::Object& o) {
   return CGAL::object_cast<T>(&o);
 }
 
-template<typename T, BOOST_VARIANT_ENUM_PARAMS(typename U)>
+template<typename T, typename ... U>
 inline
-const T* intersect_get(const boost::optional< boost::variant<BOOST_VARIANT_ENUM_PARAMS(U)> >& v) {
-  return boost::get<T>(&*v);
+const T* intersect_get(const std::optional< std::variant<U...> >& v) {
+  return std::get_if<T>(&*v);
 }
 
-template<typename T, BOOST_VARIANT_ENUM_PARAMS(typename U)>
+template<typename T, typename ... U>
 inline
-const T* intersect_get(const boost::variant<BOOST_VARIANT_ENUM_PARAMS(U)> & v) {
-  return boost::get<T>(&v);
+const T* intersect_get(const std::variant<U...> & v) {
+  return std::get_if<T>(&v);
 }
 
 template<typename A, typename B>
@@ -181,8 +181,8 @@ do_intersect_impl(const A& a, const B& b, Dynamic_dimension_tag) {
 // inline
 // typename Intersection_traits< typename Kernel_traits<A>::Kernel, A, B>::result_type >::type
 // intersection(const A& a, const B& b) {
-//   CGAL_static_assertion_msg( (std::is_same<typename A::Ambient_dimension, typename B::Ambient_dimension>::value),
-//                               "intersection with objects of different dimensions not supported");
+//   static_assert(std::is_same<typename A::Ambient_dimension, typename B::Ambient_dimension>::value),
+//                               "intersection with objects of different dimensions not supported";
 //   return internal::intersection_impl(a, b, typename A::Ambient_dimension());
 // }
 
@@ -190,7 +190,7 @@ do_intersect_impl(const A& a, const B& b, Dynamic_dimension_tag) {
 // inline
 // auto // K::Boolean
 // do_intersect(const A& a, const B& b) {
-//   CGAL_static_assertion_msg((std::is_same<typename A::Ambient_dimension, typename B::Ambient_dimension>::value),
+//   static_assert(std::is_same<typename A::Ambient_dimension, typename B::Ambient_dimension>::value,
 //                         "do_intersect with objects of different dimensions not supported");
 //   return internal::do_intersect_impl(a, b, typename A::Ambient_dimension());
 // }
