@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Intersections_2/include/CGAL/Intersection_traits_2.h $
-// $Id: Intersection_traits_2.h 1491983 2022-01-18T11:36:56+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersection_traits_2.h $
+// $Id: include/CGAL/Intersection_traits_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,8 +16,8 @@
 #include <CGAL/Intersection_traits.h>
 #include <CGAL/Bbox_2.h>
 
-#include <boost/variant.hpp>
-#include <boost/optional.hpp>
+#include <variant>
+#include <optional>
 #include <vector>
 
 namespace CGAL {
@@ -49,9 +49,9 @@ CGAL_INTERSECTION_TRAITS_2(Ray_2, Triangle_2, Point_2, Segment_2)
 template<typename K>
 struct Intersection_traits<K, typename K::Triangle_2, typename K::Triangle_2>  {
   typedef typename
-  boost::variant< typename K::Point_2, typename K::Segment_2,
+  std::variant< typename K::Point_2, typename K::Segment_2,
                   typename K::Triangle_2, typename std::vector< typename K::Point_2 > > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 
@@ -69,37 +69,37 @@ CGAL_INTERSECTION_TRAITS_2(Ray_2, Iso_rectangle_2, Point_2, Segment_2)
 // Variants of one for backwards compatibility
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_rectangle_2, typename K::Iso_rectangle_2>  {
-  typedef typename boost::variant<typename K::Iso_rectangle_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Iso_rectangle_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 
 // Point_2 is special
 template<typename K, typename B>
 struct Intersection_traits<K, typename K::Point_2, B> {
-  typedef typename boost::variant<typename K::Point_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Point_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 template<typename K, typename A>
 struct Intersection_traits<K, A, typename K::Point_2> {
-  typedef typename boost::variant<typename K::Point_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Point_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Point_2, typename K::Point_2> {
-  typedef typename boost::variant<typename K::Point_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Point_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_rectangle_2, typename K::Triangle_2>
 {
-  typedef typename boost::variant<typename K::Segment_2, typename K::Triangle_2,
+  typedef typename std::variant<typename K::Segment_2, typename K::Triangle_2,
                                   typename K::Point_2,
                                   typename std::vector< typename K::Point_2 > > variant_type;
-  typedef typename boost::optional < variant_type > result_type;
+  typedef typename std::optional < variant_type > result_type;
 };
 
 template<typename K>
@@ -118,14 +118,14 @@ struct Intersection_traits<K, A, CGAL::Bbox_2>  {
 
 template<typename K>
 struct Intersection_traits<K, CGAL::Bbox_2, typename K::Point_2>  {
-  typedef typename boost::variant<typename K::Point_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Point_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Point_2, CGAL::Bbox_2>  {
-  typedef typename boost::variant<typename K::Point_2> variant_type;
-  typedef boost::optional<variant_type> result_type;
+  typedef typename std::variant<typename K::Point_2> variant_type;
+  typedef std::optional<variant_type> result_type;
 };
 
 } // namespace CGAL
