@@ -9,8 +9,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Intersections_3/include/CGAL/Intersection_traits_3.h $
-// $Id: Intersection_traits_3.h 1491983 2022-01-18T11:36:56+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_3/include/CGAL/Intersection_traits_3.h $
+// $Id: include/CGAL/Intersection_traits_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -22,8 +22,8 @@
 #include <CGAL/Intersection_traits.h>
 #include <CGAL/Bbox_3.h>
 
-#include <boost/optional.hpp>
-#include <boost/variant.hpp>
+#include <optional>
+#include <variant>
 
 #include <vector>
 
@@ -84,9 +84,9 @@ CGAL_INTERSECTION_TRAITS_3(Sphere_3, Sphere_3, Point_3, Circle_3, Sphere_3)
 template<typename K>
 struct Intersection_traits<K, typename K::Triangle_3, typename K::Triangle_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3, typename K::Triangle_3,
+  std::variant< typename K::Point_3, typename K::Segment_3, typename K::Triangle_3,
                   typename std::vector< typename K::Point_3 > > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 
@@ -108,8 +108,8 @@ CGAL_INTERSECTION_TRAITS_2(Iso_cuboid_3, Ray_3, Point_3, Segment_3)
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_cuboid_3, typename K::Iso_cuboid_3>  {
   typedef typename
-  boost::variant< typename K::Iso_cuboid_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Iso_cuboid_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 
@@ -118,8 +118,8 @@ struct Intersection_traits<K, typename K::Iso_cuboid_3, typename K::Iso_cuboid_3
 template<typename K>
 struct Intersection_traits<K, CGAL::Bbox_3, typename K::Line_3>  {
   typedef typename
-  boost::variant< typename K::Segment_3, typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Segment_3, typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
@@ -148,23 +148,23 @@ struct Intersection_traits<K, CGAL::Bbox_3, typename K::Ray_3> :
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Iso_cuboid_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Bbox_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, Bbox_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
   template<typename K>
 struct Intersection_traits<K, typename K::Point_3, Bbox_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 
@@ -172,8 +172,8 @@ struct Intersection_traits<K, typename K::Point_3, Bbox_3>  {
 template<typename K>
 struct Intersection_traits<K, CGAL::Bbox_3, typename K::Iso_cuboid_3>  {
   typedef typename
-  boost::variant<  typename K::Iso_cuboid_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant<  typename K::Iso_cuboid_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
@@ -184,204 +184,204 @@ struct Intersection_traits<K, typename K::Iso_cuboid_3, CGAL::Bbox_3>
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_cuboid_3, typename K::Point_3>  {
   typedef typename
-    boost::variant< typename K::Point_3 > variant_type;
-    typedef typename boost::optional< variant_type > result_type;
+    std::variant< typename K::Point_3 > variant_type;
+    typedef typename std::optional< variant_type > result_type;
 };
 
 // Iso_cuboid_3 Plane_3, variant of 4
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_cuboid_3, typename K::Plane_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Plane_3, typename K::Iso_cuboid_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Iso_cuboid_3 Triangle_3, variant of 4
 template<typename K>
 struct Intersection_traits<K, typename K::Iso_cuboid_3, typename K::Triangle_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Triangle_3, typename K::Iso_cuboid_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Bbox_3 Plane_3, variant of 4
 template<typename K>
 struct Intersection_traits<K, typename CGAL::Bbox_3, typename K::Plane_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Plane_3, typename CGAL::Bbox_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Bbox_3 Triangle_3, variant of 4
 template<typename K>
 struct Intersection_traits<K, typename CGAL::Bbox_3, typename K::Triangle_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 template<typename K>
 struct Intersection_traits<K, typename K::Triangle_3, typename CGAL::Bbox_3>  {
   typedef typename
-  boost::variant< typename K::Point_3, typename K::Segment_3,
+  std::variant< typename K::Point_3, typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
 
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Line_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Line_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Line_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Line_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Ray_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Ray_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Ray_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Ray_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Segment_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Segment_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Segment_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Segment_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Plane_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Plane_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Plane_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Plane_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Triangle_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Triangle_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Triangle_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Triangle_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Tetrahedron_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Tetrahedron_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Tetrahedron_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Tetrahedron_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Point_3 Sphere_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Point_3, typename K::Sphere_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Sphere_3 Point_3, variant of one
 template<typename K>
 struct Intersection_traits<K, typename K::Sphere_3, typename K::Point_3>  {
   typedef typename
-  boost::variant< typename K::Point_3 > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  std::variant< typename K::Point_3 > variant_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 //Tetrahedron_3 Plane_3, variant of 4
@@ -389,9 +389,9 @@ template<class K>
 struct Intersection_traits<K, typename K::Tetrahedron_3, typename K::Plane_3>
 {
   typedef typename
-  boost::variant< typename K::Point_3 , typename K::Segment_3,
+  std::variant< typename K::Point_3 , typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 //Plane_3 Tetrahedron_3, variant of 4
@@ -399,9 +399,9 @@ template<class K>
 struct Intersection_traits<K, typename K::Plane_3,typename K::Tetrahedron_3>
 {
   typedef typename
-  boost::variant< typename K::Point_3 , typename K::Segment_3,
+  std::variant< typename K::Point_3 , typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 //Triangle_3 Tetrahedron_3, variant of 4
@@ -409,9 +409,9 @@ template<class K>
 struct Intersection_traits<K, typename K::Triangle_3,typename K::Tetrahedron_3>
 {
   typedef typename
-  boost::variant< typename K::Point_3 , typename K::Segment_3,
+  std::variant< typename K::Point_3 , typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 // Tetrahedron_3 Triangle_3, variant of 4
@@ -419,9 +419,9 @@ template<class K>
 struct Intersection_traits<K, typename K::Tetrahedron_3,typename K::Triangle_3>
 {
   typedef typename
-  boost::variant< typename K::Point_3 , typename K::Segment_3,
+  std::variant< typename K::Point_3 , typename K::Segment_3,
                   typename K::Triangle_3, std::vector<typename K::Point_3> > variant_type;
-  typedef typename boost::optional< variant_type > result_type;
+  typedef typename std::optional< variant_type > result_type;
 };
 
 
