@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Intersections_2/include/CGAL/Intersections_2/Circle_2_Circle_2.h $
-// $Id: Circle_2_Circle_2.h 7e62c02 2021-04-12T14:02:37+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersections_2/Circle_2_Circle_2.h $
+// $Id: include/CGAL/Intersections_2/Circle_2_Circle_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,9 +27,9 @@ namespace Intersections {
 namespace internal {
 
 template <class K>
-bool do_intersect(const typename K::Circle_2 & circ1,
-                  const typename K::Circle_2& circ2,
-                  const K&)
+typename K::Boolean do_intersect(const typename K::Circle_2& circ1,
+                                 const typename K::Circle_2& circ2,
+                                 const K&)
 {
   typedef typename K::FT FT;
 
