@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Intersections_2/include/CGAL/Intersections_2/Line_2_Line_2.h $
-// $Id: Line_2_Line_2.h 9b19c5f 2021-09-23T15:11:18+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersections_2/Line_2_Line_2.h $
+// $Id: include/CGAL/Intersections_2/Line_2_Line_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -52,17 +52,18 @@ protected:
     mutable typename K::Point_2         _intersection_point;
 };
 
-template <class K>
-inline bool do_intersect(
-    const typename K::Line_2 &p1,
-    const typename K::Line_2 &p2,
-    const K&)
-{
-    typedef Line_2_Line_2_pair<K> pair_t;
-    pair_t pair(&p1, &p2);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
-}
 
+template <class K>
+inline
+typename K::Boolean
+do_intersect(const typename K::Line_2& l1,
+             const typename K::Line_2& l2,
+             const K&)
+{
+  typedef Line_2_Line_2_pair<K> pair_t;
+  pair_t pair(&l1, &l2);
+  return pair.intersection_type() != pair_t::NO_INTERSECTION;
+}
 
 
 template <class K>
@@ -200,7 +201,6 @@ Line_2_Line_2_pair<K>::intersection_line() const
 CGAL_INTERSECTION_FUNCTION_SELF(Line_2, 2)
 CGAL_DO_INTERSECT_FUNCTION_SELF(Line_2, 2)
 
+} // namespace CGAL
 
-} //namespace CGAL
-
-#endif
+#endif // CGAL_INTERSECTIONS_2_LINE_2_LINE_2_H
