@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Intersections_2/include/CGAL/Intersections_2/Line_2_Ray_2.h $
-// $Id: Line_2_Ray_2.h 9b19c5f 2021-09-23T15:11:18+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersections_2/Line_2_Ray_2.h $
+// $Id: include/CGAL/Intersections_2/Line_2_Ray_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -55,17 +55,26 @@ protected:
 };
 
 template <class K>
-inline bool do_intersect(
-    const typename K::Ray_2 &p1,
-    const typename K::Line_2 &p2,
-    const K&)
+inline
+typename K::Boolean
+do_intersect(const typename K::Ray_2& r,
+             const typename K::Line_2& l,
+             const K&)
 {
-    typedef Ray_2_Line_2_pair<K> pair_t;
-    pair_t pair(&p1, &p2);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
+  typedef Ray_2_Line_2_pair<K> pair_t;
+  pair_t pair(&r, &l);
+  return pair.intersection_type() != pair_t::NO_INTERSECTION;
 }
 
-
+template <class K>
+inline
+typename K::Boolean
+do_intersect(const typename K::Line_2& l,
+             const typename K::Ray_2& r,
+             const K& k)
+{
+  return do_intersect(r, l, k);
+}
 
 template <class K>
 typename Intersection_traits
@@ -99,20 +108,6 @@ intersection(const typename K::Line_2 &line,
     return internal::intersection(ray, line, k);
 }
 
-
-template <class K>
-inline bool do_intersect(
-    const typename K::Line_2 &p1,
-    const typename K::Ray_2 &p2,
-    const K&)
-{
-    typedef Ray_2_Line_2_pair<K> pair_t;
-    pair_t pair(&p2, &p1);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
-}
-
-
-
 template <class K>
 typename Ray_2_Line_2_pair<K>::Intersection_results
 Ray_2_Line_2_pair<K>::intersection_type() const
