@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Intersections_2/include/CGAL/Intersections_2/Ray_2_Triangle_2.h $
-// $Id: Ray_2_Triangle_2.h fb37f69 2021-09-23T13:15:28+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Intersections_2/include/CGAL/Intersections_2/Ray_2_Triangle_2.h $
+// $Id: include/CGAL/Intersections_2/Ray_2_Triangle_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -165,26 +165,26 @@ intersection(const typename K::Triangle_2&tr,
 
 
 template <class K>
-inline bool do_intersect(
-    const typename K::Ray_2 &p1,
-    const typename K::Triangle_2 &p2,
-    const K&)
+inline
+typename K::Boolean
+do_intersect(const typename K::Ray_2& r,
+             const typename K::Triangle_2& tr,
+             const K&)
 {
-    typedef Ray_2_Triangle_2_pair<K> pair_t;
-    pair_t pair(&p1, &p2);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
+  typedef Ray_2_Triangle_2_pair<K> pair_t;
+  pair_t pair(&r, &tr);
+  return pair.intersection_type() != pair_t::NO_INTERSECTION;
 }
 
 
 template <class K>
-inline bool do_intersect(
-    const typename K::Triangle_2 &p1,
-    const typename K::Ray_2 &p2,
-    const K&)
+inline
+typename K::Boolean
+do_intersect(const typename K::Triangle_2& tr,
+             const typename K::Ray_2& r,
+             const K& k)
 {
-    typedef Ray_2_Triangle_2_pair<K> pair_t;
-    pair_t pair(&p2, &p1);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
+  return do_intersect(r, tr, k);
 }
 
 } // namespace internal
@@ -193,7 +193,6 @@ inline bool do_intersect(
 CGAL_INTERSECTION_FUNCTION(Ray_2, Triangle_2, 2)
 CGAL_DO_INTERSECT_FUNCTION(Ray_2, Triangle_2, 2)
 
+} // namespace CGAL
 
-} //namespace CGAL
-
-#endif
+#endif // CGAL_INTERSECTIONS_2_RAY_2_TRIANGLE_2_H
