@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_23/include/CGAL/Iso_cuboid_3.h $
-// $Id: Iso_cuboid_3.h 39e6369 2023-05-12T10:32:54+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Iso_cuboid_3.h $
+// $Id: include/CGAL/Iso_cuboid_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -35,7 +35,7 @@ class Iso_cuboid_3 : public R_::Kernel_base::Iso_cuboid_3
   typedef typename R_::Aff_transformation_3  Aff_transformation_3;
 
   typedef Iso_cuboid_3                    Self;
-  CGAL_static_assertion((std::is_same<Self, typename R_::Iso_cuboid_3>::value));
+  static_assert(std::is_same<Self, typename R_::Iso_cuboid_3>::value);
 
 public:
 
