@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_23/include/CGAL/Kernel/Type_mapper.h $
-// $Id: Type_mapper.h 3127190 2020-12-08T12:48:04+01:00 Dmitry Anisimov
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Kernel/Type_mapper.h $
+// $Id: include/CGAL/Kernel/Type_mapper.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,14 +21,11 @@
 
 #include <vector>
 
-#include <boost/type_traits/remove_cv.hpp>
-#include <boost/type_traits/remove_reference.hpp>
-
 #include <boost/mpl/transform.hpp>
 #include <boost/mpl/remove.hpp>
 
-#include <boost/optional.hpp>
-#include <boost/variant.hpp>
+#include <optional>
+#include <variant>
 
 #include <boost/preprocessor/facilities/expand.hpp>
 #include <boost/preprocessor/repetition/repeat_from_to.hpp>
@@ -54,8 +51,8 @@ struct Type_mapper_impl<std::vector< T >, K1, K2 > {
 };
 
 template < typename T, typename K1, typename K2 >
-struct Type_mapper_impl<boost::optional<T>, K1, K2 > {
-  typedef boost::optional< typename Type_mapper_impl<T, K1, K2>::type > type;
+struct Type_mapper_impl<std::optional<T>, K1, K2 > {
+  typedef std::optional< typename Type_mapper_impl<T, K1, K2>::type > type;
 };
 
 
@@ -66,9 +63,9 @@ struct Type_mapper_impl<boost::optional<T>, K1, K2 > {
 
 #define CGAL_VARIANT_TYPEMAP(z, n, d) \
 template< typename K1, typename K2, BOOST_PP_ENUM_PARAMS(n, class T) >            \
-struct Type_mapper_impl<boost::variant<BOOST_PP_ENUM_PARAMS(n, T)>, K1, K2> {                    \
+struct Type_mapper_impl<std::variant<BOOST_PP_ENUM_PARAMS(n, T)>, K1, K2> {                    \
   BOOST_PP_REPEAT(n, CGAL_TYPEMAP_TYPEDEFS, T)                            \
-  typedef boost::variant<BOOST_PP_ENUM_PARAMS(n, A)> type; \
+  typedef std::variant<BOOST_PP_ENUM_PARAMS(n, A)> type; \
 };
 
 BOOST_PP_REPEAT_FROM_TO(1, 10, CGAL_VARIANT_TYPEMAP, _)
@@ -76,16 +73,6 @@ BOOST_PP_REPEAT_FROM_TO(1, 10, CGAL_VARIANT_TYPEMAP, _)
 #undef CGAL_TYPEMAP_TYPEDEFS
 #undef CGAL_VARIANT_TYPEMAP
 
-// CODE_TAG
-//template<typename K1, typename K2, BOOST_VARIANT_ENUM_PARAMS(typename U) >
-//struct Type_mapper_impl<boost::variant<BOOST_VARIANT_ENUM_PARAMS(U)>, K1, K2 > {
-//  typedef typename boost::make_variant_over<
-//    typename boost::mpl::transform<
-//      typename boost::variant<BOOST_VARIANT_ENUM_PARAMS(U)>::types,
-//      Type_mapper_impl<boost::mpl::_1, K1, K2> >::type
-//    >::type type;
-//};
-
 // Then we specialize for all kernel objects.
 // More details on why it is like that are here: https://github.com/CGAL/cgal/pull/4878#discussion_r459986501
 #define CGAL_Kernel_obj(X) \
@@ -111,9 +98,9 @@ struct Type_mapper_impl < typename K1::FT, K1, K2 >
 
 template < typename T, typename K1, typename K2 >
 struct Type_mapper :
-    internal::Type_mapper_impl< typename boost::remove_cv<
-                                  typename boost::remove_reference < T >::type
-                                  >::type, K1, K2 >
+    internal::Type_mapper_impl< std::remove_cv_t<
+                                  std::remove_reference_t< T >
+                                  >, K1, K2 >
 { };
 
 } //namespace CGAL
