@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4/Kernel_d/include/CGAL/Kernel_d/Line_d.h $
-// $Id: Line_d.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_d/include/CGAL/Kernel_d/Line_d.h $
+// $Id: include/CGAL/Kernel_d/Line_d.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -44,7 +44,7 @@ class Line_d : public Handle_for< Pair_d<p_R> > {
 
 /*{\Mdefinition
 An instance of data type |Line_d| is an oriented line in
-$d$-dimensional Euclidian space.}*/
+$d$-dimensional Euclidean space.}*/
 
 public:
 
