@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Mesh_3/include/CGAL/Mesh_3/Mesher_level.h $
-// $Id: Mesher_level.h 5439dbd 2021-08-24T18:04:50+02:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/Mesher_level.h $
+// $Id: include/CGAL/Mesh_3/Mesher_level.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -120,7 +120,7 @@ template <
   class Element, /**< Type of elements that this level refines. */
   class Previous, /* = Null_mesher_level, */
   /**< Previous level type, defaults to
-     \c Null_mesher_level. */
+     `Null_mesher_level`. */
   class Triangulation_traits /** Traits class that defines types for the
          triangulation. */
 >
@@ -175,7 +175,7 @@ protected:
     return derived().debug_info_element_impl(e);
   }
 
-  /** \name Private member datas */
+  /** \name Private member data */
 
   Previous_level& previous_level; /**< The previous level of the refinement
                                     process. */
@@ -198,7 +198,7 @@ public:
   {
   }
 
-  /** \name FUNCTIONS IMPLEMENTED IN THE CLASS \c Derived */
+  /** \name FUNCTIONS IMPLEMENTED IN THE CLASS `Derived` */
 
   /**  Access to the triangulation */
   Triangulation& triangulation()
@@ -248,7 +248,7 @@ public:
     return derived().number_of_bad_elements_impl();
   }
 
-  /** Tells if, as regards the elements of type \c Element, the refinement is
+  /** Tells if, as regards the elements of type `Element`, the refinement is
       done. */
   bool no_longer_element_to_refine()
   {
@@ -292,13 +292,13 @@ public:
                                         visitor.previous_level());
   }
 
-  /** Gives the point that should be inserted to refine the element \c e */
+  /** Gives the point that should be inserted to refine the element `e` */
   Bare_point refinement_point(const Element& e)
   {
     return derived().refinement_point_impl(e);
   }
 
-  /** Actions before testing conflicts for point \c p and element \c e */
+  /** Actions before testing conflicts for point `p` and element `e` */
   template <typename Mesh_visitor>
   void before_conflicts(const Element& e, const Point& p,
       Mesh_visitor visitor)
@@ -311,7 +311,7 @@ public:
       point conflicts with something, and do what is needed. The return
       type is made of two booleans:
         - the first one tells if the point can be inserted,
-        - in case of, the first one is \c false, the second one tells if
+        - in case of, the first one is `false`, the second one tells if
         the tested element should be reconsidered latter.
   */
   Mesher_level_conflict_status private_test_point_conflict(const Point& p,
@@ -321,8 +321,8 @@ public:
   }
 
   /**
-   * Actions before inserting the point \c p in order to refine the
-   * element \c e. The zone of conflicts is \c zone.
+   * Actions before inserting the point `p` in order to refine the
+   * element `e`. The zone of conflicts is `zone`.
    */
   template <class Mesh_visitor>
   void before_insertion(Element& e, const Point& p, Zone& zone,
@@ -343,7 +343,7 @@ public:
     visitor.after_insertion(vh);
   }
 
-  /** Actions after testing conflicts for point \c p and element \c e
+  /** Actions after testing conflicts for point `p` and element `e`
    *  if no point is inserted. */
   template <class Mesh_visitor>
   void after_no_insertion(const Element& e, const Point& p, Zone& zone,
@@ -361,7 +361,7 @@ public:
    */
 
   /**
-   * Tells it the algorithm is done, regarding elements of type \c Element
+   * Tells it the algorithm is done, regarding elements of type `Element`
    * or elements of previous levels.
    */
   bool is_algorithm_done()
@@ -383,7 +383,7 @@ public:
 
   /**
    * This function takes one element from the queue, and try to refine
-   * it. It returns \c true if one point has been inserted.
+   * it. It returns `true` if one point has been inserted.
    * @todo Merge with try_to_refine_element().
    */
   template <class Mesh_visitor>
@@ -426,7 +426,7 @@ public:
   /** \name STEP BY STEP FUNCTIONS */
 
   /**
-   * Inserts exactly one point, if possible, and returns \c false if no
+   * Inserts exactly one point, if possible, and returns `false` if no
    * point has been inserted because the algorithm is done.
    */
   template <class Mesh_visitor>
@@ -457,7 +457,7 @@ template <
   class Element, /**< Type of elements that this level refines. */
   class Previous, /* = Null_mesher_level, */
   /**< Previous level type, defaults to
-     \c Null_mesher_level. */
+     `Null_mesher_level`. */
   class Triangulation_traits, /** Traits class that defines types for the
          triangulation. */
   typename Concurrency_tag>
@@ -519,8 +519,8 @@ public:
       point conflicts with something, and do what is needed. The return
       type is made of two booleans:
         - the first one tells if the point can be inserted,
-        - in case of, the first one is \c false, the second one tells if
-        the tested element should be reconsidered latter.
+        - in case of, the first one is `false`, the second one tells if
+        the tested element should be reconsidered later.
       This function is called by the superior level, if any.
   */
   Mesher_level_conflict_status
@@ -648,7 +648,7 @@ public:
 
   /**
    * Applies one step of the algorithm: tries to refine one element of
-   * previous level or one element of this level. Return \c false iff
+   * previous level or one element of this level. Return `false` iff
    * <tt> is_algorithm_done()==true </tt>.
    */
   template <class Mesh_visitor>
@@ -681,7 +681,7 @@ template <
   class Element, /**< Type of elements that this level refines. */
   class Previous, /* = Null_mesher_level, */
   /**< Previous level type, defaults to
-     \c Null_mesher_level. */
+     `Null_mesher_level`. */
   class Triangulation_traits> /** Traits class that defines types for the
                                   triangulation. */
 class Mesher_level<Tr, Derived, Element, Previous,
@@ -804,8 +804,8 @@ public:
       point conflicts with something, and do what is needed. The return
       type is made of two booleans:
         - the first one tells if the point can be inserted,
-        - in case of, the first one is \c false, the second one tells if
-        the tested element should be reconsidered latter.
+        - in case of, the first one is `false`, the second one tells if
+        the tested element should be reconsidered later.
       This function is called by the superior level, if any.
   */
   template <class Mesh_visitor>
@@ -1109,7 +1109,7 @@ public:
 
   /**
    * Applies one step of the algorithm: tries to refine one element of
-   * previous level or one element of this level. Return \c false iff
+   * previous level or one element of this level. Return `false` iff
    * <tt> is_algorithm_done()==true </tt>.
    * Note that when parallelism is activated, this is not "one step"
    * but the full refinement.
