@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Mesh_3/include/CGAL/Mesh_3/polylines_to_protect.h $
-// $Id: polylines_to_protect.h 74540b0 2022-04-26T15:32:02+02:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Mesh_3/include/CGAL/Mesh_3/polylines_to_protect.h $
+// $Id: include/CGAL/Mesh_3/polylines_to_protect.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -15,7 +15,6 @@
 
 #include <CGAL/license/Mesh_3.h>
 
-
 #include <vector>
 #include <map>
 #include <utility> // std::swap
@@ -23,17 +22,21 @@
 
 #include <CGAL/tuple.h>
 #include <CGAL/Image_3.h>
+#include <CGAL/number_utils.h>
+#include <CGAL/squared_distance_3.h>
+
 #include <CGAL/boost/graph/split_graph_into_polylines.h>
 #include <CGAL/Mesh_3/internal/Graph_manipulations.h>
 #include <boost/graph/adjacency_list.hpp>
-#include <CGAL/Labeled_mesh_domain_3.h> // for CGAL::Null_subdomain_index
-#include <CGAL/number_utils.h>
-#include <boost/utility.hpp> // for boost::prior
-#include <boost/optional.hpp>
 
 #include <CGAL/Search_traits_3.h>
 #include <CGAL/Orthogonal_incremental_neighbor_search.h>
 
+#include <CGAL/Mesh_3/Null_subdomain_index.h>
+
+#include <type_traits>
+#include <optional>
+
 namespace CGAL {
 namespace Mesh_3 {
 namespace internal {
@@ -382,8 +385,8 @@ void snap_graph_vertices(Graph& graph,
   {
     if(poly_it->begin() != poly_it->end()) {
       tree.insert(*poly_it->begin());
-      if(boost::next(poly_it->begin()) != poly_it->end()) {
-        tree.insert(*boost::prior(poly_it->end()));
+      if(std::next(poly_it->begin()) != poly_it->end()) {
+        tree.insert(*std::prev(poly_it->end()));
       }
     }
   }
@@ -447,7 +450,7 @@ polylines_to_protect
  InterpolationFunctor interpolate,
  PolylineInputIterator existing_polylines_begin,
  PolylineInputIterator existing_polylines_end,
- boost::optional<Image_word_type> scalar_interpolation_value = boost::none,
+ std::optional<Image_word_type> scalar_interpolation_value = std::nullopt,
  int prec = 10)
 {
   typedef typename DomainFunctor::result_type Domain_type;
@@ -582,12 +585,13 @@ polylines_to_protect
                  pixel[1],
                  pixel[2]);
               square[ii][jj].domain = domain_fct(square[ii][jj].word);
-              if(scalar_interpolation_value != boost::none) {
+              if(scalar_interpolation_value != std::nullopt) {
                 square[ii][jj].word =
                   Image_word_type(square[ii][jj].word -
                                   (*scalar_interpolation_value));
               }
               ++pixel_values_set[square[ii][jj].domain];
+
             }
           }
 
@@ -730,7 +734,7 @@ case_1_2_1:
                                                        square[1][0], null);
 
               Isoline_equation equation =
-                (scalar_interpolation_value == boost::none) ?
+                (scalar_interpolation_value == std::nullopt) ?
                 Isoline_equation(1, -1, -1, 0) :
                 Isoline_equation(v00, v10, v01, v11);
               insert_curve_in_graph.insert_curve(equation,
@@ -740,7 +744,7 @@ case_1_2_1:
                                                  p00,
                                                  p10 - p00,
                                                  p01 - p00);
-              if(scalar_interpolation_value == boost::none) {
+              if(scalar_interpolation_value == std::nullopt) {
                 equation = Isoline_equation(0, -1, -1, 1);
               }
               insert_curve_in_graph.insert_curve(equation,
@@ -867,7 +871,7 @@ case_1_2_1:
                                                          square[1][1], null);
                 vertex_descriptor bottom = g_manip.split(square[0][0],
                                                          square[1][0], null);
-                if(scalar_interpolation_value == boost::none) {
+                if(scalar_interpolation_value == std::nullopt) {
                   g_manip.try_add_edge(top, bottom);
                 } else {
                   insert_curve_in_graph.insert_curve(Isoline_equation(v00, v10,
@@ -886,7 +890,7 @@ case_1_2_1:
                 CGAL_assertion(square[1][0].domain==square[0][1].domain);
                 CGAL_assertion(square[0][0].domain!=square[0][1].domain);
 
-                if(scalar_interpolation_value != boost::none) {
+                if(scalar_interpolation_value != std::nullopt) {
                   // Compute the squared distance between the two branches of
                   // the hyperbola.
                   const double discrimant = double(v00) * v11 - double(v01) * v10;
@@ -959,7 +963,7 @@ case_1_2_1:
                                                        square[1][1], null);
 
               Isoline_equation equation =
-                (scalar_interpolation_value == boost::none) ?
+                (scalar_interpolation_value == std::nullopt) ?
                 Isoline_equation(1, -1, 1, 1) :
                 Isoline_equation(v00, v10, v01, v11);
 
@@ -1038,15 +1042,15 @@ polylines_to_protect(std::vector<std::vector<P> >& polylines,
   for (PolylineInputIterator poly_it = existing_polylines_begin;
        poly_it != existing_polylines_end; ++poly_it)
   {
-    Polyline polyline = *poly_it;
+    const Polyline& polyline = *poly_it;
     if (polyline.size() < 2)
       continue;
 
-    typename Polyline::iterator pit = polyline.begin();
-    while (boost::next(pit) != polyline.end())
+    typename Polyline::const_iterator pit = polyline.begin();
+    while (std::next(pit) != polyline.end())
     {
       vertex_descriptor v = g_manip.get_vertex(*pit, false);
-      vertex_descriptor w = g_manip.get_vertex(*boost::next(pit), false);
+      vertex_descriptor w = g_manip.get_vertex(*std::next(pit), false);
       g_manip.try_add_edge(v, w);
       ++pit;
     }
@@ -1128,6 +1132,79 @@ polylines_to_protect(const CGAL::Image_3& cgal_image,
      existing_polylines_end);
 }
 
+template <typename P,
+          typename Image_word_type,
+          typename PolylineInputIterator>
+void
+polylines_to_protect_on_bbox(const CGAL::Image_3& cgal_image,
+                     std::vector<std::vector<P> >& polylines,
+                     PolylineInputIterator existing_polylines_begin,
+                     PolylineInputIterator existing_polylines_end)
+{
+  polylines_to_protect<P, Image_word_type>(cgal_image,
+                                           polylines,
+                                           existing_polylines_begin,
+                                           existing_polylines_end);
+}
+
+
+
+template <typename PolylineRange1, typename PolylineRange2>
+void
+merge_and_snap_polylines(const CGAL::Image_3& image,
+                         PolylineRange1& polylines_to_snap,
+                         const PolylineRange2& existing_polylines)
+{
+  static_assert(std::is_same<typename PolylineRange1::value_type::value_type,
+                             typename PolylineRange2::value_type::value_type>::value,
+                "Polyline ranges should have same point type");
+  using P = typename PolylineRange1::value_type::value_type;
+  using K = typename Kernel_traits<P>::Kernel;
+
+  using CGAL::internal::polylines_to_protect_namespace::Vertex_info;
+  using Graph = boost::adjacency_list<boost::setS, boost::vecS, boost::undirectedS,
+                                      Vertex_info<P> >;
+  using vertex_descriptor = typename boost::graph_traits<Graph>::vertex_descriptor;
+
+  // build graph of polylines_to_snap
+  Graph graph;
+  typedef Mesh_3::internal::Returns_midpoint<K, int> Midpoint_fct;
+  Mesh_3::internal::Graph_manipulations<Graph,
+    P,
+    int,
+    Midpoint_fct> g_manip(graph);
+
+  for (const auto& polyline : polylines_to_snap)
+  {
+    if (polyline.size() < 2)
+      continue;
+
+    auto pit = polyline.begin();
+    while (std::next(pit) != polyline.end())
+    {
+      vertex_descriptor v = g_manip.get_vertex(*pit, false);
+      vertex_descriptor w = g_manip.get_vertex(*std::next(pit), false);
+      g_manip.try_add_edge(v, w);
+      ++pit;
+    }
+  }
+
+  // snap graph to existing_polylines
+  snap_graph_vertices(graph,
+    image.vx(), image.vy(), image.vz(),
+    std::begin(existing_polylines), std::end(existing_polylines),
+    K());
+
+  // rebuild polylines_to_snap
+  polylines_to_snap.clear();
+  Mesh_3::Polyline_visitor<P, Graph> visitor(polylines_to_snap, graph);
+  Less_for_Graph_vertex_descriptors<Graph> less(graph);
+  const Graph& const_graph = graph;
+  Mesh_3::Angle_tester<K> angle_tester(90.);
+  split_graph_into_polylines(const_graph, visitor, angle_tester, less);
+}
+
+
 } // namespace CGAL
 
 #endif // CGAL_MESH_3_POLYLINES_TO_PROTECT_H
