@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/STL_Extension/include/CGAL/Named_function_parameters.h $
-// $Id: Named_function_parameters.h da39109 2023-02-27T09:55:49+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/Named_function_parameters.h $
+// $Id: include/CGAL/Named_function_parameters.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,7 +19,6 @@
 #include <CGAL/tags.h>
 #include <CGAL/STL_Extension/internal/mesh_option_classes.h>
 
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/has_xxx.hpp>
 
 #include <type_traits>
@@ -143,14 +142,14 @@ struct Lookup_named_param_def
   typedef typename internal_np::Get_param<typename NP::base, Query_tag>::type NP_type;
   typedef typename internal_np::Get_param<typename NP::base, Query_tag>::reference NP_reference;
 
-  typedef typename boost::mpl::if_<
-    std::is_same<NP_type, internal_np::Param_not_found>,
-    D, NP_type>::type
+  typedef std::conditional_t<
+    std::is_same_v<NP_type, internal_np::Param_not_found>,
+    D, NP_type>
   type;
 
-  typedef typename boost::mpl::if_<
-    std::is_same<NP_reference, internal_np::Param_not_found>,
-    D&, NP_reference>::type
+  typedef std::conditional_t<
+    std::is_same_v<NP_reference, internal_np::Param_not_found>,
+    D&, NP_reference>
   reference;
 };
 
@@ -182,7 +181,7 @@ typename Get_param<Named_params_impl<T, Tag, Base>, Query_tag>::type
 get_parameter_impl(const Named_params_impl<T, Tag, Base>& np, Query_tag tag)
 {
 #ifndef CGAL_NO_STATIC_ASSERTION_TEST
-  CGAL_static_assertion( (!std::is_same<Query_tag, Tag>::value) );
+  static_assert(!std::is_same<Query_tag, Tag>::value);
 #endif
   return get_parameter_impl(static_cast<const typename Base::base&>(np), tag);
 }
@@ -243,7 +242,7 @@ template <typename T, typename Tag, typename Base, typename Query_tag>
 typename Get_param<Named_params_impl<T, Tag, Base>, Query_tag>::reference
 get_parameter_reference_impl(const Named_params_impl<T, Tag, Base>& np, Query_tag tag)
 {
-  CGAL_static_assertion( (!std::is_same<Query_tag, Tag>::value) );
+  static_assert(!std::is_same<Query_tag, Tag>::value);
   return get_parameter_reference_impl(static_cast<const typename Base::base&>(np), tag);
 }
 
@@ -569,7 +568,7 @@ namespace boost
   template <typename T, typename Tag, typename Base, typename Tag2, bool B = false>
   void get_param(CGAL::Named_function_parameters<T,Tag,Base>, Tag2)
   {
-    CGAL_static_assertion(B && "You must use CGAL::parameters::get_parameter instead of boost::get_param");
+    static_assert(B && "You must use CGAL::parameters::get_parameter instead of boost::get_param");
   }
 }
 #endif
@@ -577,6 +576,6 @@ namespace boost
 // For disambiguation using SFINAE
 BOOST_MPL_HAS_XXX_TRAIT_DEF(CGAL_Named_function_parameters_class)
 template<class T>
-CGAL_CPP17_INLINE constexpr bool is_named_function_parameter = has_CGAL_Named_function_parameters_class<T>::value;
+inline constexpr bool is_named_function_parameter = has_CGAL_Named_function_parameters_class<T>::value;
 
 #endif // CGAL_BOOST_FUNCTION_PARAMS_HPP
