@@ -3,9 +3,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Nef_S2/include/CGAL/Nef_S2/OGL_base_object.h $
-// $Id: OGL_base_object.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Nef_S2/include/CGAL/Nef_S2/OGL_base_object.h $
+// $Id: include/CGAL/Nef_S2/OGL_base_object.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Peter Hachenberger  <hachenberger@mpi-sb.mpg.de>
@@ -13,6 +13,9 @@
 #ifndef CGAL_OGL_BASE_OBJECT_H
 #define CGAL_OGL_BASE_OBJECT_H
 
+#include <CGAL/license/Nef_S2.h>
+
+
 #include <CGAL/Simple_cartesian.h>
 
 namespace CGAL {
