@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_LA_functors.h $
-// $Id: Cartesian_LA_functors.h 2d8f804 2021-02-15T21:06:12+01:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/NewKernel_d/include/CGAL/NewKernel_d/Cartesian_LA_functors.h $
+// $Id: include/CGAL/NewKernel_d/Cartesian_LA_functors.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -13,7 +13,7 @@
 #define CGAL_CARTESIAN_LA_FUNCTORS_H
 
 #include <CGAL/NewKernel_d/utils.h>
-#include <CGAL/is_iterator.h>
+#include <CGAL/type_traits/is_iterator.h>
 #include <CGAL/argument_swaps.h>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/transforming_iterator.h>
@@ -57,28 +57,28 @@ template<class R_,class Zero_> struct Construct_LA_vector
                 return std::move(v);
         }
         template<class...U>
-        typename std::enable_if<Constructible_from_each<RT,U...>::value &&
+        std::enable_if_t<Constructible_from_each<RT,U...>::value &&
                 std::is_same<Dimension_tag<int(sizeof...(U))>, Dimension>::value,
-          result_type>::type
+          result_type>
         operator()(U&&...u)const{
                 return typename Constructor::Values()(std::forward<U>(u)...);
         }
-        //template<class...U,class=typename std::enable_if<Constructible_from_each<RT,U...>::value>::type,class=typename std::enable_if<(sizeof...(U)==static_dim+1)>::type,class=void>
+        //template<class...U,class=std::enable_if_t<Constructible_from_each<RT,U...>::value>,class=typename std::enable_if_t<(sizeof...(U)==static_dim+1)>,class=void>
         template<class...U>
-        typename std::enable_if<Constructible_from_each<RT,U...>::value &&
+        std::enable_if_t<Constructible_from_each<RT,U...>::value &&
                 std::is_same<Dimension_tag<int(sizeof...(U)-1)>, Dimension>::value,
-          result_type>::type
+          result_type>
         operator()(U&&...u)const{
                 return Apply_to_last_then_rest()(typename Constructor::Values_divide(),std::forward<U>(u)...);
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (Iter f,Iter g,Cartesian_tag t)const
         {
                 return this->operator()((int)std::distance(f,g),f,g,t);
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (int d,Iter f,Iter g,Cartesian_tag)const
         {
                 CGAL_assertion(d==std::distance(f,g));
@@ -86,28 +86,28 @@ template<class R_,class Zero_> struct Construct_LA_vector
                 return typename Constructor::Iterator()(d,f,g);
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::bidirectional_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::bidirectional_iterator_tag>::value,result_type> operator()
                 (Iter f,Iter g,Homogeneous_tag)const
         {
                 --g;
                 return this->operator()((int)std::distance(f,g),f,g,*g);
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::bidirectional_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::bidirectional_iterator_tag>::value,result_type> operator()
                 (int d,Iter f,Iter g,Homogeneous_tag)const
         {
                 --g;
                 return this->operator()(d,f,g,*g);
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (Iter f,Iter g)const
         {
           // Shouldn't it try comparing dist(f,g) to the dimension if it is known?
                 return this->operator()(f,g,typename R::Rep_tag());
         }
         template<class Iter> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (int d,Iter f,Iter g)const
         {
                 return this->operator()(d,f,g,typename R::Rep_tag());
@@ -115,7 +115,7 @@ template<class R_,class Zero_> struct Construct_LA_vector
 
         // Last homogeneous coordinate given separately
         template<class Iter,class NT> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (int d,Iter f,Iter g,NT const&l)const
         {
                 CGAL_assertion(d==std::distance(f,g));
@@ -124,7 +124,7 @@ template<class R_,class Zero_> struct Construct_LA_vector
                 return typename Constructor::Iterator()(d,CGAL::make_transforming_iterator(f,Divide<FT,NT>(l)),CGAL::make_transforming_iterator(g,Divide<FT,NT>(l)));
         }
         template<class Iter,class NT> inline
-          typename std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
+          std::enable_if_t<is_iterator_type<Iter,std::forward_iterator_tag>::value,result_type> operator()
                 (Iter f,Iter g,NT const&l)const
         {
                 return this->operator()((int)std::distance(f,g),f,g,l);
