@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/avx4.h $
-// $Id: avx4.h e6c767d 2021-05-12T15:45:07+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/avx4.h $
+// $Id: include/CGAL/NewKernel_d/Vector/avx4.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -31,19 +31,19 @@ namespace CGAL {
     typedef Dimension_tag<4> Dimension;
     typedef Dimension_tag<4> Max_dimension;
     // No Rebind_dimension, this is a building block
-    template<class,bool=true> struct Property : boost::false_type {};
+    template<class,bool=true> struct Property : std::false_type {};
     template<bool b> struct Property<Has_vector_plus_minus_tag,b>
-      : boost::true_type {};
+      : std::true_type {};
     /* MAYBE?
        template<bool b> struct Property<Has_vector_scalar_ops_tag,b>
-       : boost::true_type {};
+       : std::true_type {};
        */
     template<bool b> struct Property<Has_determinant_of_vectors_tag,b>
-      : boost::true_type {};
+      : std::true_type {};
     template<bool b> struct Property<Has_dot_product_tag,b>
-      : boost::true_type {};
+      : std::true_type {};
     template<bool b> struct Property<Has_determinant_of_vectors_omit_last_tag,b>
-      : boost::true_type {};
+      : std::true_type {};
 
     typedef __m256d Vector;
     struct Construct_vector {
