@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/determinant_of_iterator_to_points_from_points.h $
-// $Id: determinant_of_iterator_to_points_from_points.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/determinant_of_iterator_to_points_from_points.h $
+// $Id: include/CGAL/NewKernel_d/Vector/determinant_of_iterator_to_points_from_points.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -42,7 +42,7 @@ struct Add_determinant_of_iterator_to_points_from_points
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_iterator_to_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   template<class Iter>
   static NT determinant_of_iterator_to_points(Iter const&first, Iter const&end){
@@ -74,7 +74,7 @@ struct Add_determinant_of_iterator_to_points_from_points
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_iterator_to_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   template<class Iter>
   static NT determinant_of_iterator_to_points(Iter const&first, Iter const&end){
@@ -108,7 +108,7 @@ struct Add_determinant_of_iterator_to_points_from_points
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_iterator_to_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   template<class Iter>
   static NT determinant_of_iterator_to_points(Iter const&first, Iter const&end){
@@ -144,7 +144,7 @@ struct Add_determinant_of_iterator_to_points_from_points
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_iterator_to_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   template<class Iter>
   static NT determinant_of_iterator_to_points(Iter const&first, Iter const&end){
@@ -182,7 +182,7 @@ struct Add_determinant_of_iterator_to_points_from_points
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_iterator_to_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   template<class Iter>
   static NT determinant_of_iterator_to_points(Iter const&first, Iter const&end){
