@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/determinant_of_points_from_vectors.h $
-// $Id: determinant_of_points_from_vectors.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/NewKernel_d/include/CGAL/NewKernel_d/Vector/determinant_of_points_from_vectors.h $
+// $Id: include/CGAL/NewKernel_d/Vector/determinant_of_points_from_vectors.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -42,7 +42,7 @@ struct Add_determinant_of_points_from_vectors_and_minus
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   static NT determinant_of_points(Vector const&a, Vector const&b,
       Vector const&c){
@@ -66,7 +66,7 @@ struct Add_determinant_of_points_from_vectors_and_minus
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   static NT determinant_of_points(Vector const&a, Vector const&b,
       Vector const&c, Vector const&d){
@@ -90,7 +90,7 @@ struct Add_determinant_of_points_from_vectors_and_minus
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   static NT determinant_of_points(Vector const&a, Vector const&b,
       Vector const&c, Vector const&d, Vector const&e){
@@ -114,7 +114,7 @@ struct Add_determinant_of_points_from_vectors_and_minus
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   static NT determinant_of_points(Vector const&a, Vector const&b,
       Vector const&c, Vector const&d, Vector const&e, Vector const&f){
@@ -138,7 +138,7 @@ struct Add_determinant_of_points_from_vectors_and_minus
     };
   template<class P,class=void> struct Property : LA::template Property<P> {};
   template<class D> struct Property<Has_determinant_of_points_tag, D> :
-    boost::true_type {};
+    std::true_type {};
 
   static NT determinant_of_points(Vector const&a, Vector const&b,
       Vector const&c, Vector const&d, Vector const&e, Vector const&f,
