@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/NewKernel_d/include/CGAL/NewKernel_d/functor_properties.h $
-// $Id: functor_properties.h 634fe39 2020-12-30T19:56:58+01:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/NewKernel_d/include/CGAL/NewKernel_d/functor_properties.h $
+// $Id: include/CGAL/NewKernel_d/functor_properties.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Glisse
@@ -20,7 +20,7 @@ namespace CGAL {
     BOOST_MPL_HAS_XXX_TRAIT_DEF(Is_pretty) \
   } \
   template<class T,bool=internal::has_##Is_pretty<T>::value> \
-  struct Is_pretty : boost::false_type {}; \
+  struct Is_pretty : std::false_type {}; \
   template<class T> \
   struct Is_pretty<T,true> : T::Is_pretty {}
 
