@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/STL_Extension/include/CGAL/Object.h $
-// $Id: Object.h b575892 2021-06-08T18:21:46+01:00 Giles Bathgate
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/Object.h $
+// $Id: include/CGAL/Object.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -27,8 +27,8 @@
 #include <iterator>
 #include <typeinfo>
 
-#include <boost/variant.hpp>
-#include <boost/optional.hpp>
+#include <variant>
+#include <optional>
 #include <boost/any.hpp>
 #include <memory>
 
@@ -39,7 +39,7 @@ class Object
     std::shared_ptr<boost::any> obj;
 
     // returns an any pointer from a variant
-    struct Any_from_variant : public boost::static_visitor<boost::any*> {
+    struct Any_from_variant {
       template<typename T>
       boost::any* operator()(const T& t) const {
         return new boost::any(t);
@@ -52,8 +52,6 @@ class Object
     template<class T>
     friend T object_cast(const Object & o);
 
-    typedef void (Object::*bool_type)() const;
-    void this_type_does_not_support_comparisons() const {}
   public:
 
     struct private_tag{};
@@ -64,14 +62,14 @@ class Object
     Object(T && t, private_tag) : obj(new boost::any(std::forward<T>(t))) { }
 
     // implicit constructor from optionals containing variants
-    template<BOOST_VARIANT_ENUM_PARAMS(typename T)>
-    Object(const boost::optional< boost::variant<BOOST_VARIANT_ENUM_PARAMS(T) > >& t)
-      : obj( t ? boost::apply_visitor(Any_from_variant(), *t) : nullptr) { }
+    template<typename ... T>
+    Object(const std::optional< std::variant<T...> >& t)
+      : obj( t ? std::visit(Any_from_variant(), *t) : nullptr) { }
 
     // implicit constructor from  variants
-    template<BOOST_VARIANT_ENUM_PARAMS(typename T)>
-    Object(const boost::variant<BOOST_VARIANT_ENUM_PARAMS(T) >& v)
-      : obj(boost::apply_visitor(Any_from_variant(), v)) { }
+    template<typename ... T>
+    Object(const std::variant<T...>& v)
+      : obj(std::visit(Any_from_variant(), v)) { }
 
     template <class T>
     bool assign(T &t) const
@@ -97,8 +95,8 @@ class Object
     }
 
     // safe-bool conversion
-    operator bool_type() const {
-      return empty() == false ? &Object::this_type_does_not_support_comparisons : 0;
+    explicit operator bool() const {
+      return !empty();
     }
 
 
