@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Periodic_2_triangulation_2/include/CGAL/Periodic_2_offset_2.h $
-// $Id: Periodic_2_offset_2.h 4e519a3 2021-05-05T13:15:37+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Periodic_2_triangulation_2/include/CGAL/Periodic_2_offset_2.h $
+// $Id: include/CGAL/Periodic_2_offset_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Nico Kruithof <Nico@nghk.nl>
@@ -16,7 +16,7 @@
 
 
 #include <CGAL/basic.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Cartesian.h>
 
 namespace CGAL
@@ -71,14 +71,14 @@ public:
   int &operator[](int i)
   {
     if (i == 0) return _offx;
-    CGAL_triangulation_assertion(i == 1);
+    CGAL_assertion(i == 1);
     return _offy;
   }
   /// Return the i-th entry of o.
   int operator[](int i) const
   {
     if (i == 0) return _offx;
-    CGAL_triangulation_assertion(i == 1);
+    CGAL_assertion(i == 1);
     return _offy;
   }
   /// Add o' to o using vector addition.
