@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Periodic_3_triangulation_3/include/CGAL/Periodic_3_offset_3.h $
-// $Id: Periodic_3_offset_3.h 4e519a3 2021-05-05T13:15:37+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Periodic_3_triangulation_3/include/CGAL/Periodic_3_offset_3.h $
+// $Id: include/CGAL/Periodic_3_offset_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -17,9 +17,12 @@
 #include <CGAL/license/Periodic_3_triangulation_3.h>
 
 #include <CGAL/basic.h>
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Cartesian.h>
 
+#include <iostream>
+#include <type_traits>
+
 namespace CGAL {
 
 class Periodic_3_offset_3
@@ -43,18 +46,27 @@ public:
   int& z() { return _offz; }
   int z() const { return _offz; }
 
-  int &operator[](int i) {
+  // Use sfinae on the operator[] to accept only integral types as argument
+  template <typename T,
+            typename std::enable_if<std::is_integral<T>::value>::type* = nullptr>
+  int& operator[](T i)
+  {
     if (i==0) return _offx;
     if (i==1) return _offy;
-    CGAL_triangulation_assertion(i==2);
+    CGAL_assertion(i==2);
     return _offz;
   }
-  int operator[](int i) const {
+
+  template <typename T,
+            typename std::enable_if<std::is_integral<T>::value>::type* = nullptr>
+  int operator[](T i) const
+  {
     if (i==0) return _offx;
     if (i==1) return _offy;
-    CGAL_triangulation_assertion(i==2);
+    CGAL_assertion(i==2);
     return _offz;
   }
+
   void operator+=(const Periodic_3_offset_3 &other) {
     _offx += other._offx;
     _offy += other._offy;
