@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h $
-// $Id: Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h 5c8df66 2020-09-25T14:25:14+02:00 Jane Tournois
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h $
+// $Id: include/CGAL/Periodic_4_hyperbolic_Delaunay_triangulation_traits_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     :   Iordan Iordanov
@@ -24,7 +24,7 @@
 #include <CGAL/Cartesian.h>
 
 #include <boost/tuple/tuple.hpp>
-#include <boost/variant.hpp>
+#include <variant>
 
 #include <utility>
 
@@ -371,9 +371,9 @@ class Compute_approximate_hyperbolic_diameter
     Hyperbolic_point_2 operator()(const Hyperbolic_segment_2& s1,
                                   const Hyperbolic_segment_2& s2)
     {
-      if(Circular_arc_2* c1 = boost::get<Circular_arc_2>(&s1))
+      if(Circular_arc_2* c1 = std::get_if<Circular_arc_2>(&s1))
       {
-        if(Circular_arc_2* c2 = boost::get<Circular_arc_2>(&s2))
+        if(Circular_arc_2* c2 = std::get_if<Circular_arc_2>(&s2))
         {
           std::pair<Hyperbolic_point_2, Hyperbolic_point_2> res = operator()(c1->circle(),
                                                                              c2->circle());
@@ -387,7 +387,7 @@ class Compute_approximate_hyperbolic_diameter
         }
         else
         {
-          Euclidean_segment_2* ell2 = boost::get<Euclidean_segment_2>(&s2);
+          Euclidean_segment_2* ell2 = std::get_if<Euclidean_segment_2>(&s2);
           std::pair<Hyperbolic_point_2, Hyperbolic_point_2> res = operator()(c1->circle(),
                                                                              ell2->supporting_line());
           Hyperbolic_point_2 p1 = res.first;
@@ -401,8 +401,8 @@ class Compute_approximate_hyperbolic_diameter
       }
       else
       {
-        Euclidean_segment_2* ell1 = boost::get<Euclidean_segment_2>(&s1);
-        if(Circular_arc_2* c2 = boost::get<Circular_arc_2>(&s2))
+        Euclidean_segment_2* ell1 = std::get_if<Euclidean_segment_2>(&s1);
+        if(Circular_arc_2* c2 = std::get_if<Circular_arc_2>(&s2))
         {
           std::pair<Hyperbolic_point_2, Hyperbolic_point_2> res = operator()(ell1->supporting_line(),
                                                                              c2->circle());
@@ -416,7 +416,7 @@ class Compute_approximate_hyperbolic_diameter
         }
         else
         {
-          Euclidean_segment_2* ell2 = boost::get<Euclidean_segment_2>(&s2);
+          Euclidean_segment_2* ell2 = std::get_if<Euclidean_segment_2>(&s2);
           Hyperbolic_point_2 p1 = operator()(ell1->supporting_line(), ell2->supporting_line());
           CGAL_assertion(p1.x()*p1.x() + p1.y()*p1.y()) < FT(1);
           return p1;
@@ -465,9 +465,9 @@ class Compute_approximate_hyperbolic_diameter
       Euclidean_line_2* l;
       Circle_2* c;
 
-      if(Circle_2* c_pq = boost::get<Circle_2>(&bis_pq))
+      if(Circle_2* c_pq = std::get_if<Circle_2>(&bis_pq))
       {
-        if(Circle_2* c_qr = boost::get<Circle_2>(&bis_qr))
+        if(Circle_2* c_qr = std::get_if<Circle_2>(&bis_qr))
         {
           std::pair<Hyperbolic_point_2, Hyperbolic_point_2> inters = _gt.construct_inexact_intersection_2_object()(*c_pq, *c_qr);
 
@@ -477,14 +477,14 @@ class Compute_approximate_hyperbolic_diameter
           return inters.second;
         }
         // here bis_qr is a line
-        l = boost::get<Euclidean_line_2>(&bis_qr);
+        l = std::get_if<Euclidean_line_2>(&bis_qr);
         c = c_pq;
       }
       else
       {
         // here bis_pq is a line
-        l = boost::get<Euclidean_line_2>(&bis_pq);
-        c = boost::get<Circle_2>(&bis_qr);
+        l = std::get_if<Euclidean_line_2>(&bis_pq);
+        c = std::get_if<Circle_2>(&bis_qr);
       }
 
       std::pair<Hyperbolic_point_2, Hyperbolic_point_2> inters = _gt.construct_inexact_intersection_2_object()(*c, *l);
