@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_triangulation_face_base_2.h $
-// $Id: Periodic_4_hyperbolic_triangulation_face_base_2.h 254d60f 2019-10-19T15:23:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Periodic_4_hyperbolic_triangulation_2/include/CGAL/Periodic_4_hyperbolic_triangulation_face_base_2.h $
+// $Id: include/CGAL/Periodic_4_hyperbolic_triangulation_face_base_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Iordan Iordanov  <Iordan.Iordanov@loria.fr>
@@ -17,7 +17,6 @@
 
 #include <CGAL/basic.h>
 #include <CGAL/Dummy_tds_2.h>
-#include <CGAL/triangulation_assertions.h>
 #include <CGAL/Triangulation_face_base_2.h>
 
 namespace CGAL {
@@ -73,13 +72,13 @@ public:
 
   Hyperbolic_translation translation(int i) const
   {
-    CGAL_triangulation_precondition(i >= 0 && i <= 2);
+    CGAL_precondition(i >= 0 && i <= 2);
     return o[i];
   }
 
   void set_translation(const int& k, const Hyperbolic_translation& new_o)
   {
-    CGAL_triangulation_precondition(k >= 0 && k <= 2);
+    CGAL_precondition(k >= 0 && k <= 2);
     o[k] = new_o;
   }
 
