@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Kernel_23/include/CGAL/Point_3.h $
-// $Id: Point_3.h 2884569 2022-04-27T16:32:06+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Point_3.h $
+// $Id: include/CGAL/Point_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,7 +20,6 @@
 #include <CGAL/Origin.h>
 #include <CGAL/representation_tags.h>
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/Bbox_3.h>
 #include <CGAL/Dimension.h>
@@ -35,7 +34,7 @@ class Point_3 : public R_::Kernel_base::Point_3
   typedef typename R_::Aff_transformation_3  Aff_transformation_3;
 
   typedef Point_3                            Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Point_3>::value));
+  static_assert(std::is_same<Self, typename R_::Point_3>::value);
 
 public:
 
@@ -76,8 +75,10 @@ public:
   {}
 
   template < typename T1, typename T2, typename T3 >
-  Point_3(const T1& x, const T2& y, const T3& z)
-    : Rep(typename R::Construct_point_3()(Return_base_tag(), x, y, z))
+  Point_3(T1&& x, T2&& y, T3&& z)
+    : Rep(typename R::Construct_point_3()(Return_base_tag(), std::forward<T1>(x),
+                                                             std::forward<T2>(y),
+                                                             std::forward<T3>(z)))
   {}
 
   Point_3(const RT& hx, const RT& hy, const RT& hz, const RT& hw)
@@ -284,7 +285,7 @@ extract(std::istream& is, Point_3<R>& p, const Cartesian_tag&)
         break;
     }
     if (is)
-      p = Point_3<R>(x, y, z);
+      p = Point_3<R>(std::move(x), std::move(y), std::move(z));
     return is;
 }
 
