@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Point_set_3/include/CGAL/Point_set_3/IO/PLY.h $
-// $Id: PLY.h 10b0af3 2022-01-13T14:43:34+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Point_set_3/include/CGAL/Point_set_3/IO/PLY.h $
+// $Id: include/CGAL/Point_set_3/IO/PLY.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
@@ -118,40 +118,40 @@ public:
         continue;
       }
 
-      if(dynamic_cast<PLY_read_typed_number<boost::int8_t>*>(property))
+      if(dynamic_cast<PLY_read_typed_number<std::int8_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::int8_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::int8_t>(m_point_set,
                                                                    name));
       }
-      else if(dynamic_cast<PLY_read_typed_number<boost::uint8_t>*>(property))
+      else if(dynamic_cast<PLY_read_typed_number<std::uint8_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::uint8_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::uint8_t>(m_point_set,
                                                                     name));
       }
-      else if(dynamic_cast<PLY_read_typed_number<boost::int16_t>*>(property))
+      else if(dynamic_cast<PLY_read_typed_number<std::int16_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::int16_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::int16_t>(m_point_set,
                                                                     name));
       }
-      else if(dynamic_cast<PLY_read_typed_number<boost::uint16_t>*>(property))
+      else if(dynamic_cast<PLY_read_typed_number<std::uint16_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::uint16_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::uint16_t>(m_point_set,
                                                                      name));
       }
-      else if(dynamic_cast<PLY_read_typed_number<boost::int32_t>*>(property))
+      else if(dynamic_cast<PLY_read_typed_number<std::int32_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::int32_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::int32_t>(m_point_set,
                                                                     name));
       }
-      else if(dynamic_cast<PLY_read_typed_number<boost::uint32_t>*>(property))
+      else if(dynamic_cast<PLY_read_typed_number<std::uint32_t>*>(property))
       {
         m_properties.push_back
-            (new PLY_property_to_point_set_property<boost::uint32_t>(m_point_set,
+            (new PLY_property_to_point_set_property<std::uint32_t>(m_point_set,
                                                                      name));
       }
       else if(dynamic_cast<PLY_read_typed_number<float>*>(property))
@@ -367,25 +367,6 @@ bool read_PLY(const std::string& fname, CGAL::Point_set_3<Point, Vector>& point_
 
 #ifndef CGAL_NO_DEPRECATED_CODE
 
-/*!
-  \ingroup PkgPointSet3IODeprecated
-
-  \deprecated This function is deprecated since \cgal 5.3,
-              \link PkgPointSet3IO `CGAL::IO::read_PLY()` \endlink  should be used instead.
-
-  \brief reads a point set with properties from an input stream in \ascii or binary PLY format.
-
-  - the operator reads the vertex `point` property;
-  - if three PLY properties `nx`, `ny` and `nz` with type `float`
-     or `double` are found, the normal map is added;
-  - if any other PLY property is found, a "[name]" property map is
-    added, where `[name]` is the name of the PLY property.
-
-  The `comments` parameter can be omitted. If provided, it will be
-  used to store the potential comments found in the PLY
-  header. Each line starting by "comment " in the header is
-  appended to the `comments` string (without the "comment " word).
- */
 template <typename Point, typename Vector>
 CGAL_DEPRECATED bool read_ply_point_set(std::istream& is, ///< input stream.
                                         CGAL::Point_set_3<Point, Vector>& point_set, ///< point set
@@ -456,14 +437,14 @@ bool write_PLY(std::ostream& os,
   typedef typename Point_set::Index Index;
   typedef typename Point_set::Point_map Point_map;
   typedef typename Point_set::Vector_map Vector_map;
-  typedef typename Point_set::template Property_map<boost::int8_t> Int8_map;
-  typedef typename Point_set::template Property_map<boost::uint8_t> Uint8_map;
-  typedef typename Point_set::template Property_map<boost::int16_t> Int16_map;
-  typedef typename Point_set::template Property_map<boost::uint16_t> Uint16_map;
-  typedef typename Point_set::template Property_map<boost::int32_t> Int32_map;
-  typedef typename Point_set::template Property_map<boost::uint32_t> Uint32_map;
-  typedef typename Point_set::template Property_map<boost::int64_t> Int64_map;
-  typedef typename Point_set::template Property_map<boost::uint64_t> Uint64_map;
+  typedef typename Point_set::template Property_map<std::int8_t> Int8_map;
+  typedef typename Point_set::template Property_map<std::uint8_t> Uint8_map;
+  typedef typename Point_set::template Property_map<std::int16_t> Int16_map;
+  typedef typename Point_set::template Property_map<std::uint16_t> Uint16_map;
+  typedef typename Point_set::template Property_map<std::int32_t> Int32_map;
+  typedef typename Point_set::template Property_map<std::uint32_t> Uint32_map;
+  typedef typename Point_set::template Property_map<std::int64_t> Int64_map;
+  typedef typename Point_set::template Property_map<std::uint64_t> Uint64_map;
   typedef typename Point_set::template Property_map<float> Float_map;
   typedef typename Point_set::template Property_map<double> Double_map;
 
@@ -505,7 +486,7 @@ bool write_PLY(std::ostream& os,
 
     if(prop[i] == "point")
     {
-      if(boost::is_same<typename Get_FT_from_map<typename Point_set::Point_map>::type, float>::value)
+      if(std::is_same<typename Get_FT_from_map<typename Point_set::Point_map>::type, float>::value)
       {
         os << "property float x" << std::endl
            << "property float y" << std::endl
@@ -522,7 +503,7 @@ bool write_PLY(std::ostream& os,
     }
     if(prop[i] == "normal")
     {
-      if(boost::is_same<typename Get_FT_from_map<typename Point_set::Vector_map>::type, float>::value)
+      if(std::is_same<typename Get_FT_from_map<typename Point_set::Vector_map>::type, float>::value)
       {
         os << "property float nx" << std::endl
            << "property float ny" << std::endl
@@ -538,104 +519,93 @@ bool write_PLY(std::ostream& os,
       continue;
     }
 
-    bool okay = false;
     {
-      Int8_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::int8_t>(prop[i]);
-      if(okay)
+      std::optional<Int8_map> pmap = point_set.template property_map<std::int8_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property char " << prop[i] << std::endl;
-        printers.push_back(new internal::Char_property_printer<Index,Int8_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Int8_map>(pmap.value()));
         continue;
       }
     }
     {
-      Uint8_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::uint8_t>(prop[i]);
-      if(okay)
+      std::optional<Uint8_map> pmap = point_set.template property_map<std::uint8_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property uchar " << prop[i] << std::endl;
-        printers.push_back(new internal::Char_property_printer<Index,Uint8_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Uint8_map>(pmap.value()));
         continue;
       }
     }
     {
-      Int16_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::int16_t>(prop[i]);
-      if(okay)
+      std::optional<Int16_map> pmap = point_set.template property_map<std::int16_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property short " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Int16_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Int16_map>(pmap.value()));
         continue;
       }
     }
     {
-      Uint16_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::uint16_t>(prop[i]);
-      if(okay)
+      std::optional<Uint16_map> pmap = point_set.template property_map<std::uint16_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property ushort " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Uint16_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Uint16_map>(pmap.value()));
         continue;
       }
     }
     {
-      Int32_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::int32_t>(prop[i]);
-      if(okay)
+      std::optional<Int32_map> pmap = point_set.template property_map<std::int32_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property int " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Int32_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Int32_map>(pmap.value()));
         continue;
       }
     }
     {
-      Uint32_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::uint32_t>(prop[i]);
-      if(okay)
+      std::optional<Uint32_map> pmap = point_set.template property_map<std::uint32_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property uint " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Uint32_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Uint32_map>(pmap.value()));
         continue;
       }
     }
     {
-      Int64_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::int64_t>(prop[i]);
-      if(okay)
+      std::optional<Int64_map> pmap = point_set.template property_map<std::int64_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property int " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Int64_map,boost::int32_t>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Int64_map,std::int32_t>(pmap.value()));
         continue;
       }
     }
     {
-      Uint64_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<boost::uint64_t>(prop[i]);
-      if(okay)
+      std::optional<Uint64_map> pmap = point_set.template property_map<std::uint64_t>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property uint " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Uint64_map,boost::uint32_t>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Uint64_map,std::uint32_t>(pmap.value()));
         continue;
       }
     }
     {
-      Float_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<float>(prop[i]);
-      if(okay)
+      std::optional<Float_map> pmap = point_set.template property_map<float>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property float " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Float_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Float_map>(pmap.value()));
         continue;
       }
     }
     {
-      Double_map pmap;
-      boost::tie(pmap, okay) = point_set.template property_map<double>(prop[i]);
-      if(okay)
+      std::optional<Double_map> pmap = point_set.template property_map<double>(prop[i]);
+      if(pmap.has_value())
       {
         os << "property double " << prop[i] << std::endl;
-        printers.push_back(new internal::Simple_property_printer<Index,Double_map>(pmap));
+        printers.push_back(new internal::Simple_property_printer<Index,Double_map>(pmap.value()));
         continue;
       }
     }
@@ -744,12 +714,6 @@ bool write_PLY(const std::string& fname, const CGAL::Point_set_3<Point, Vector>&
 
 #ifndef CGAL_NO_DEPRECATED_CODE
 
-/*!
-  \ingroup PkgPointSet3IODeprecated
-
-  \deprecated This function is deprecated since \cgal 5.3,
-              \link PkgPointSet3IO `CGAL::IO::write_PLY()` \endlink  should be used instead.
- */
 template <typename Point, typename Vector>
 CGAL_DEPRECATED bool write_ply_point_set(std::ostream& os,
                                          const CGAL::Point_set_3<Point, Vector>& point_set,
