@@ -4,8 +4,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Poisson_surface_reconstruction_3/include/CGAL/Poisson_implicit_surface_3.h $
-// $Id: Poisson_implicit_surface_3.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Poisson_surface_reconstruction_3/include/CGAL/Poisson_implicit_surface_3.h $
+// $Id: include/CGAL/Poisson_implicit_surface_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Laurent RINEAU
@@ -56,7 +56,7 @@ namespace CGAL {
         gt.compute_squared_radius_3_object()(bounding_sphere);
     }
 
-    FT operator()(Point p) const
+    FT operator()(const Point& p) const
     {
       return func(p);
     }
@@ -109,15 +109,6 @@ namespace CGAL {
     return surface(f, sphere, error_bound);
   }
 
-//   template <typename GT, typename Function>
-//   struct Surface_mesh_traits_generator_3<Poisson_implicit_surface_3<GT, Function> >
-//   {
-//     typedef Poisson_implicit_surface_3<GT, Function> Surface_type;
-//     typedef typename Surface_mesher::Poisson_implicit_surface_oracle_3<GT,
-//                                                              Surface_type> Type;
-//     typedef Type type; // Boost meta-programming compatibility
-//   };
-
   // non documented class
   template <typename FT, typename Point>
   class Poisson_implicit_function_wrapper : public CGAL::cpp98::unary_function<Point, FT>
@@ -129,7 +120,7 @@ namespace CGAL {
   public:
     Poisson_implicit_function_wrapper(Poisson_implicit_function f) : function(f) {}
 
-    FT operator()(Point p) const
+    FT operator()(const Point& p) const
     {
       return function(p.x(), p.y(), p.z());
     }
