@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/fair.h $
-// $Id: fair.h bb0b9a8 2022-03-07T15:32:37+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/fair.h $
+// $Id: include/CGAL/Polygon_mesh_processing/fair.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,14 +19,14 @@
 
 #include <CGAL/Polygon_mesh_processing/internal/fair_impl.h>
 #include <CGAL/Named_function_parameters.h>
-#include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
+#include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/Weights/cotangent_weights.h>
 
 #if defined(CGAL_EIGEN3_ENABLED)
 #include <CGAL/Eigen_solver_traits.h>  // for sparse linear system solver
 #endif
 
-#include <boost/type_traits/is_same.hpp>
+#include <type_traits>
 
 namespace CGAL {
 
@@ -41,18 +41,18 @@ namespace internal {
            typename TriangleMesh,
            typename VertexRange,
            typename VertexPointMap>
-  bool fair(TriangleMesh& tmesh,
-    const VertexRange& vertices,
-    SparseLinearSolver solver,
-    WeightCalculator weight_calculator,
-    unsigned int continuity,
-    VertexPointMap vpmap)
-  {
-    CGAL::Polygon_mesh_processing::internal::Fair_Polyhedron_3
-       <TriangleMesh, SparseLinearSolver, WeightCalculator, VertexPointMap>
-       fair_functor(tmesh, vpmap, weight_calculator);
-    return fair_functor.fair(vertices, solver, continuity);
-  }
+bool fair(TriangleMesh& tmesh,
+          const VertexRange& vertices,
+          SparseLinearSolver solver,
+          WeightCalculator weight_calculator,
+          unsigned int continuity,
+          VertexPointMap vpmap)
+{
+  CGAL::Polygon_mesh_processing::internal::Fair_Polyhedron_3
+     <TriangleMesh, SparseLinearSolver, WeightCalculator, VertexPointMap>
+     fair_functor(tmesh, vpmap, weight_calculator);
+  return fair_functor.fair(vertices, solver, continuity);
+}
 
 } //end namespace internal
 
@@ -76,7 +76,7 @@ namespace internal {
   do not suffice to solve constructed linear system.
 
   Note that if the vertex range to which fairing is applied contains all the vertices of the triangle mesh,
-  fairing does not fail, but the mesh gets shrinked to `CGAL::ORIGIN`.
+  fairing does not fail, but the mesh gets shrunk to `CGAL::ORIGIN`.
 
   @tparam TriangleMesh a model of `FaceGraph` and `MutableFaceGraph`
   @tparam VertexRange a range of vertex descriptors of `TriangleMesh`, model of `Range`.
@@ -98,8 +98,8 @@ namespace internal {
     \cgalParamNEnd
 
     \cgalParamNBegin{fairing_continuity}
-      \cgalParamDescription{A value controling the tangential continuity of the output surface patch.
-                            The possible values are 0, 1 and 2, refering to the  C<sup>0</sup>, C<sup>1</sup>
+      \cgalParamDescription{A value controlling the tangential continuity of the output surface patch.
+                            The possible values are 0, 1 and 2, referring to the  C<sup>0</sup>, C<sup>1</sup>
                             and C<sup>2</sup> continuity.}
       \cgalParamType{unsigned int}
       \cgalParamDefault{`1`}
@@ -151,35 +151,37 @@ namespace internal {
 #endif
 
 #if defined(CGAL_EIGEN3_ENABLED)
-    CGAL_static_assertion_msg(
-      (!boost::is_same<typename GetSolver<NamedParameters, Default_solver>::type, bool>::value) || EIGEN_VERSION_AT_LEAST(3, 2, 0),
+    static_assert(
+      (!std::is_same<typename GetSolver<NamedParameters, Default_solver>::type, bool>::value) || EIGEN_VERSION_AT_LEAST(3, 2, 0),
       "The function `fair` requires Eigen3 version 3.2 or later.");
 #else
-    CGAL_static_assertion_msg(
-      (!boost::is_same<typename GetSolver<NamedParameters, Default_solver>::type, bool>::value),
+    static_assert(
+      (!std::is_same<typename GetSolver<NamedParameters, Default_solver>::type, bool>::value),
       "The function `fair` requires Eigen3 version 3.2 or later.");
 #endif
 
     typedef typename GetVertexPointMap < TriangleMesh, NamedParameters>::type VPMap;
+    VPMap vpmap = choose_parameter(get_parameter(np, internal_np::vertex_point),
+                                   get_property_map(vertex_point, tmesh));
+
+    typedef typename GetGeomTraits < TriangleMesh, NamedParameters>::type GT;
+    GT gt = choose_parameter<GT>(get_parameter(np, internal_np::geom_traits));
 
     // Cotangent_weight_with_voronoi_area_fairing has been changed to the version:
-    // Cotangent_weight_with_voronoi_area_fairing_secure to avoid imprecisions from
+    // Secure_cotangent_weight_with_voronoi_area to avoid imprecisions from
     // the issue #4706 - https://github.com/CGAL/cgal/issues/4706.
-    typedef CGAL::Weights::Secure_cotangent_weight_with_voronoi_area<TriangleMesh, VPMap> Default_weight_calculator;
-
-    VPMap vpmap_ = choose_parameter(get_parameter(np, internal_np::vertex_point),
-                                    get_property_map(vertex_point, tmesh));
+    typedef CGAL::Weights::Secure_cotangent_weight_with_voronoi_area<TriangleMesh, VPMap, GT> Default_weight_calculator;
 
     return internal::fair(tmesh, vertices,
       choose_parameter<Default_solver>(get_parameter(np, internal_np::sparse_linear_solver)),
-      choose_parameter(get_parameter(np, internal_np::weight_calculator), Default_weight_calculator(tmesh, vpmap_)),
+      choose_parameter(get_parameter(np, internal_np::weight_calculator), Default_weight_calculator(tmesh, vpmap, gt)),
       choose_parameter(get_parameter(np, internal_np::fairing_continuity), 1),
-      vpmap_);
+      vpmap);
   }
 
-} //end namespace Polygon_mesh_processing
+} // namespace Polygon_mesh_processing
 
-} //end namespace CGAL
+} // namespace CGAL
 
 #include <CGAL/enable_warnings.h>
 
