@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
-// $Id: snap.h ca23626 2022-03-11T14:28:18+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h $
+// $Id: include/CGAL/Polygon_mesh_processing/internal/Snapping/snap.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -14,7 +14,7 @@
 #ifndef CGAL_POLYGON_MESH_PROCESSING_SNAPPING_SNAP_H
 #define CGAL_POLYGON_MESH_PROCESSING_SNAPPING_SNAP_H
 
-#include <CGAL/license/Polygon_mesh_processing/repair.h>
+#include <CGAL/license/Polygon_mesh_processing/geometric_repair.h>
 
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
  #ifndef CGAL_PMP_SNAP_DEBUG
@@ -26,12 +26,13 @@
 #include <CGAL/Polygon_mesh_processing/internal/Snapping/snap_vertices.h>
 
 #include <CGAL/Named_function_parameters.h>
-#include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
+#include <CGAL/boost/graph/named_params_helper.h>
+#include <CGAL/boost/graph/Euler_operations.h>
 #include <CGAL/Polygon_mesh_processing/border.h>
 #include <CGAL/Polygon_mesh_processing/compute_normal.h>
 
 #include <CGAL/AABB_tree.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_halfedge_graph_segment_primitive.h>
 #include <CGAL/assertions.h>
 #include <CGAL/boost/graph/helpers.h>
@@ -104,15 +105,19 @@ void simplify_range(HalfedgeRange& halfedge_range,
   typedef CGAL::dynamic_halfedge_property_t<bool>                                 Halfedge_bool_tag;
   typedef typename boost::property_map<TriangleMesh, Halfedge_bool_tag>::type     Range_halfedges;
 
-  Range_halfedges range_halfedges = get(Halfedge_bool_tag(), tm);
-  for(halfedge_descriptor h : halfedge_range)
-    put(range_halfedges, h, true);
+  const bool all_hedges = (::CGAL::internal::exact_num_halfedges(tm)==halfedge_range.size());
+
+  Range_halfedges range_halfedges = get(Halfedge_bool_tag(), tm, all_hedges);
+  if (!all_hedges)
+    for(halfedge_descriptor h : halfedge_range)
+      put(range_halfedges, h, true);
 
   CGAL_postcondition_code(const std::size_t initial_n = halfedge_range.size();)
 
   std::set<halfedge_descriptor> edges_to_test(halfedge_range.begin(), halfedge_range.end());
 
   int collapsed_n = 0;
+
   while(!edges_to_test.empty())
   {
     const halfedge_descriptor h = *(edges_to_test.begin());
@@ -133,6 +138,7 @@ void simplify_range(HalfedgeRange& halfedge_range,
     {
       const halfedge_descriptor prev_h = prev(h, tm);
       const halfedge_descriptor next_h = next(h, tm);
+      const halfedge_descriptor prev_oh = prev(opposite(h, tm), tm);
 
       // check that the border has at least 4 edges not to create degenerate volumes
       if(border_size(h, tm) >= 4)
@@ -151,11 +157,43 @@ void simplify_range(HalfedgeRange& halfedge_range,
             new_tolerance += CGAL::approximate_sqrt(CGAL::squared_distance(new_p, pt));
         }
 
-        if (!CGAL::Euler::does_satisfy_link_condition(edge(h, tm), tm))
+        // check that the collapse does not create a new degenerate face
+        bool do_collapse = true;
+        for(halfedge_descriptor he : halfedges_around_target(h, tm))
+        {
+          if(he != prev_oh && // ignore the triangle incident to h that will disappear
+             !is_border(he, tm) &&
+             collinear(get(vpm, source(he, tm)), new_p, get(vpm, target(next(he,tm),tm))))
+          {
+            do_collapse = false;
+            break;
+          }
+        }
+
+        if(!do_collapse)
           continue;
+
+        for(halfedge_descriptor he : halfedges_around_target(opposite(h,tm), tm))
+        {
+          if(he != opposite(h,tm) &&
+             !is_border(he, tm) &&
+             collinear(get(vpm, source(he, tm)), new_p, get(vpm, target(next(he,tm),tm))))
+          {
+            do_collapse = false;
+            break;
+          }
+        }
+
+        if(!do_collapse)
+          continue;
+
+        if(!CGAL::Euler::does_satisfy_link_condition(edge(h, tm), tm))
+          continue;
+
         const halfedge_descriptor opoh = opposite(prev(opposite(h, tm), tm), tm);
-        if (is_border(opoh, tm))
-          edges_to_test.erase( opoh );
+        if(is_border(opoh, tm))
+          edges_to_test.erase(opoh);
+
         vertex_descriptor v = Euler::collapse_edge(edge(h, tm), tm);
 
         put(vpm, v, new_p);
@@ -163,14 +201,13 @@ void simplify_range(HalfedgeRange& halfedge_range,
 
         if(get(range_halfedges, prev_h))
           edges_to_test.insert(prev_h);
-        if(next_h!=opoh && get(range_halfedges, next_h))
+        if(next_h != opoh && get(range_halfedges, next_h))
           edges_to_test.insert(next_h);
-
         ++collapsed_n;
       }
     }
   }
-
+  CGAL_USE(collapsed_n);
 #ifdef CGAL_PMP_SNAP_DEBUG
   std::cout << "collapsed " << collapsed_n << " edges" << std::endl;
 #endif
@@ -194,7 +231,7 @@ template <typename TriangleMesh,
 class Projection_traits
 {
   typedef typename AABBTraits::FT                                          FT;
-  typedef typename AABBTraits::Point_3                                     Point;
+  typedef typename AABBTraits::Point                                       Point;
   typedef typename AABBTraits::Primitive                                   Primitive;
   typedef typename AABBTraits::Bounding_box                                Bounding_box;
   typedef typename AABBTraits::Primitive::Id                               Primitive_id;
@@ -340,7 +377,7 @@ public:
       return;
 
     const typename Primitive::Datum& s = primitive.datum(m_traits.shared_data());
-    if(m_traits.equal_3_object()(s[0], query) || m_traits.equal_3_object()(s[1], query))
+    if(m_traits.equal_object()(s[0], query) || m_traits.equal_object()(s[1], query))
     {
       // If we are NOT using the same mesh and the query is (geometrically) equal to one extremity
       // of the target edge, we don't want to move the source point away from the target point
@@ -637,7 +674,6 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
 
   typedef typename boost::property_traits<VPMS>::value_type                       Point;
   typedef typename boost::property_traits<VPMT>::reference                        Point_ref;
-  typedef typename GeomTraits::Vector_3                                           Vector;
 
   typedef std::pair<halfedge_descriptor, Point>                                   Vertex_with_new_position;
   typedef std::vector<Vertex_with_new_position>                                   Vertices_with_new_position;
@@ -687,7 +723,12 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
 
       bool do_split = true;
 
-      // Some splits can create degenerate faces, avoid that
+      // In case of self-snapping, avoid degenerate caps
+      const bool is_same_mesh = (&tm_T == &tm_S);
+      if(is_same_mesh && target(next(opposite(h_to_split, tm_T), tm_T), tm_T) == splitter_v)
+        do_split = false;
+
+      // Do not split if it would create a degenerate needle
       if((new_position == get(vpm_T, target(h_to_split, tm_T))) ||
          (new_position == get(vpm_T, source(h_to_split, tm_T))))
         do_split = false;
@@ -695,11 +736,58 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
       if(!first_split && new_position == previous_split_position)
         do_split = false;
 
+      // check if the new faces after split will not be degenerate
+      const Point& p0 = new_position;
+      Point_ref p1 = get(vpm_T, source(h_to_split, tm_T));
+      Point_ref p2 = get(vpm_T, target(next(opposite(h_to_split, tm_T), tm_T), tm_T));
+      Point_ref p3 = get(vpm_T, target(h_to_split, tm_T));
+
+      /* Chooses the diagonal that will split the quad in two triangles that maximizes
+       * the scalar product of the un-normalized normals of the two triangles.
+       *
+       * The lengths of the un-normalized normals (computed using cross-products of two vectors)
+       * are proportional to the area of the triangles.
+       * Maximizing the scalar product of the two normals will avoid skinny triangles,
+       * and will also take into account the cosine of the angle between the two normals.
+       *
+       * In particular, if the two triangles are oriented in different directions,
+       * the scalar product will be negative.
+       */
+      auto p1p3 = CGAL::cross_product(p2-p1, p3-p2) * CGAL::cross_product(p0-p3, p1-p0);
+      auto p0p2 = CGAL::cross_product(p1-p0, p1-p2) * CGAL::cross_product(p3-p2, p3-p0);
+      bool first_split_face = (p0p2 > p1p3);
+
+      if(first_split_face)
+      {
+        if(p0p2 <= 0 || collinear(p0,p1,p2) || collinear(p0,p2,p3))
+          do_split = false;
+      }
+      else
+      {
+        if(p1p3 <= 0 || collinear(p0,p1,p3) || collinear(p1,p2,p3))
+          do_split = false;
+      }
+
+      if(do_split && !is_source_mesh_fixed)
+      {
+        for(halfedge_descriptor h : halfedges_around_target(splitter_v, tm_S))
+        {
+          if(!is_border(h,tm_S) && collinear(get(vpm_S, source(h,tm_S)), new_position, get(vpm_S, target(next(h,tm_S),tm_S))))
+          {
+            do_split = false;
+            break;
+          }
+        }
+
+        if(do_split)
+          put(vpm_S, splitter_v, new_position);
+      }
+
 #ifdef CGAL_PMP_SNAP_DEBUG_PP
       std::cout << " -.-.-. Splitting " << edge(h_to_split, tm_T) << " |||| "
                 << " Vs " << source(h_to_split, tm_T) << " (" << tm_T.point(source(h_to_split, tm_T)) << ")"
                 << " --- Vt " << target(h_to_split, tm_T) << " (" << tm_T.point(target(h_to_split, tm_T)) << ")" << std::endl;
-      std::cout << "With point: " << vnp.second << std::endl;
+      std::cout << "With point: " << new_position << " (init: " << vnp.second << ")" << std::endl;
       std::cout << "Actually split? " << do_split << std::endl;
 #endif
 
@@ -715,75 +803,27 @@ std::size_t split_edges(EdgesToSplitContainer& edges_to_split,
 
         visitor.after_vertex_edge_snap(new_v, tm_T);
       }
-
-      if(!is_source_mesh_fixed)
-        put(vpm_S, splitter_v, new_position);
+      else
+      {
+        continue;
+      }
 
       first_split = false;
       previous_split_position = new_position;
       ++snapped_n;
 
-      // Everything below is choosing the diagonal to triangulate the quad formed by the edge split
-      // So, it's only relevant if splitting has been performed
-      if(!do_split)
-        continue;
-
-      /*          new_p
-       *         /   \
-       *    res /     \ h_to_split
-       *       /       \
-       *      /         \
-       *    left       right
-       *     |         /
-       *     |        /
-       *     |       /
-       *     |      /
-       *     |     /
-       *     |    /
-       *      opp
-       */
-
-      const halfedge_descriptor res = prev(h_to_split, tm_T);
-      const Point_ref left_pt = get(vpm_T, source(res, tm_T));
-      const Point_ref right_pt = get(vpm_T, target(h_to_split, tm_T));
-      const Point_ref opp = get(vpm_T, target(next(opposite(res, tm_T), tm_T), tm_T));
-
-      // Check if 'p' is "visible" from 'opp' (i.e. its projection on the plane 'Pl(left, opp, right)'
-      // falls in the cone with apex 'opp' and sides given by 'left' and 'right')
-      const Vector n = gt.construct_orthogonal_vector_3_object()(right_pt, left_pt, opp);
-      const Point trans_left_pt = gt.construct_translated_point_3_object()(left_pt, n);
-      const Point trans_right_pt = gt.construct_translated_point_3_object()(right_pt, n);
-
-      const Point_ref new_p = get(vpm_T, new_v);
-      const bool left_of_left = (gt.orientation_3_object()(trans_left_pt, left_pt, opp, new_p) == CGAL::POSITIVE);
-      const bool right_of_right = (gt.orientation_3_object()(right_pt, trans_right_pt, opp, new_p) == CGAL::POSITIVE);
-
-      const bool is_visible = (!left_of_left && !right_of_right);
-
-#ifdef CGAL_PMP_SNAP_DEBUG_PP
-      std::cout << "Left/Right: " << left_of_left << " " << right_of_right << std::endl;
-      std::cout << "visible from " << opp << " ? " << is_visible << std::endl;
-#endif
-
-      // h_to_split is equal to 'next(res)' after splitting
-      const halfedge_descriptor h_to_split_opp = opposite(h_to_split, tm_T);
-
-      if(is_visible)
-      {
-        halfedge_descriptor h2 = prev(prev(h_to_split_opp, tm_T), tm_T);
-        halfedge_descriptor new_hd = CGAL::Euler::split_face(h_to_split_opp,
-                                                             h2, tm_T);
-        h_to_split = opposite(prev(new_hd, tm_T), tm_T);
-        visitor.after_split_face(h_to_split_opp, h2, tm_T);
-      }
+      halfedge_descriptor v0, v1, v2, v3;
+      v0 = opposite(h_to_split, tm_T);
+      v1 = next(v0, tm_T);
+      v2 = next(v1, tm_T);
+      v3 = next(v2, tm_T);
+      // halfedge_descriptor new_hd =
+      first_split_face ? CGAL::Euler::split_face(v0, v2, tm_T)
+                       : CGAL::Euler::split_face(v1, v3, tm_T);
+      if(first_split_face)
+        visitor.after_split_face(v0, v2, tm_T);
       else
-      {
-        halfedge_descriptor h2 = prev(h_to_split_opp, tm_T);
-        halfedge_descriptor new_hd = CGAL::Euler::split_face(opposite(res, tm_T),
-                                                             h2, tm_T);
-        h_to_split = opposite(next(new_hd, tm_T), tm_T);
-        visitor.after_split_face(opposite(res, tm_T), h2, tm_T);
-      }
+        visitor.after_split_face(v1, v3, tm_T);
     }
   }
 
@@ -839,7 +879,7 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
   typedef typename boost::property_traits<VPMT>::value_type                       Point;
 
   typedef CGAL::AABB_halfedge_graph_segment_primitive<TriangleMesh, VPMT>         Primitive;
-  typedef CGAL::AABB_traits<GT, Primitive>                                        AABB_Traits;
+  typedef CGAL::AABB_traits_3<GT, Primitive>                                      AABB_Traits;
   typedef CGAL::AABB_tree<AABB_Traits>                                            AABB_tree;
 
   typedef std::pair<halfedge_descriptor, Point>                                   Vertex_with_new_position;
@@ -925,7 +965,7 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
 #endif
 
 #ifndef CGAL_LINKED_WITH_TBB
-  CGAL_static_assertion_msg (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+  static_assert (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                              "Parallel_tag is enabled but TBB is unavailable.");
 #else // CGAL_LINKED_WITH_TBB
   if(std::is_convertible<ConcurrencyTag, Parallel_tag>::value)
@@ -1009,7 +1049,7 @@ std::size_t snap_non_conformal_one_way(const HalfedgeRange& halfedge_range_S,
   }
 }
 
-// \ingroup PMP_repairing_grp
+// \ingroup PMP_geometric_repair_grp
 //
 // Attempts to snap the vertices in `halfedge_range_A` onto edges of `halfedge_range_B`, and reciprocally.
 // A vertex from the first range is only snapped to an edge of the second range if the distance to
@@ -1197,10 +1237,10 @@ std::size_t snap_non_conformal(HalfedgeRange& halfedge_range_A,
   // We keep in memory pairs of source/target edges that are stitchable after vertex-vertex snapping
   // --> these halfedges should not be considered as targets in non-conformal snapping
   // Similarly, matching vertices whose incident edges have matching directions are also locked
-  Locked_vertices locked_vertices_A = get(Vertex_bool_tag(), tm_A);
-  Locked_vertices locked_vertices_B = get(Vertex_bool_tag(), tm_B);
-  Locked_halfedges locked_halfedges_A = get(Halfedge_bool_tag(), tm_A);
-  Locked_halfedges locked_halfedges_B = get(Halfedge_bool_tag(), tm_B);
+  Locked_vertices locked_vertices_A = get(Vertex_bool_tag(), tm_A, false);
+  Locked_vertices locked_vertices_B = get(Vertex_bool_tag(), tm_B, false);
+  Locked_halfedges locked_halfedges_A = get(Halfedge_bool_tag(), tm_A, false);
+  Locked_halfedges locked_halfedges_B = get(Halfedge_bool_tag(), tm_B, false);
 
   std::vector<std::pair<vertex_descriptor, vertex_descriptor> > locked_vertices;
   std::vector<halfedge_descriptor> locked_halfedges_A_vector, locked_halfedges_B_vector;
@@ -1406,6 +1446,8 @@ std::size_t snap_borders(TriangleMesh& tm,
                                                       true /*self snapping*/, np, np);
 }
 
+//TODO:add an option to preserve orientation?
+
 } // end namespace experimental
 } // end namespace Polygon_mesh_processing
 } // end namespace CGAL
