@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/simplify_polyline.h $
-// $Id: simplify_polyline.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/internal/simplify_polyline.h $
+// $Id: include/CGAL/Polygon_mesh_processing/internal/simplify_polyline.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,7 +13,7 @@
 #ifndef CGAL_POLYGON_MESH_PROCESSING_SIMPLIFY_POLYLINE_H
 #define CGAL_POLYGON_MESH_PROCESSING_SIMPLIFY_POLYLINE_H
 
-#include <CGAL/license/Polygon_mesh_processing/repair.h>
+#include <CGAL/license/Polygon_mesh_processing/geometric_repair.h>
 
 #include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
@@ -103,7 +103,7 @@ void simplify_polyline(const PointRangeIn& input,
             ++ei; // we skip ei-1
           else
           {
-            bi=ei-1; // ei-1 shall not be skipt
+            bi=ei-1; // ei-1 shall not be skipped
             break;
           }
         }
@@ -178,7 +178,7 @@ void simplify_polyline(const PointRangeIn& input,
           output.push_back(input[i]);
           put(out_pm, output.back(), get(in_pm, input[i]));
         }
-      //TODO if is_closed-==true, shall we add en extra step to see if we can remove output.front() and output[output.size()-2] (inital endpoints)
+      //TODO if is_closed-==true, shall we add en extra step to see if we can remove output.front() and output[output.size()-2] (initial endpoints)
     }
   }
 }
