@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/remesh.h $
-// $Id: remesh.h e8c5de5 2022-10-06T15:37:03+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/remesh.h $
+// $Id: include/CGAL/Polygon_mesh_processing/remesh.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,6 +18,8 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/Polygon_mesh_processing/internal/Isotropic_remeshing/remesh_impl.h>
+#include <CGAL/Polygon_mesh_processing/Uniform_sizing_field.h>
+#include <CGAL/Polygon_mesh_processing/tangential_relaxation.h>
 
 #include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
@@ -43,12 +45,15 @@ namespace Polygon_mesh_processing {
 *         and `boost::graph_traits<PolygonMesh>::%halfedge_descriptor` must be
 *         models of `Hashable`.
 * @tparam FaceRange range of `boost::graph_traits<PolygonMesh>::%face_descriptor`,
-          model of `Range`. Its iterator type is `ForwardIterator`.
+*         model of `Range`. Its iterator type is `ForwardIterator`.
+* @tparam SizingFunction model of `PMPSizingField`
 * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
 *
 * @param pmesh a polygon mesh with triangulated surface patches to be remeshed
 * @param faces the range of triangular faces defining one or several surface patches to be remeshed
-* @param target_edge_length the edge length that is targeted in the remeshed patch.
+* @param sizing field that determines a target length for individual edges.
+*        If a number convertible to a `double` is passed, `Uniform_sizing_field()` will be used,
+*        with the number as a target edge length.
 *        If `0` is passed then only the edge-flip, tangential relaxation, and projection steps will be done.
 * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 *
@@ -166,6 +171,16 @@ namespace Polygon_mesh_processing {
 *     \cgalParamDefault{`false`}
 *   \cgalParamNEnd
 *
+*   \cgalParamNBegin{allow_move_functor}
+*     \cgalParamDescription{A function object used to determinate if a vertex move should
+*                           be allowed or not during the relaxation step.}
+*     \cgalParamType{Functor that provides `bool operator()(vertex_descriptor v, Point_3 src, Point_3 tgt)`
+*                    returning `true`
+*                    if the vertex `v` can be moved from `src` to `tgt`;
+*                    `%Point_3` being the value type of the vertex point map }
+*     \cgalParamDefault{If not provided, all moves are allowed.}
+*   \cgalParamNEnd
+*
 *   \cgalParamNBegin{do_project}
 *     \cgalParamDescription{whether vertices should be reprojected on the input surface after creation or displacement}
 *     \cgalParamType{Boolean}
@@ -193,13 +208,15 @@ namespace Polygon_mesh_processing {
 */
 template<typename PolygonMesh
        , typename FaceRange
-       , typename NamedParameters = parameters::Default_named_parameters>
+       , typename SizingFunction
+       , typename NamedParameters = parameters::Default_named_parameters
+       , typename = typename std::enable_if_t<!std::is_convertible_v<SizingFunction, double>>>
 void isotropic_remeshing(const FaceRange& faces
-                       , const double& target_edge_length
+                       , SizingFunction& sizing
                        , PolygonMesh& pmesh
                        , const NamedParameters& np = parameters::default_values())
 {
-  if (boost::begin(faces)==boost::end(faces))
+  if (std::begin(faces)==std::end(faces))
     return;
 
   typedef PolygonMesh PM;
@@ -261,8 +278,8 @@ void isotropic_remeshing(const FaceRange& faces
 #endif
     ) ) );
 
-  double low = 4. / 5. * target_edge_length;
-  double high = 4. / 3. * target_edge_length;
+  auto shall_move = choose_parameter(get_parameter(np, internal_np::allow_move_functor),
+                                     internal::Allow_all_moves());
 
 #if !defined(CGAL_NO_PRECONDITIONS)
   if(protect)
@@ -271,7 +288,7 @@ void isotropic_remeshing(const FaceRange& faces
     msg.append(" true with constraints larger than 4/3 * target_edge_length.");
     msg.append(" Remeshing aborted.");
     CGAL_precondition_msg(
-      internal::constraints_are_short_enough(pmesh, ecmap, vpmap, fpmap, high),
+      internal::constraints_are_short_enough(pmesh, ecmap, fpmap, sizing),
       msg.c_str());
   }
 #endif
@@ -303,8 +320,7 @@ void isotropic_remeshing(const FaceRange& faces
 
 #ifdef CGAL_PMP_REMESHING_VERBOSE
   std::cout << std::endl;
-  std::cout << "Remeshing (size = " << target_edge_length;
-  std::cout << ", #iter = " << nb_iterations << ")..." << std::endl;
+  std::cout << "Remeshing (#iter = " << nb_iterations << ")..." << std::endl;
   t.reset(); t.start();
 #endif
 
@@ -313,16 +329,14 @@ void isotropic_remeshing(const FaceRange& faces
 #ifdef CGAL_PMP_REMESHING_VERBOSE
     std::cout << " * Iteration " << (i + 1) << " *" << std::endl;
 #endif
-    if (target_edge_length>0)
-    {
-      if(do_split)
-        remesher.split_long_edges(high);
-      if(do_collapse)
-        remesher.collapse_short_edges(low, high, collapse_constraints);
-    }
+
+    if(do_split)
+     remesher.split_long_edges(sizing);
+    if(do_collapse)
+     remesher.collapse_short_edges(sizing, collapse_constraints);
     if(do_flip)
       remesher.flip_edges_for_valence_and_shape();
-    remesher.tangential_relaxation_impl(smoothing_1d, nb_laplacian);
+    remesher.tangential_relaxation_impl(smoothing_1d, nb_laplacian, sizing, shall_move);
     if ( choose_parameter(get_parameter(np, internal_np::do_project), true) )
       remesher.project_to_surface(get_parameter(np, internal_np::projection_functor));
 #ifdef CGAL_PMP_REMESHING_VERBOSE
@@ -332,12 +346,36 @@ void isotropic_remeshing(const FaceRange& faces
 
 #ifdef CGAL_PMP_REMESHING_VERBOSE
   t.stop();
-  std::cout << "Remeshing done (size = " << target_edge_length;
-  std::cout << ", #iter = " << nb_iterations;
+  std::cout << "Remeshing done (#iter = " << nb_iterations;
   std::cout << ", " << t.time() << " sec )." << std::endl;
 #endif
 }
 
+// Overload when using target_edge_length for sizing
+template<typename PolygonMesh
+       , typename FaceRange
+       , typename SizingValue
+       , typename NamedParameters = parameters::Default_named_parameters
+       , typename = typename std::enable_if_t<std::is_convertible_v<SizingValue, double>>>
+void isotropic_remeshing(const FaceRange& faces
+                       , const SizingValue target_edge_length
+                       , PolygonMesh& pmesh
+                       , const NamedParameters& np = parameters::default_values())
+{
+  using parameters::choose_parameter;
+  using parameters::get_parameter;
+
+  typedef typename GetVertexPointMap<PolygonMesh, NamedParameters>::type VPMap;
+  VPMap vpmap = choose_parameter(get_parameter(np, internal_np::vertex_point),
+    get_property_map(vertex_point, pmesh));
+
+  Uniform_sizing_field<PolygonMesh, VPMap> sizing(target_edge_length, vpmap);
+  if (target_edge_length > 0)
+    isotropic_remeshing(faces, sizing, pmesh, np);
+  else
+    isotropic_remeshing(faces, sizing, pmesh, np.do_split(false).do_collapse(false));
+}
+
 /*!
 * \ingroup PMP_meshing_grp
 * @brief splits the edges listed in `edges` into sub-edges
@@ -352,12 +390,13 @@ void isotropic_remeshing(const FaceRange& faces
 *         has an internal property map for `CGAL::vertex_point_t`.
 * @tparam EdgeRange range of `boost::graph_traits<PolygonMesh>::%edge_descriptor`,
 *   model of `Range`. Its iterator type is `InputIterator`.
+* @tparam SizingFunction model of `PMPSizingField`
 * @tparam NamedParameters a sequence of \ref bgl_namedparameters "Named Parameters"
 *
 * @param pmesh a polygon mesh
 * @param edges the range of edges to be split if they are longer than given threshold
-* @param max_length the edge length above which an edge from `edges` is split
-*        into to sub-edges
+* @param sizing the sizing function that is used to split edges from 'edges' list. If a number convertible to
+*        a `double` is passed,  `Uniform_sizing_field()` will be used, with the number as target edge length.
 * @param np an optional sequence of \ref bgl_namedparameters "Named Parameters" among the ones listed below
 
 * \cgalNamedParamsBegin
@@ -402,9 +441,11 @@ void isotropic_remeshing(const FaceRange& faces
 */
 template<typename PolygonMesh
        , typename EdgeRange
-       , typename NamedParameters = parameters::Default_named_parameters>
+       , typename SizingFunction
+       , typename NamedParameters = parameters::Default_named_parameters
+       , typename = typename std::enable_if_t<!std::is_convertible_v<SizingFunction, double>>>
 void split_long_edges(const EdgeRange& edges
-                    , const double& max_length
+                    , SizingFunction& sizing
                     , PolygonMesh& pmesh
                     , const NamedParameters& np = parameters::default_values())
 {
@@ -451,7 +492,23 @@ void split_long_edges(const EdgeRange& edges
              fimap,
              false/*need aabb_tree*/);
 
-  remesher.split_long_edges(edges, max_length);
+     remesher.split_long_edges(edges, sizing);
+}
+
+// Convenience overload when using max_length for sizing
+template<typename PolygonMesh
+       , typename EdgeRange
+       , typename SizingValue
+       , typename NamedParameters = parameters::Default_named_parameters
+       , typename = typename std::enable_if_t<std::is_convertible_v<SizingValue, double>>>
+void split_long_edges(const EdgeRange& edges
+                    , const SizingValue max_length
+                    , PolygonMesh& pmesh
+                    , const NamedParameters& np = parameters::default_values())
+{
+  // construct the uniform field, 3/4 as m_sq_long is stored with 4/3 of length
+  Uniform_sizing_field sizing(3. / 4. * max_length, pmesh);
+  split_long_edges(edges, sizing, pmesh, np);
 }
 
 } //end namespace Polygon_mesh_processing
