@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Polygonal_surface_reconstruction/include/CGAL/Polygonal_surface_reconstruction.h $
-// $Id: Polygonal_surface_reconstruction.h d8c92fc 2022-08-02T13:32:36+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygonal_surface_reconstruction/include/CGAL/Polygonal_surface_reconstruction.h $
+// $Id: include/CGAL/Polygonal_surface_reconstruction.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Liangliang Nan
@@ -18,6 +18,10 @@
 #include <CGAL/Polygonal_surface_reconstruction/internal/hypothesis.h>
 #include <CGAL/Polygonal_surface_reconstruction/internal/compute_confidences.h>
 #include <CGAL/Polygonal_surface_reconstruction/internal/point_set_with_planes.h>
+#include <CGAL/Polygon_mesh_processing/orient_polygon_soup.h>
+#include <CGAL/Polygon_mesh_processing/polygon_soup_to_polygon_mesh.h>
+#include <CGAL/Polygon_mesh_processing/polygon_mesh_to_polygon_soup.h>
+#include <CGAL/Polygon_mesh_processing/repair_polygon_soup.h>
 
 #include <unordered_map>
 
@@ -28,7 +32,7 @@
 namespace CGAL {
 
         /*!
-        \ingroup PkgPolygonalSurfaceReconstruction
+        \ingroup PkgPolygonalSurfaceReconstructionRef
 
         \brief
 
@@ -455,7 +459,12 @@ namespace CGAL {
 
                         // Converts from internal data structure to the required `PolygonMesh`.
                         output_mesh.clear();        // make sure it is empty.
-                        CGAL::copy_face_graph(target_mesh, output_mesh);
+                        std::vector<Point> points;
+                        std::vector<std::vector<std::size_t> > polygons;
+                        CGAL::Polygon_mesh_processing::polygon_mesh_to_polygon_soup(target_mesh, points, polygons);
+                        CGAL::Polygon_mesh_processing::merge_duplicate_points_in_polygon_soup(points, polygons);
+                        CGAL::Polygon_mesh_processing::orient_polygon_soup(points, polygons);
+                        CGAL::Polygon_mesh_processing::polygon_soup_to_polygon_mesh(points, polygons, output_mesh);
                 }
                 else {
                         error_message_ = "solving the binary program failed";
