@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polynomial/include/CGAL/Polynomial_traits_d.h $
-// $Id: Polynomial_traits_d.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polynomial/include/CGAL/Polynomial_traits_d.h $
+// $Id: include/CGAL/Polynomial_traits_d.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -389,7 +389,7 @@ public:
   struct Substitute_homogeneous{
   public:
     // this is the end of the recursion
-    // begin contains the homogeneous variabel
+    // begin contains the homogeneous variable
     // hdegree is the remaining degree
     template <class Input_iterator>
     typename
@@ -462,7 +462,7 @@ private:
 
 
   // We use our own Strict Weak Ordering predicate in order to avoid
-  // problems when calling sort for a Exponents_coeff_pair where the
+  // problems when calling sort for an `Exponents_coeff_pair` where the
   // coeff type has no comparison operators available.
 private:
   struct Compare_exponents_coeff_pair
@@ -566,7 +566,7 @@ public:
     template <class Input_iterator, class NT> Polynomial_d
     construct_value_type(Input_iterator begin, Input_iterator end, NT) const {
       typedef CGAL::Coercion_traits<NT,Coefficient_type> CT;
-      CGAL_static_assertion((boost::is_same<typename CT::Type,Coefficient_type>::value));
+      static_assert(std::is_same<typename CT::Type,Coefficient_type>::value);
       typename CT::Cast cast;
       return Polynomial_d(
           boost::make_transform_iterator(begin,cast),
@@ -618,7 +618,7 @@ public:
     operator()( Input_iterator begin, Input_iterator end ) const {
       if(begin == end ) return Polynomial_d(0);
       typedef typename std::iterator_traits<Input_iterator>::value_type value_type;
-      typedef Boolean_tag<boost::is_same<value_type,Coefficient_type>::value>
+      typedef Boolean_tag<std::is_same<value_type,Coefficient_type>::value>
         Is_coeff;
       std::vector<value_type> vec(begin,end);
       return construct(vec.begin(),vec.end(),Is_coeff());
@@ -667,7 +667,7 @@ public:
         typedef Polynomial_traits_d<Coefficient_type> PT;
         typename PT::Construct_polynomial construct;
 
-        CGAL_static_assertion(PT::d != 0); // Coefficient_type is a Polynomial
+        static_assert(PT::d != 0); // Coefficient_type is a Polynomial
         std::vector<Coefficient_type> coefficients;
 
         Coefficient_type zero(0);
@@ -999,7 +999,7 @@ public:
 
   // Sign_at, Sign_at_homogeneous, Compare
   // define XXX_ even though ICoeff may not be Real_embeddable
-  // select propoer XXX among XXX_ or Null_functor using ::boost::mpl::if_
+  // select proper XXX among XXX_ or Null_functor using ::std::conditional_t
 private:
   struct Sign_at_ {
   private:
@@ -1036,8 +1036,8 @@ private:
   typedef Real_embeddable_traits<Innermost_coefficient_type> RET_IC;
   typedef typename RET_IC::Is_real_embeddable IC_is_real_embeddable;
 public:
-  typedef typename ::boost::mpl::if_<IC_is_real_embeddable,Sign_at_,Null_functor>::type Sign_at;
-  typedef typename ::boost::mpl::if_<IC_is_real_embeddable,Sign_at_homogeneous_,Null_functor>::type Sign_at_homogeneous;
+  typedef std::conditional_t<IC_is_real_embeddable::value,Sign_at_,Null_functor> Sign_at;
+  typedef std::conditional_t<IC_is_real_embeddable::value,Sign_at_homogeneous_,Null_functor> Sign_at_homogeneous;
   typedef typename Real_embeddable_traits<Polynomial_d>::Compare Compare;
 
 
