@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/GraphicsView/include/CGAL/Qt/DemosMainWindow_impl.h $
-// $Id: DemosMainWindow_impl.h c9a020b 2021-02-09T12:12:56+01:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/GraphicsView/include/CGAL/Qt/DemosMainWindow_impl.h $
+// $Id: include/CGAL/Qt/DemosMainWindow_impl.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -32,15 +32,14 @@
 #include <QMessageBox>
 #include <QStatusBar>
 #include <QGraphicsView>
-#include <QGLWidget>
 #include <QTextStream>
 #include <QSettings>
 #include <QUrl>
-#include <QDesktopWidget>
-#include <QRegExp>
-#include <QSvgGenerator>
+#include <QRegularExpression>
+#if QT_SVG_LIB
+#  include <QSvgGenerator>
+#endif
 #include <QtCore>
-#include <QtOpenGL>
 
 #include <CGAL/config.h> // needed to get CGAL_VERSION_STR
 #include <CGAL/Qt/DemosMainWindow.h>
@@ -61,13 +60,6 @@ DemosMainWindow::DemosMainWindow(QWidget * parent, ::Qt::WindowFlags flags)
   xycoord->setMinimumSize(xycoord->sizeHint());
   xycoord->clear();
 
-  actionUse_OpenGL = new QAction(this);
-  actionUse_OpenGL->setObjectName("actionUse_OpenGL");
-  actionUse_OpenGL->setCheckable(true);
-  actionUse_OpenGL->setText(tr("Use &OpenGL"));
-  actionUse_OpenGL->setStatusTip(tr("Make Qt use OpenGL to display the graphical items, instead of its native painting system."));
-  actionUse_OpenGL->setShortcut(tr("Ctrl+G"));
-
   actionUse_Antialiasing = new QAction(this);
   actionUse_Antialiasing->setObjectName("actionUse_Antialiasing");
   actionUse_Antialiasing->setCheckable(true);
@@ -150,15 +142,13 @@ DemosMainWindow::setupOptionsMenu(QMenu* menuOptions)
   if(!menuOptions->isEmpty()) {
     menuOptions->addSeparator();
   }
-  menuOptions->addAction(actionUse_OpenGL);
   menuOptions->addAction(actionUse_Antialiasing);
   connect(actionUse_Antialiasing, SIGNAL(toggled(bool)),
           this, SLOT(setUseAntialiasing(bool)));
-  connect(actionUse_OpenGL, SIGNAL(toggled(bool)),
-          this, SLOT(setUseOpenGL(bool)));
   actionUse_Antialiasing->setChecked(true);
 }
 
+#if QT_SVG_LIB
 CGAL_INLINE_FUNCTION
 void
 DemosMainWindow::setupExportSVG(QAction* action, QGraphicsView* view)
@@ -189,6 +179,7 @@ void DemosMainWindow::exportSVG()
   this->view->render(&painter);
   painter.end();
 }
+#endif // QT_SVG_LIB
 
 CGAL_INLINE_FUNCTION
 void
@@ -200,31 +191,6 @@ DemosMainWindow::setUseAntialiasing(bool checked)
                            1000);
 }
 
-CGAL_INLINE_FUNCTION
-void
-DemosMainWindow::setUseOpenGL(bool checked)
-{
-  if(checked) {
-    QGLWidget* new_viewport = new QGLWidget;
-
-    // Setup the format to allow antialiasing with OpenGL:
-    // one need to activate the SampleBuffers, if the graphic driver allows
-    // this.
-    QGLFormat glformat = new_viewport->format();
-    glformat.setOption(QGL::SampleBuffers);
-    new_viewport->setFormat(glformat);
-
-    view->setViewport(new_viewport);
-  }
-  else {
-    view->setViewport(new QWidget);
-  }
-  statusBar()->showMessage(tr("OpenGL %1activated").arg(checked?"":"de-"),
-                           1000);
-  view->viewport()->installEventFilter(navigation);
-  view->setFocus();
-}
-
 CGAL_INLINE_FUNCTION
 QMenu*
 DemosMainWindow::getMenu(QString objectName, QString title)
@@ -449,13 +415,7 @@ void DemosMainWindow::readState(QString groupname, Options /*what_to_save*/)
   resize(settings.value("size", this->size()).toSize());
 
   QPoint pos = settings.value("pos", this->pos()).toPoint();
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
   if(QGuiApplication::screenAt(pos)) {
-#else
-   QDesktopWidget* desktop = qApp->desktop();
-     if(desktop->availableGeometry(pos).contains(pos)) {
-#endif
-
     move(pos);
   }
   settings.endGroup();
