@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Kernel_23/include/CGAL/Ray_2.h $
-// $Id: Ray_2.h 3fa4364 2022-06-10T08:41:19+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Ray_2.h $
+// $Id: include/CGAL/Ray_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -42,7 +42,7 @@ class Ray_2 : public R_::Kernel_base::Ray_2
   typedef typename R_::Kernel_base::Ray_2    RRay_2;
 
   typedef Ray_2                              Self;
-  CGAL_static_assertion((std::is_same<Self, typename R_::Ray_2>::value));
+  static_assert(std::is_same<Self, typename R_::Ray_2>::value);
 
 public:
 
