@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Triangulation_2/include/CGAL/Regular_triangulation_2.h $
-// $Id: Regular_triangulation_2.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_2/include/CGAL/Regular_triangulation_2.h $
+// $Id: include/CGAL/Regular_triangulation_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Frederic Fichel, Mariette Yvinec, Julia Floetotto
@@ -18,11 +18,11 @@
 #include <CGAL/Regular_triangulation_face_base_2.h>
 #include <CGAL/Regular_triangulation_vertex_base_2.h>
 
+#include <CGAL/assertions.h>
 #include <CGAL/utility.h>
 #include <CGAL/Object.h>
 #include <CGAL/STL_Extension/internal/Has_nested_type_Bare_point.h>
 
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/identity.hpp>
 #include <boost/utility/result_of.hpp>
 
@@ -162,7 +162,7 @@ public:
     Self & operator--() { Base::operator--(); return *this; }
     Self operator++(int) { Self tmp(*this); ++(*this); return tmp; }
     Self operator--(int) { Self tmp(*this); --(*this); return tmp; }
-    operator Vertex_handle() const { return Base::base(); }
+    operator const Vertex_handle&() const { return Base::base(); }
   };
 
   typedef Iterator_range<Prevent_deref<All_vertices_iterator> > All_vertex_handles;
@@ -179,10 +179,11 @@ public:
     Self & operator--() { Base::operator--(); return *this; }
     Self operator++(int) { Self tmp(*this); ++(*this); return tmp; }
     Self operator--(int) { Self tmp(*this); --(*this); return tmp; }
-    operator Vertex_handle() const { return Base::base(); }
+    operator const Vertex_handle&() const { return Base::base(); }
  };
 
-  typedef Iterator_range<Prevent_deref<Finite_vertices_iterator> > Finite_vertex_handles;
+  typedef Iterator_range<Prevent_deref<Finite_vertices_iterator,
+                                       const Vertex_handle&>> Finite_vertex_handles;
 
   class Hidden_vertices_iterator :
     public Filter_iterator<Finite_vib, Unhidden_tester>
@@ -196,10 +197,11 @@ public:
     Self & operator--() { Base::operator--(); return *this; }
     Self operator++(int) { Self tmp(*this); ++(*this); return tmp; }
     Self operator--(int) { Self tmp(*this); --(*this); return tmp; }
-    operator Vertex_handle() const { return Base::base(); }
+    operator const Vertex_handle&() const { return Base::base(); }
  };
 
-  typedef Iterator_range<Prevent_deref<Hidden_vertices_iterator> > Hidden_vertex_handles;
+  typedef Iterator_range<Prevent_deref<Hidden_vertices_iterator,
+                                       const Vertex_handle&>> Hidden_vertex_handles;
 
  //for backward compatibility
   typedef Finite_faces_iterator                Face_iterator;
@@ -393,12 +395,12 @@ public:
   template < class InputIterator >
   std::ptrdiff_t
   insert(InputIterator first, InputIterator last,
-          typename boost::enable_if<
-              boost::is_convertible<
+          std::enable_if_t<
+              std::is_convertible<
                   typename std::iterator_traits<InputIterator>::value_type,
                   Weighted_point
-              >
-          >::type* = nullptr
+              >::value
+          >* = nullptr
 )
 #else
   template < class InputIterator >
@@ -514,12 +516,12 @@ public:
   std::ptrdiff_t
   insert(InputIterator first,
           InputIterator last,
-          typename boost::enable_if<
-              boost::is_convertible<
+          std::enable_if_t<
+              std::is_convertible<
                 typename std::iterator_traits<InputIterator>::value_type,
                 std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type>
-              >
-          >::type* = nullptr
+              >::value
+          >* = nullptr
 )
   {return insert_with_info< std::pair<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);}
 
@@ -527,12 +529,10 @@ public:
   std::ptrdiff_t
   insert(boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > first,
           boost::zip_iterator< boost::tuple<InputIterator_1,InputIterator_2> > last,
-          typename boost::enable_if<
-            boost::mpl::and_<
-              typename boost::is_convertible< typename std::iterator_traits<InputIterator_1>::value_type, Weighted_point >,
-              typename boost::is_convertible< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
-            >
-          >::type* =nullptr
+          std::enable_if_t<
+              std::is_convertible_v< typename std::iterator_traits<InputIterator_1>::value_type, Weighted_point > &&
+              std::is_convertible_v< typename std::iterator_traits<InputIterator_2>::value_type, typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type >
+          >* =nullptr
 )
   {return insert_with_info< boost::tuple<Weighted_point,typename internal::Info_check<typename Triangulation_data_structure::Vertex>::type> >(first,last);}
 #endif //CGAL_TRIANGULATION_2_DONT_INSERT_RANGE_OF_POINTS_WITH_INFO
@@ -563,7 +563,7 @@ public:
                                                  Face_handle start =
       Face_handle()) const
   {
-    CGAL_triangulation_precondition(dimension() == 2);
+    CGAL_precondition(dimension() == 2);
     int li;
     Locate_type lt;
     Face_handle fh = locate(p,lt,li, start);
@@ -640,7 +640,7 @@ public:
         }
         return  make_triple(fit, eit, vit);
     }
-    CGAL_triangulation_assertion(false);
+    CGAL_assertion(false);
     return make_triple(fit, eit, vit);
   }
 
@@ -771,7 +771,7 @@ copy_triangulation_()
   for(; hvit !=  hidden_vertices_end() ; ++hvit){
     hvit->face()->vertex_list().push_back(hvit);
   }
-  CGAL_triangulation_postcondition(is_valid());
+  CGAL_postcondition(is_valid());
 }
 
 template < class Gt, class Tds >
@@ -838,7 +838,7 @@ power_test(const Face_handle& f, int i, const Weighted_point &p) const
   // p is supposed to be on  edge(f,i)
   // return ON_NEGATIVE_SIDE if p is above(f,i)
   // (p has to be hidden)
-  CGAL_triangulation_precondition(!is_infinite(f,i) &&
+  CGAL_precondition(!is_infinite(f,i) &&
                                    orientation(f->vertex(ccw(i))->point(),
                                                f->vertex(cw(i))->point(),
                                                p) == COLLINEAR);
@@ -857,7 +857,7 @@ power_test(const Weighted_point &p0,
            const Weighted_point &p,
            bool perturb) const
 {
-  CGAL_triangulation_precondition(orientation(p0, p1, p2) == POSITIVE);
+  CGAL_precondition(orientation(p0, p1, p2) == POSITIVE);
 
   using namespace boost;
 
@@ -887,7 +887,7 @@ power_test(const Weighted_point &p0,
       return o;
   }
 
-  CGAL_triangulation_assertion(false);
+  CGAL_assertion(false);
   return ON_NEGATIVE_SIDE;
 }
 
@@ -920,7 +920,7 @@ is_valid_face(Face_handle fh) const
   bool result = true;
   if(is_infinite(fh)) result = result && fh->vertex_list().empty();
   if(!result) { show_face(fh);}
-  CGAL_triangulation_assertion(result);
+  CGAL_assertion(result);
 
   typename Vertex_list::iterator vlit = fh->vertex_list().begin(),
                                  vldone = fh->vertex_list().end();
@@ -928,7 +928,7 @@ is_valid_face(Face_handle fh) const
     result = result && power_test(fh,(*vlit)->point()) == ON_NEGATIVE_SIDE;
     result = result &&((*vlit)->face() == fh);
     if(!result)     show_face(fh);
-    CGAL_triangulation_assertion(result);
+    CGAL_assertion(result);
   }
   return result;
 }
@@ -978,7 +978,7 @@ is_valid_vertex(Vertex_handle vh) const
 //      show_face(vh->face());
 //    }
   }
-  CGAL_triangulation_assertion(result);
+  CGAL_assertion(result);
   return result;
 }
 
@@ -1022,7 +1022,7 @@ is_valid(bool verbose, int /* level */) const
                                       it2->point(),
                                       it3->point());
           result = result && s == COLLINEAR ;
-          CGAL_triangulation_assertion(result);
+          CGAL_assertion(result);
           ++it1 ; ++it2; ++it3;
         }
       }
@@ -1030,18 +1030,18 @@ is_valid(bool verbose, int /* level */) const
     case 2 :
       for(Finite_faces_iterator it=finite_faces_begin();
           it!=finite_faces_end(); it++) {
-        CGAL_triangulation_assertion(! is_infinite(it));
+        CGAL_assertion(! is_infinite(it));
         Orientation s = orientation(it->vertex(0)->point(),
                                     it->vertex(1)->point(),
                                     it->vertex(2)->point());
-        CGAL_triangulation_assertion(s == LEFT_TURN);
+        CGAL_assertion(s == LEFT_TURN);
         result = result && (s == LEFT_TURN);
 
         for(int i = 0 ; i < 3 ; i++) {
           if(!is_infinite(it->vertex(i)))
             result = result && ON_POSITIVE_SIDE !=
                 power_test(it->neighbor(i), it->vertex(i)->point());
-          CGAL_triangulation_assertion(result);
+          CGAL_assertion(result);
         }
       }
 
@@ -1053,7 +1053,7 @@ is_valid(bool verbose, int /* level */) const
         Orientation s = orientation(pc->point(),
                                     qc->point(),
                                     rc->point());
-        CGAL_triangulation_assertion(s != LEFT_TURN);
+        CGAL_assertion(s != LEFT_TURN);
         result = result && (s != LEFT_TURN);
         ++pc ; ++qc ; ++rc;
       } while(pc != start);
@@ -1063,7 +1063,7 @@ is_valid(bool verbose, int /* level */) const
       result = result && (number_of_faces() == 2*(number_of_vertices()+1)
                           - 4
                           - degree(infinite_vertex()));
-      CGAL_triangulation_assertion(result);
+      CGAL_assertion(result);
       break;
   }
 
@@ -1075,7 +1075,7 @@ is_valid(bool verbose, int /* level */) const
   }
   result = result && (Base::number_of_vertices() ==
                        number_of_vertices() + number_of_hidden_vertices());
-  CGAL_triangulation_assertion(result);
+  CGAL_assertion(result);
   return result;
 }
 
@@ -1167,7 +1167,7 @@ typename Regular_triangulation_2<Gt,Tds>::Bare_point
 Regular_triangulation_2<Gt,Tds>::
 weighted_circumcenter(Face_handle f) const
 {
-  CGAL_triangulation_precondition(dimension() == 2 || !is_infinite(f));
+  CGAL_precondition(dimension() == 2 || !is_infinite(f));
   return weighted_circumcenter(f->vertex(0)->point(),
                                f->vertex(1)->point(),
                                f->vertex(2)->point());
@@ -1194,7 +1194,7 @@ dual(const Edge &e) const
   typedef typename Geom_traits::Ray_2         Ray;
   typedef typename Geom_traits::Segment_2     Segment;
 
-  CGAL_triangulation_precondition(! is_infinite(e));
+  CGAL_precondition(! is_infinite(e));
   if(dimension() == 1){
     const Weighted_point& p = (e.first)->vertex(cw(e.second))->point();
     const Weighted_point& q = (e.first)->vertex(ccw(e.second))->point();
@@ -1354,7 +1354,7 @@ typename Regular_triangulation_2<Gt,Tds>::Vertex_handle
 Regular_triangulation_2<Gt,Tds>::
 reinsert(Vertex_handle v, Face_handle start)
 {
-  CGAL_triangulation_assertion(v->is_hidden());
+  CGAL_assertion(v->is_hidden());
   v->set_hidden(false);
   _hidden_vertices--;
 
@@ -1385,8 +1385,8 @@ void
 Regular_triangulation_2<Gt,Tds>::
 exchange_hidden(Vertex_handle va, Vertex_handle vb)
 {
-  CGAL_triangulation_assertion(vb->is_hidden());
-  CGAL_triangulation_assertion(vb == vb->face()->vertex_list().back());
+  CGAL_assertion(vb->is_hidden());
+  CGAL_assertion(vb == vb->face()->vertex_list().back());
 
 //  //to debug
 //  std::cerr << "from exchange hidden 1" << std::endl;
@@ -1411,7 +1411,7 @@ void
 Regular_triangulation_2<Gt,Tds>::
 exchange_incidences(Vertex_handle va, Vertex_handle vb)
 {
-  CGAL_triangulation_assertion(!vb->is_hidden());
+  CGAL_assertion(!vb->is_hidden());
   std::list<Face_handle> faces;
   if(dimension() == 0) {
     faces.push_back(vb->face());
@@ -1421,7 +1421,7 @@ exchange_incidences(Vertex_handle va, Vertex_handle vb)
     faces.push_back(vb->face()->neighbor(1-i));
   }
   else {
-    CGAL_triangulation_assertion(dimension() == 2);
+    CGAL_assertion(dimension() == 2);
     Face_circulator fc = incident_faces(vb), done(fc);
     do {
       faces.push_back(fc);
@@ -1486,12 +1486,12 @@ void
 Regular_triangulation_2<Gt,Tds>::
 regularize(Vertex_handle v)
 {
-  CGAL_triangulation_precondition(v != infinite_vertex());
+  CGAL_precondition(v != infinite_vertex());
   Faces_around_stack faces_around;
 
   if(dimension() < 1) return;
 
-  //initialise faces_around
+  //initialize faces_around
   if(dimension() == 1) {
     faces_around.push_back(v->face());
     faces_around.push_back(v->face()->neighbor(1- v->face()->index(v)));
@@ -1553,8 +1553,8 @@ void
 Regular_triangulation_2<Gt,Tds>::
 remove(Vertex_handle v)
 {
-  CGAL_triangulation_precondition(v != Vertex_handle());
-  CGAL_triangulation_precondition(!is_infinite(v));
+  CGAL_precondition(v != Vertex_handle());
+  CGAL_precondition(!is_infinite(v));
 
   if(v->is_hidden())
     return remove_hidden(v);
@@ -1821,7 +1821,7 @@ void
 Regular_triangulation_2<Gt,Tds>::
 update_hidden_points_2_2(const Face_handle& f1, const Face_handle& f2)
 {
-  CGAL_triangulation_assertion(f1->has_neighbor(f2));
+  CGAL_assertion(f1->has_neighbor(f2));
 
   Vertex_list p_list;
   p_list.splice(p_list.begin(), f1->vertex_list());
@@ -1862,7 +1862,7 @@ update_hidden_points_2_2(const Face_handle& f1, const Face_handle& f2)
   int idx2 = f1->index(f2);
   Vertex_handle v0=f1->vertex(ccw(idx2));
   Vertex_handle v1=f1->vertex(cw(idx2));
-  CGAL_triangulation_assertion(!is_infinite(v0) && !is_infinite(v1));
+  CGAL_assertion(!is_infinite(v0) && !is_infinite(v1));
 
   while(! p_list.empty())
   {
@@ -1883,7 +1883,7 @@ Regular_triangulation_2<Gt,Tds>::
 update_hidden_points_1_3(const Face_handle& f1, const Face_handle& f2,
                          const Face_handle& f3)
 {
-  CGAL_triangulation_assertion(f1->has_neighbor(f2) &&
+  CGAL_assertion(f1->has_neighbor(f2) &&
                                f2->has_neighbor(f3) &&
                                f3->has_neighbor(f1));
 
@@ -1903,9 +1903,9 @@ update_hidden_points_1_3(const Face_handle& f1, const Face_handle& f2,
       v0 = f1->vertex(3-(idx2+idx3)),
       v1 = f2->vertex(f2->index(f1));
 
-  CGAL_triangulation_assertion(f2->has_vertex(v0) && f1->has_vertex(v0));
-  CGAL_triangulation_assertion(f3->has_vertex(v1));
-  CGAL_triangulation_assertion(! is_infinite(v0));
+  CGAL_assertion(f2->has_vertex(v0) && f1->has_vertex(v0));
+  CGAL_assertion(f3->has_vertex(v1));
+  CGAL_assertion(! is_infinite(v0));
 
   // if two of f1, f2,and f3 are infinite
   // the list goes entirely to the third finite face
@@ -2216,7 +2216,7 @@ typename Regular_triangulation_2<Gt,Tds>::Vertex_handle
 Regular_triangulation_2<Gt,Tds>::
 finite_vertex() const
 {
-  CGAL_triangulation_precondition(number_of_vertices() >= 1);
+  CGAL_precondition(number_of_vertices() >= 1);
   return(finite_vertices_begin());
 }
 
@@ -2235,7 +2235,7 @@ typename Regular_triangulation_2<Gt,Tds>::Finite_vertex_handles
 Regular_triangulation_2<Gt,Tds>::
 finite_vertex_handles() const
 {
-  return make_prevent_deref_range(finite_vertices_begin(),finite_vertices_end());
+    return { finite_vertices_begin(), finite_vertices_end() };
 }
 
 template < class Gt, class Tds >
@@ -2262,7 +2262,7 @@ typename Regular_triangulation_2<Gt,Tds>::Hidden_vertex_handles
 Regular_triangulation_2<Gt,Tds>::
 hidden_vertex_handles() const
 {
-  return make_prevent_deref_range(hidden_vertices_begin(),hidden_vertices_end());
+  return { hidden_vertices_begin(), hidden_vertices_end() };
 }
 
 template < class Gt, class Tds >
