@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Scale_space_reconstruction_3/include/CGAL/Scale_space_reconstruction_3/Weighted_PCA_smoother.h $
-// $Id: Weighted_PCA_smoother.h efc0c52 2021-01-15T10:02:00+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Scale_space_reconstruction_3/include/CGAL/Scale_space_reconstruction_3/Weighted_PCA_smoother.h $
+// $Id: include/CGAL/Scale_space_reconstruction_3/Weighted_PCA_smoother.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s):      Thijs van Lankveld, Simon Giraudot
@@ -41,7 +41,7 @@ namespace Scale_space_reconstruction_3
  *  %Smoother for scale space reconstruction based on a principal
  *  component analysis weighted by the local density of points.
  *
- *  \cgalModels CGAL::Scale_space_reconstruction_3::Smoother
+ *  \cgalModels{CGAL::Scale_space_reconstruction_3::Smoother}
  *
  *  \tparam Geom_traits geometric traits class. It must be a
  *  model of `DelaunayTriangulationTraits_3`. It must have a
@@ -70,8 +70,8 @@ template <typename Geom_traits,
 class Weighted_PCA_smoother
 {
 public:
-  typedef typename Geom_traits::FT FT; ///< defines the point type.
-  typedef typename Geom_traits::Point_3 Point; ///< defines the point typ.e
+  typedef typename Geom_traits::FT FT; ///< defines the field number type.
+  typedef typename Geom_traits::Point_3 Point; ///< defines the point type.
   typedef typename Geom_traits::Vector_3 Vector; ///< defines the vector type.
 private:
 
@@ -198,10 +198,10 @@ private:
   void try_parallel (const F& func, std::size_t begin, std::size_t end)
   {
 #ifndef CGAL_LINKED_WITH_TBB
-    CGAL_static_assertion_msg (!(boost::is_convertible<ConcurrencyTag, Parallel_tag>::value),
+    static_assert (!(std::is_convertible<ConcurrencyTag, Parallel_tag>::value),
                                "Parallel_tag is enabled but TBB is unavailable.");
 #else
-    if (boost::is_convertible<ConcurrencyTag,Parallel_tag>::value)
+    if (std::is_convertible<ConcurrencyTag,Parallel_tag>::value)
       tbb::parallel_for(tbb::blocked_range<std::size_t>(begin, end), func);
     else
 #endif
