@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Kernel_23/include/CGAL/Segment_2.h $
-// $Id: Segment_2.h 8fa0f55 2021-05-27T10:27:38+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Kernel_23/include/CGAL/Segment_2.h $
+// $Id: include/CGAL/Segment_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,12 +18,13 @@
 #define CGAL_SEGMENT_2_H
 
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/Bbox_2.h>
 #include <CGAL/Dimension.h>
 #include <CGAL/kernel_config.h>
 
+#include <type_traits>
+
 namespace CGAL {
 
 template <class R_>
@@ -39,7 +40,7 @@ class Segment_2 : public R_::Kernel_base::Segment_2
   typedef typename R_::Kernel_base::Segment_2 RSegment_2;
 
   typedef Segment_2                           Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Segment_2>::value));
+  static_assert(std::is_same<Self, typename R_::Segment_2>::value);
 
 public:
 
