@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Octree.h $
-// $Id: Octree.h 8e7ea14 2021-04-14T10:57:53+02:00 Simon Giraudot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Shape_detection/include/CGAL/Shape_detection/Efficient_RANSAC/Octree.h $
+// $Id: include/CGAL/Shape_detection/Efficient_RANSAC/Octree.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -31,10 +31,6 @@
 namespace CGAL {
 namespace Shape_detection {
 
-// Forward declaration needed for automatic traits detection without
-// including the deprecated header itself…
-template <typename Gt, typename IR, typename IPM, typename INM>
-struct Shape_detection_traits;
 
 namespace internal {
 
@@ -43,9 +39,6 @@ struct Traits_base { typedef Traits type; };
 template <typename Gt, typename IR, typename IPM, typename INM>
 struct Traits_base<CGAL::Shape_detection::Efficient_RANSAC_traits<Gt,IR,IPM,INM> >
 { typedef Gt type; };
-template <typename Gt, typename IR, typename IPM, typename INM>
-struct Traits_base<CGAL::Shape_detection::Shape_detection_traits<Gt,IR,IPM,INM> >
-{ typedef Gt type; };
 
 template<class Traits>
 class RANSAC_octree {
@@ -56,8 +49,9 @@ class RANSAC_octree {
   typedef std::vector<std::size_t> Input_range;
   typedef Random_index_access_property_map<Input_iterator, Point_map> Indexed_point_map;
 
-  typedef CGAL::Octree<typename Traits_base<Traits>::type,
-                       Input_range, Indexed_point_map> Octree;
+  typedef Orthtree_traits_point<typename Traits_base<Traits>::type, Input_range, Indexed_point_map, false, 3> OTraits;
+
+  typedef CGAL::Orthtree<OTraits> Octree;
 
   Traits m_traits;
   Input_range m_input_range;
@@ -70,7 +64,8 @@ class RANSAC_octree {
 
 public:
 
-  typedef typename Octree::Node Node;
+  typedef typename Octree::Node_index Node;
+  typedef typename OTraits::Node_data Node_data;
 
   RANSAC_octree(const Traits &traits,
                 Input_iterator begin,
@@ -81,18 +76,26 @@ public:
           m_input_range(boost::counting_iterator<std::size_t>(0),
                         boost::counting_iterator<std::size_t>(end - begin)),
           m_index_map(begin, point_map),
-          m_octree(m_input_range, m_index_map, 1.0),
+          m_octree(OTraits(m_input_range, m_index_map)),
           m_bBox (bbox_3(make_transform_iterator_from_property_map(begin, point_map),
                          make_transform_iterator_from_property_map(end, point_map))),
           m_offset(offset) {}
 
   std::size_t index (Node node, std::size_t i) const
   {
-    return m_offset + *(node.begin() + i);
+    return m_offset + *(m_octree.data(node).begin() + i);
+  }
+
+  std::size_t depth(const Node& node) const {
+    return m_octree.depth(node);
+  }
+
+  bool is_leaf(const Node& node) const {
+    return m_octree.is_leaf(node);
   }
 
   std::size_t size() const {
-    return m_octree.root().size();
+    return m_input_range.size();
   }
 
   std::size_t maxLevel() const {
@@ -127,17 +130,27 @@ public:
     return m_width;
   }
 
+  Node child(const Node& node, std::size_t i) const {
+    return m_octree.child(node, i);
+  }
+
+  Node parent(const Node& node) const {
+    return m_octree.parent(node);
+  }
+
   Node locate(const typename Traits::Point_3 &p) const {
     return m_octree.locate(p);
   }
 
   Node root() const { return m_octree.root(); }
 
+  Node_data points(const Node& n) const { return m_octree.data(n); }
+
   typename Traits::Point_3 barycenter(const Node &node) const {
     return m_octree.barycenter(node);
   }
 
-  Bbox_3 boundingBox() const {
+  typename Traits::GeomTraits::Iso_cuboid_3 boundingBox() const {
       return m_octree.bbox(m_octree.root());
   }
 };
