@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Shape_regularization/include/CGAL/Shape_regularization/regularize_segments.h $
-// $Id: regularize_segments.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Shape_regularization/include/CGAL/Shape_regularization/regularize_segments.h $
+// $Id: include/CGAL/Shape_regularization/regularize_segments.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -70,6 +70,9 @@ namespace Segments {
     that should be addressed. The function is based on the class `QP_regularization`.
     Please refer to that class and these concepts for more information.
 
+    This class requires a `QPSolver` model which defaults to the \ref thirdpartyOSQP "OSQP"
+    library, which must be available on the system.
+
     \tparam InputRange
     a model of `ConstRange` whose iterator type is `RandomAccessIterator`
 
