@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Number_types/include/CGAL/Sqrt_extension/Fraction_traits.h $
-// $Id: Fraction_traits.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Number_types/include/CGAL/Sqrt_extension/Fraction_traits.h $
+// $Id: include/CGAL/Sqrt_extension/Fraction_traits.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,11 +24,11 @@ namespace CGAL {
 //################################# CGAL::Fraction_traits ##################
 // Select the right alternative as Fraction_traits
 // The actual Type traits is Intern::Sqrt_ext_Ftr_base_2
-// The selction is done in two steps:
+// The selection is done in two steps:
 // 1. Inter::Sqrt_ext_Ftr_base_1 selects by the BOOL_TAG whether the COEFF type
 //    Is_fraction
 // 2. Intern::Sqrt_ext_Ftr_base_2 checks whether the internal type of the ROOT
-//    is still implicite convertible to the new COEFF type.
+//    is still implicitly convertible to the new COEFF type.
 //    since the ROOT type it self can not be converted.
 namespace Intern{
     template <class EXT, bool> class Sqrt_ext_Ftr_base_2;
@@ -37,13 +37,13 @@ namespace Intern{
 
 /*! \ingroup CGAL_Sqrt_extension
     \ingroup CGAL_Fraction_traits_spec
-    \brief Specialisation of CGAL::Fraction_traits for CGAL::Sqrt_extension.
+    \brief Specialization of CGAL::Fraction_traits for CGAL::Sqrt_extension.
  *
  *  Extensions provide suitable specializations of \c CGAL::Fraction_traits.
  *  They are decomposable iff their coefficient type is.
- *  The denominator \e d of a Extension \e ext is a low common multiple
+ *  The denominator \e d of an extension \e ext is a low common multiple
  *  (see \c CGAL::Fraction_traits::Common_factor for details) of the
- *  denominators of its coefficients.  The numerator is the Extenion
+ *  denominators of its coefficients.  The numerator is the extension
  *  \e d*ext with a fraction-free coefficient type.
  *
  *  This works for nested Sqrt_extensions, too.
@@ -147,7 +147,7 @@ template <class COEFF, class ROOT, class ACDE_TAG, class FP_TAG>
 class Sqrt_ext_Ftr_base_1< Sqrt_extension<COEFF,ROOT,ACDE_TAG,FP_TAG>, CGAL::Tag_true >
     : public Sqrt_ext_Ftr_base_2<
     Sqrt_extension<COEFF,ROOT,ACDE_TAG,FP_TAG>,
-    ::boost::is_same< typename CGAL::Coercion_traits<ROOT,typename CGAL::Fraction_traits<COEFF>::Numerator_type>::Type,
+    ::std::is_same< typename CGAL::Coercion_traits<ROOT,typename CGAL::Fraction_traits<COEFF>::Numerator_type>::Type,
                         typename CGAL::Fraction_traits<COEFF>::Numerator_type>::value >
 {
     //nothing new
