@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_events_2.h $
-// $Id: Straight_skeleton_builder_events_2.h 4d85f84 2020-09-29T20:00:27+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Straight_skeleton_2/include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_events_2.h $
+// $Id: include/CGAL/Straight_skeleton_2/Straight_skeleton_builder_events_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -15,8 +15,6 @@
 
 #include <CGAL/Straight_skeleton_2/Straight_skeleton_aux.h>
 
-#include <boost/intrusive_ptr.hpp>
-
 #include <ostream>
 
 namespace CGAL {
@@ -24,17 +22,14 @@ namespace CGAL {
 namespace CGAL_SS_i {
 
 template<class SSkel_, class Traits_>
-class Event_2 : public Ref_counted_base
+class Event_2
 {
   typedef SSkel_  SSkel ;
   typedef Traits_ Traits ;
 
 public:
-
   typedef Event_2<SSkel,Traits> Self ;
 
-  typedef boost::intrusive_ptr<Self> SelfPtr ;
-
   typedef typename Traits::Point_2          Point_2 ;
   typedef typename Traits::FT               FT ;
   typedef typename Traits::Trisegment_2_ptr Trisegment_2_ptr ;
@@ -46,7 +41,7 @@ public:
 
   typedef CGAL_SS_i::Triedge<Halfedge_handle> Triedge ;
 
-  enum Type { cEdgeEvent, cSplitEvent, cPseudoSplitEvent } ;
+  enum Type { cEdgeEvent, cSplitEvent, cPseudoSplitEvent, cArficialEvent } ;
 
 public:
 
@@ -178,7 +173,7 @@ private :
   virtual void dump ( std::ostream& ss ) const
   {
     this->Base::dump(ss);
-    ss << " (Split Event, Seed=" << mSeed->id() << " (" << mSeed->point() << ") OppBorder=" << this->triedge().e2()->id() << ')' ;
+    ss << " (Split Event, Seed=" << mSeed->id() << " pos=(" << mSeed->point() << ") OppBorder=" << this->triedge().e2()->id() << ')' ;
   }
 
 private :
@@ -247,6 +242,48 @@ private :
   bool          mOppositeIs0 ;
 } ;
 
+
+template<class SSkel_, class Traits_>
+class Artificial_event_2 : public Event_2<SSkel_,Traits_>
+{
+  typedef SSkel_  SSkel ;
+  typedef Traits_ Traits ;
+
+  typedef Event_2<SSkel,Traits> Base ;
+
+  typedef typename SSkel::Halfedge_handle Halfedge_handle ;
+  typedef typename SSkel::Vertex_handle   Vertex_handle ;
+
+  typedef typename Base::Type             Type ;
+  typedef typename Base::Triedge          Triedge ;
+  typedef typename Base::Trisegment_2_ptr Trisegment_2_ptr ;
+
+public:
+  Artificial_event_2 ( Triedge const&          aTriedge,
+                       Trisegment_2_ptr const& aTrisegment,
+                       Vertex_handle           aSeed )
+    :
+      Base(aTriedge,aTrisegment)
+    , mSeed(aSeed)
+  {}
+
+  virtual Type type() const { return this->cArficialEvent ; }
+
+  virtual Vertex_handle seed0() const { return mSeed ; }
+  virtual Vertex_handle seed1() const { return mSeed ; }
+
+private :
+  virtual void dump ( std::ostream& ss ) const
+  {
+    this->Base::dump(ss);
+
+    ss << " (Artificial Event, Seed=" << mSeed->id() << ")" ;
+  }
+
+private :
+  Vertex_handle mSeed ;
+};
+
 }
 
 } // end namespace CGAL
