@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Surface_mesh_segmentation/include/CGAL/Surface_mesh_segmentation/internal/auxiliary/graph.h $
-// $Id: graph.h b45e788 2022-06-23T16:25:21+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh_segmentation/include/CGAL/Surface_mesh_segmentation/internal/auxiliary/graph.h $
+// $Id: include/CGAL/Surface_mesh_segmentation/internal/auxiliary/graph.h 50cfbde3b84 $
 // Re-licensed for CGAL distribution to:
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Original license is:
@@ -53,10 +53,10 @@ This program is available under dual licence:
 
 1) Under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 Note that any program that incorporates the code under this licence must, under the terms of the GNU GPL, be released under a licence compatible with the GPL. GNU GPL does not permit incorporating this program into proprietary programs. If you wish to do this, please see the alternative licence available below.
-GNU General Public License can be found at http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+GNU General Public License can be found at https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 
 2) Proprietary Licence from UCL Business PLC.
-To enable programers to include the MaxFlow software in a proprietary system (which is not allowed by the GNU GPL), this licence gives you the right to incorporate the software in your program and distribute under any licence of your choosing. The full terms of the licence and applicable fee, are available from the Licensors at: http://www.uclb-elicensing.com/optimisation_software/maxflow_computervision.html
+To enable programmers to include the MaxFlow software in a proprietary system (which is not allowed by the GNU GPL), this licence gives you the right to incorporate the software in your program and distribute under any licence of your choosing. The full terms of the licence and applicable fee, are available from the Licensors at: http://www.uclb-elicensing.com/optimisation_software/maxflow_computervision.html
 
 ##################################################################
 
@@ -637,7 +637,7 @@ private:
     arcs_for[MF_ARC_BLOCK_SIZE]; /* all arcs must be at even addresses */
     union {
       arc_forward                        dummy;
-      node                                *LAST_NODE;        /* used in graph consruction */
+      node                                *LAST_NODE;        /* used in graph construction */
     }                                                LAST_NODE;
   } arc_for_block;
 
@@ -651,7 +651,7 @@ private:
     arcs_rev[MF_ARC_BLOCK_SIZE]; /* all arcs must be at even addresses */
     union {
       arc_reverse                        dummy;
-      node                                *LAST_NODE;        /* used in graph consruction */
+      node                                *LAST_NODE;        /* used in graph construction */
     }                                                LAST_NODE;
   } arc_rev_block;
 
@@ -661,7 +661,7 @@ private:
   DBlock<nodeptr>                *nodeptr_block;
 
   void        (*error_function)(const char
-                          *);        /* this function is called if a error occurs,
+                          *);        /* this function is called if an error occurs,
                                                                                    with a corresponding error message
                                                                                    (or exit(1) is called if it's nullptr) */
 
