@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/Bounded_normal_change_placement.h $
-// $Id: Bounded_normal_change_placement.h ff09c5d 2019-10-25T16:35:53+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh_simplification/include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/Bounded_normal_change_placement.h $
+// $Id: include/CGAL/Surface_mesh_simplification/Policies/Edge_collapse/Bounded_normal_change_placement.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri
@@ -15,7 +15,7 @@
 
 #include <CGAL/property_map.h>
 
-#include <boost/optional.hpp>
+#include <optional>
 
 namespace CGAL {
 namespace Surface_mesh_simplification {
@@ -29,7 +29,7 @@ public:
   {}
 
   template <typename Profile>
-  boost::optional<typename Profile::Point>
+  std::optional<typename Profile::Point>
   operator()(const Profile& profile) const
   {
     typedef typename Profile::VertexPointMap                              Vertex_point_map;
@@ -43,11 +43,11 @@ public:
     const Geom_traits& gt = profile.geom_traits();
     const Vertex_point_map& vpm = profile.vertex_point_map();
 
-    boost::optional<typename Profile::Point> op = m_get_placement(profile);
+    std::optional<typename Profile::Point> op = m_get_placement(profile);
     if(op)
     {
       // triangles returns the triangles of the star of the vertices of the edge to collapse
-      // First the two trianges incident to the edge, then the other triangles
+      // First the two triangles incident to the edge, then the other triangles
       // The second vertex of each triangle is the vertex that gets placed
        const typename Profile::Triangle_vector& triangles = profile.triangles();
        if(triangles.size() > 2)
@@ -76,7 +76,7 @@ public:
            Vector n2 = gt.construct_cross_product_vector_3_object()(eq2p, eq2r);
 
            if(!is_positive(gt.compute_scalar_product_3_object()(n1, n2)))
-             return boost::optional<typename Profile::Point>();
+             return std::optional<typename Profile::Point>();
 
            ++it;
          }
