@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Three/include/CGAL/Three/Scene_item_rendering_helper.h $
-// $Id: Scene_item_rendering_helper.h 3ee53a4 2023-05-26T18:11:51+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Three/include/CGAL/Three/Scene_item_rendering_helper.h $
+// $Id: include/CGAL/Three/Scene_item_rendering_helper.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Maxime Gimeno
@@ -69,7 +69,7 @@ public:
 #endif
   Q_DECLARE_FLAGS(Gl_data_names, Gl_data_name)
 
-  QMenu* contextMenu() Q_DECL_OVERRIDE;
+  QMenu* contextMenu() override;
 
   /*!
      * \brief processData calls `computeElements()`
@@ -86,13 +86,13 @@ public:
   //! It must be between 0 and 255.
   //! \param alpha the integer value for the alpha channel.
   //!
-  void setAlpha(int alpha) Q_DECL_OVERRIDE;
+  void setAlpha(int alpha) override;
   //! \brief The item's bounding box.
   //!
   //! If the Bbox has never been computed, computes it and
   //! saves the result for further calls.
   //! @returns the item's bounding box.
-  Scene_item::Bbox bbox()const Q_DECL_OVERRIDE;
+  Scene_item::Bbox bbox()const override;
   //!
   //! \brief getTriangleContainer returns the `id`th `Triangle_container`.
   //!
@@ -110,7 +110,7 @@ public:
   //! \brief setTriangleContainer sets the `id`th `Triangle_container` to `tc`.
   //!
   //! If `id` is bigger than the current size of the container vector, this vector is
-  //! resized accordingly. This means that for optimisation reasons, containers should be created
+  //! resized accordingly. This means that for optimization reasons, containers should be created
   //! decreasingly.
   //!
   void setTriangleContainer(std::size_t id,
@@ -120,7 +120,7 @@ public:
   //! \brief setEdgeContainer sets the `id`th `Edge_container` to `tc`.
   //!
   //! If `id` is bigger than the current size of the container vector, this vector is
-  //! resized accordingly. This means that for optimisation reasons, containers should be created
+  //! resized accordingly. This means that for optimization reasons, containers should be created
   //! decreasingly.
   //!
   void setEdgeContainer(std::size_t id,
@@ -130,7 +130,7 @@ public:
   //! \brief setPointContainer sets the `id`th `Point_container` to `tc`.
   //!
   //! If `id` is bigger than the current size of the container vector, this vector is
-  //! resized accordingly. This means that for optimisation reasons, containers should be created
+  //! resized accordingly. This means that for optimization reasons, containers should be created
   //! decreasingly.
   //!
   void setPointContainer(std::size_t id,
@@ -174,15 +174,15 @@ public:
   //! saves the result for further calls.
   //! @returns the item's bounding box's diagonal length.
   //! @todo must replace the one from Scene_item eventually
-  virtual double diagonalBbox() const Q_DECL_OVERRIDE;
+  virtual double bboxDiagonal() const override;
   //!
   //! \brief newViewer adds Vaos for `viewer`.
   //! \param viewer the new viewer.
   //!
-  void newViewer(Viewer_interface *viewer) Q_DECL_OVERRIDE;
+  void newViewer(Viewer_interface *viewer) override;
   //! \brief removeViewer removes the Vaos for `viewer`.
   //! \param viewer the viewer to be removed.
-  void removeViewer(Viewer_interface *viewer) Q_DECL_OVERRIDE;
+  void removeViewer(Viewer_interface *viewer) override;
 protected:
 
 
@@ -194,7 +194,7 @@ protected:
 
   //!Returns the float alpha value of an item.
   //! This value is between 0.0f and 1.0f.
-  float alpha() const Q_DECL_OVERRIDE;
+  float alpha() const override;
 
   /*! Fills the `Vbo`s with data.
      */
@@ -205,7 +205,7 @@ protected:
   //!
   //! Computes the items Bbox and stores the result. Must be overridden.
   //!@todo must replace the one from Scene_item eventually.
-  virtual void compute_bbox() const Q_DECL_OVERRIDE = 0;
+  virtual void compute_bbox() const override = 0;
   //!
   //! \brief setBbox allows to set the Bbox in compute_bbox();
   //! \param b
