@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/STL_Extension/include/CGAL/Time_stamper.h $
-// $Id: Time_stamper.h e9b7595 2021-05-04T11:45:57+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/STL_Extension/include/CGAL/Time_stamper.h $
+// $Id: include/CGAL/Time_stamper.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Jane Tournois
@@ -13,6 +13,7 @@
 #define CGAL_TIME_STAMPER_H
 
 #include <CGAL/Has_timestamp.h>
+#include <string>
 
 namespace CGAL {
 
@@ -27,18 +28,21 @@ constexpr size_t rounded_down_log2(size_t n)
 template <typename T>
 struct Time_stamper
 {
+  static constexpr bool has_timestamp = true;
+
   static void initialize_time_stamp(T* pt) {
     pt->set_time_stamp(std::size_t(-1));
   }
 
   template <typename time_stamp_t>
   static void set_time_stamp(T* pt, time_stamp_t& time_stamp_) {
+    CGAL_assertion(pt->time_stamp() != std::size_t(-2));
     if(pt->time_stamp() == std::size_t(-1)) {
       const std::size_t new_ts = time_stamp_++;
       pt->set_time_stamp(new_ts);
     }
     else {
-      // else: the time stamp is re-used
+      // else: the time stamp is reused
 
       // Enforces that the time stamp is greater than the current value.
       // That is used when a TDS_3 is copied: in that case, the
@@ -60,13 +64,23 @@ struct Time_stamper
 
   static std::size_t time_stamp(const T* pt)
   {
+    CGAL_assertion(pt == nullptr || pt->time_stamp() != std::size_t(-2));
     if(pt == nullptr){
       return std::size_t(-1);
     }
     return pt->time_stamp();
   }
 
+  static auto display_id(const T* pt, int offset = 0)
+  {
+    if(pt == nullptr)
+      return std::string("nullptr");
+    else
+      return std::string("#") + std::to_string(pt->time_stamp() + offset);
+  }
+
   static std::size_t hash_value(const T* p) {
+    CGAL_assertion(p == nullptr || p->time_stamp() != std::size_t(-2));
     if(nullptr == p)
       return std::size_t(-1);
     else
@@ -86,6 +100,7 @@ struct Time_stamper
 template <typename T>
 struct No_time_stamp
 {
+  static constexpr bool has_timestamp = false;
 public:
   template <typename time_stamp_t>
   static void set_time_stamp(T*, time_stamp_t&)  {}
@@ -101,6 +116,11 @@ public:
     return 0;
   }
 
+  static auto display_id(const T* pt, int)
+  {
+    return static_cast<const void*>(pt);
+  }
+
   static std::size_t hash_value(const T* p) {
 
     constexpr std::size_t shift = internal::rounded_down_log2(sizeof(T));
