@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/TDS_2/include/CGAL/Triangulation_utils_2.h $
-// $Id: Triangulation_utils_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/TDS_2/include/CGAL/Triangulation_utils_2.h $
+// $Id: include/CGAL/Triangulation_utils_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,7 +18,7 @@
 #include <CGAL/license/TDS_2.h>
 
 
-#include <CGAL/triangulation_assertions.h>
+#include <CGAL/assertions.h>
 
 namespace CGAL {
 template < class T = void >
@@ -39,13 +39,13 @@ class Triangulation_cw_ccw_2
 public:
   static int ccw(const int i)
     {
-      CGAL_triangulation_precondition( i >= 0 && i < 3);
+      CGAL_precondition( i >= 0 && i < 3);
       return ccw_map[i];
     }
 
   static int cw(const int i)
     {
-      CGAL_triangulation_precondition( i >= 0 && i < 3);
+      CGAL_precondition( i >= 0 && i < 3);
       return cw_map[i];
     }
 };
