@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Apollonius_graph_nearest_site_2.h $
-// $Id: Apollonius_graph_nearest_site_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Voronoi_diagram_2/include/CGAL/Voronoi_diagram_2/Apollonius_graph_nearest_site_2.h $
+// $Id: include/CGAL/Voronoi_diagram_2/Apollonius_graph_nearest_site_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,7 +20,7 @@
 #include <CGAL/Triangulation_utils_2.h>
 #include <CGAL/Apollonius_graph_2/Orientation_2.h>
 
-#include <boost/variant.hpp>
+#include <variant>
 
 namespace CGAL {
 
@@ -48,7 +48,7 @@ class Apollonius_graph_nearest_site_2
   typedef typename Delaunay_graph::Edge_circulator    Edge_circulator;
 
 public:
-  typedef boost::variant<Vertex_handle,Edge,Face_handle> result_type;
+  typedef std::variant<Vertex_handle,Edge,Face_handle> result_type;
 
   result_type operator()(const Delaunay_graph& dg, const Point_2& p) const {
     CGAL_precondition( dg.dimension() >= 0 );
