@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Alpha_wrap_3/include/CGAL/alpha_wrap_3.h $
-// $Id: alpha_wrap_3.h 9fbfd9a 2022-05-24T10:08:56+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Alpha_wrap_3/include/CGAL/alpha_wrap_3.h $
+// $Id: include/CGAL/alpha_wrap_3.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pierre Alliez
@@ -105,14 +105,14 @@ void alpha_wrap_3(const PointRange& points,
   using NP_helper = Point_set_processing_3_np_helper<PointRange, InputNamedParameters>;
   using Geom_traits = typename NP_helper::Geom_traits;
   using Oracle = Alpha_wraps_3::internal::Triangle_soup_oracle<Geom_traits>;
-  using AW3 = Alpha_wraps_3::internal::Alpha_wrap_3<Oracle>;
+  using AW3 = Alpha_wraps_3::internal::Alpha_wrapper_3<Oracle>;
 
   Geom_traits gt = choose_parameter<Geom_traits>(get_parameter(in_np, internal_np::geom_traits));
 
   Oracle oracle(alpha, gt);
   oracle.add_triangle_soup(points, faces, in_np);
   AW3 alpha_wrap_builder(oracle);
-  alpha_wrap_builder(alpha, offset, alpha_wrap, out_np);
+  alpha_wrap_builder(alpha, offset, alpha_wrap, in_np, out_np);
 }
 
 // Convenience overloads
@@ -148,7 +148,7 @@ void alpha_wrap_3(const PointRange& points,
                   OutputMesh& alpha_wrap,
                   const CGAL::Named_function_parameters<T_I, Tag_I, Base_I>& in_np,
                   const CGAL::Named_function_parameters<T_O, Tag_O, Base_O>& out_np,
-                  typename std::enable_if<boost::has_range_const_iterator<FaceRange>::value>::type* = nullptr)
+                  std::enable_if_t<boost::has_range_const_iterator<FaceRange>::value>* = nullptr)
 {
   return alpha_wrap_3(points, faces, alpha, alpha / 30., alpha_wrap, in_np, out_np);
 }
@@ -160,7 +160,7 @@ void alpha_wrap_3(const PointRange& points,
                   const double alpha,
                   OutputMesh& alpha_wrap,
                   const CGAL_NP_CLASS& in_np,
-                  typename std::enable_if<boost::has_range_const_iterator<FaceRange>::value>::type* = nullptr)
+                  std::enable_if_t<boost::has_range_const_iterator<FaceRange>::value>* = nullptr)
 {
   return alpha_wrap_3(points, faces, alpha, alpha / 30., alpha_wrap, in_np,
                       CGAL::parameters::default_values());
@@ -171,7 +171,7 @@ void alpha_wrap_3(const PointRange& points,
                   const FaceRange& faces,
                   const double alpha,
                   OutputMesh& alpha_wrap,
-                  typename std::enable_if<boost::has_range_const_iterator<FaceRange>::value>::type* = nullptr)
+                  std::enable_if_t<boost::has_range_const_iterator<FaceRange>::value>* = nullptr)
 {
   return alpha_wrap_3(points, faces, alpha, alpha / 30., alpha_wrap,
                       CGAL::parameters::default_values(), CGAL::parameters::default_values());
@@ -245,7 +245,7 @@ void alpha_wrap_3(const TriangleMesh& tmesh,
                   const InputNamedParameters& in_np,
                   const OutputNamedParameters& out_np
 #ifndef DOXYGEN_RUNNING
-                  , typename std::enable_if<! boost::has_range_const_iterator<TriangleMesh>::value>::type* = nullptr
+                  , std::enable_if_t<! boost::has_range_const_iterator<TriangleMesh>::value>* = nullptr
 #endif
                   )
 {
@@ -254,14 +254,14 @@ void alpha_wrap_3(const TriangleMesh& tmesh,
 
   using Geom_traits = typename GetGeomTraits<TriangleMesh, InputNamedParameters>::type;
   using Oracle = Alpha_wraps_3::internal::Triangle_mesh_oracle<Geom_traits>;
-  using AW3 = Alpha_wraps_3::internal::Alpha_wrap_3<Oracle>;
+  using AW3 = Alpha_wraps_3::internal::Alpha_wrapper_3<Oracle>;
 
   Geom_traits gt = choose_parameter<Geom_traits>(get_parameter(in_np, internal_np::geom_traits));
 
   Oracle oracle(alpha, gt);
   oracle.add_triangle_mesh(tmesh, in_np);
   AW3 alpha_wrap_builder(oracle);
-  alpha_wrap_builder(alpha, offset, alpha_wrap, out_np);
+  alpha_wrap_builder(alpha, offset, alpha_wrap, in_np, out_np);
 }
 
 // The convenience overloads are the same for triangle mesh & point set
@@ -338,7 +338,7 @@ void alpha_wrap_3(const PointRange& points,
 #else
                   const CGAL::Named_function_parameters<T_I, Tag_I, Base_I>& in_np,
                   const CGAL::Named_function_parameters<T_O, Tag_O, Base_O>& out_np,
-                  typename std::enable_if<boost::has_range_const_iterator<PointRange>::value>::type* = nullptr
+                  std::enable_if_t<boost::has_range_const_iterator<PointRange>::value>* = nullptr
 #endif
                   )
 {
@@ -350,14 +350,14 @@ void alpha_wrap_3(const PointRange& points,
   using NP_helper = Point_set_processing_3_np_helper<PointRange, InputNamedParameters>;
   using Geom_traits = typename NP_helper::Geom_traits;
   using Oracle = Alpha_wraps_3::internal::Point_set_oracle<Geom_traits>;
-  using AW3 = Alpha_wraps_3::internal::Alpha_wrap_3<Oracle>;
+  using AW3 = Alpha_wraps_3::internal::Alpha_wrapper_3<Oracle>;
 
   Geom_traits gt = choose_parameter<Geom_traits>(get_parameter(in_np, internal_np::geom_traits));
 
   Oracle oracle(gt);
   oracle.add_point_set(points, in_np);
   AW3 alpha_wrap_builder(oracle);
-  alpha_wrap_builder(alpha, offset, alpha_wrap, out_np);
+  alpha_wrap_builder(alpha, offset, alpha_wrap, in_np, out_np);
 }
 
 // Convenience overloads, common to both mesh and point set
