@@ -2,9 +2,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Triangulation_2/include/CGAL/boost/graph/graph_traits_Regular_triangulation_2.h $
-// $Id: graph_traits_Regular_triangulation_2.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Triangulation_2/include/CGAL/boost/graph/graph_traits_Regular_triangulation_2.h $
+// $Id: include/CGAL/boost/graph/graph_traits_Regular_triangulation_2.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri, Fernando Cacciola
@@ -12,6 +12,9 @@
 #ifndef CGAL_GRAPH_TRAITS_REGULAR_TRIANGULATION_2_H
 #define CGAL_GRAPH_TRAITS_REGULAR_TRIANGULATION_2_H
 
+#include <CGAL/license/Triangulation_2.h>
+
+
 #include <CGAL/Regular_triangulation_2.h>
 #include <CGAL/boost/graph/properties_Regular_triangulation_2.h>
 
