@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/BGL/include/CGAL/boost/graph/internal/helpers.h $
-// $Id: helpers.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/BGL/include/CGAL/boost/graph/internal/helpers.h $
+// $Id: include/CGAL/boost/graph/internal/helpers.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Andread Fabri
@@ -11,9 +11,15 @@
 #ifndef CGAL_BOOST_GRAPH_INTERNAL_HELPERS_H
 #define CGAL_BOOST_GRAPH_INTERNAL_HELPERS_H
 
-#include <boost/graph/graph_traits.hpp>
-#include <boost/optional.hpp>
+#include <CGAL/iterator.h>
+#include <CGAL/property_map.h>
 #include <CGAL/boost/graph/iterator.h>
+#include <CGAL/Named_function_parameters.h>
+#include <CGAL/value_type_traits.h>
+
+#include <boost/iterator/function_output_iterator.hpp>
+
+#include <tuple>
 
 namespace CGAL {
 
@@ -129,7 +135,7 @@ std::size_t
 exact_num_vertices(const Graph& g)
 {
   typename boost::graph_traits<Graph>::vertex_iterator beg, end;
-  boost::tie(beg,end) = vertices(g);
+  std::tie(beg,end) = vertices(g);
   return std::distance(beg,end);
  }
 
@@ -138,7 +144,7 @@ std::size_t
 exact_num_halfedges(const Graph& g)
 {
   typename boost::graph_traits<Graph>::halfedge_iterator beg, end;
-  boost::tie(beg,end) = halfedges(g);
+  std::tie(beg,end) = halfedges(g);
   return std::distance(beg,end);
  }
 
@@ -147,7 +153,7 @@ std::size_t
 exact_num_edges(const Graph& g)
 {
   typename boost::graph_traits<Graph>::edge_iterator beg, end;
-  boost::tie(beg,end) = edges(g);
+  std::tie(beg,end) = edges(g);
   return std::distance(beg,end);
  }
 
@@ -156,14 +162,14 @@ std::size_t
 exact_num_faces(const Graph& g)
 {
   typename boost::graph_traits<Graph>::face_iterator beg, end;
-  boost::tie(beg,end) = faces(g);
+  std::tie(beg,end) = faces(g);
   return std::distance(beg,end);
 }
 
 template<typename Graph>
 bool
 is_isolated(typename boost::graph_traits<Graph>::vertex_descriptor v,
-            Graph& g)
+            const Graph& g)
 {
   return halfedge(v, g) == boost::graph_traits<Graph>::null_halfedge();
 }
@@ -200,6 +206,44 @@ adjust_incoming_halfedge(typename boost::graph_traits<Graph>::vertex_descriptor
 
 
 } // internal
+
+namespace impl
+{
+  template<typename PMAP>
+  struct Output_iterator_functor
+  {
+    typedef typename boost::property_traits<PMAP>::key_type input_t;
+    typedef typename boost::property_traits<PMAP>::value_type output_t;
+    PMAP map;
+    Output_iterator_functor(PMAP map)
+      :map(map)
+    {
+    }
+    void operator()(const typename std::pair<input_t, output_t>& pair)
+    {
+      put(map, pair.first, pair.second);
+    }
+  };
+
+  template<typename PMAP>
+  boost::function_output_iterator<Output_iterator_functor<PMAP> > make_functor(PMAP map)
+  {
+    return boost::make_function_output_iterator(Output_iterator_functor<PMAP>(map));
+  }
+
+  inline Emptyset_iterator make_functor(const internal_np::Param_not_found&)
+  {
+    return Emptyset_iterator();
+  }
+}//end of impl
+
+template <class PMAP>
+struct value_type_traits<boost::function_output_iterator<impl::Output_iterator_functor<PMAP>>>
+{
+  typedef std::pair<typename impl::Output_iterator_functor<PMAP>::input_t,
+                    typename impl::Output_iterator_functor<PMAP>::output_t> type;
+};
+
 } // CGAL
 
 
