@@ -1,7 +1,7 @@
 // Copyright (c) 2007-2015  GeometryFactory (France).  All rights reserved.
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/BGL/include/CGAL/boost/graph/named_params_helper.h $
-// $Id: named_params_helper.h 477353d 2022-04-20T15:55:50+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/BGL/include/CGAL/boost/graph/named_params_helper.h $
+// $Id: include/CGAL/boost/graph/named_params_helper.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Andreas Fabri, Fernando Cacciola, Jane Tournois
@@ -15,12 +15,12 @@
 #include <CGAL/iterator.h>
 #include <CGAL/Kernel_traits.h>
 #include <CGAL/Origin.h>
+#include <CGAL/iterator.h>
+#include <CGAL/Default.h>
 #include <CGAL/Named_function_parameters.h>
 #include <CGAL/property_map.h>
 
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/has_xxx.hpp>
-#include <boost/type_traits/is_same.hpp>
 
 #include <fstream>
 #include <iterator>
@@ -42,14 +42,13 @@ class property_map_selector
 {
 public:
   typedef typename graph_has_property<PolygonMesh, PropertyTag>::type Has_internal_pmap;
-  typedef typename boost::mpl::if_c<Has_internal_pmap::value,
-                                    typename boost::property_map<PolygonMesh, PropertyTag>::type,
-                                    typename boost::cgal_no_property::type
-                                    >::type type;
-  typedef typename boost::mpl::if_c<Has_internal_pmap::value,
-                                    typename boost::property_map<PolygonMesh, PropertyTag>::const_type,
-                                    typename boost::cgal_no_property::const_type
-                                    >::type const_type;
+  typedef std::conditional_t<Has_internal_pmap::value,
+                             typename boost::property_map<PolygonMesh, PropertyTag>::type,
+                             typename boost::cgal_no_property::type> type;
+  typedef std::conditional_t<Has_internal_pmap::value,
+                             typename boost::property_map<PolygonMesh, PropertyTag>::const_type,
+                             typename boost::cgal_no_property::const_type
+                             > const_type;
 
   type get_pmap(const PropertyTag& p, PolygonMesh& pmesh)
   {
@@ -109,22 +108,75 @@ public:
   typedef typename boost::property_traits<PMap>::value_type type;
 };
 
+
+template <typename PolygonMesh,
+          typename VPM_from_NP>
+struct GetVertexPointMap_impl
+{
+  typedef VPM_from_NP type;
+  typedef VPM_from_NP const_type;
+
+  template<class NamedParameters>
+  static const_type
+  get_const_map(const NamedParameters& np, const PolygonMesh&)
+  {
+    return parameters::get_parameter(np, internal_np::vertex_point);
+  }
+
+  template<class NamedParameters>
+  static type
+  get_map(const NamedParameters& np, PolygonMesh&)
+  {
+    return parameters::get_parameter(np, internal_np::vertex_point);
+  }
+};
+
+template <typename PolygonMesh>
+struct GetVertexPointMap_impl<PolygonMesh, internal_np::Param_not_found>
+{
+  typedef typename property_map_selector<PolygonMesh, boost::vertex_point_t>::const_type const_type;
+  typedef typename property_map_selector<PolygonMesh, boost::vertex_point_t>::type type;
+
+  template<class NamedParameters>
+  static const_type
+  get_const_map(const NamedParameters& /* np */, const PolygonMesh& pm)
+  {
+    return get_const_property_map(boost::vertex_point, pm);
+  }
+
+  template<class NamedParameters>
+  static type
+  get_map(const NamedParameters& /* np */, PolygonMesh& pm)
+  {
+    return get_property_map(boost::vertex_point, pm);
+  }
+};
+
 template <typename PolygonMesh,
           typename NamedParameters = parameters::Default_named_parameters>
 class GetVertexPointMap
 {
-  typedef typename property_map_selector<PolygonMesh, boost::vertex_point_t>::const_type
-  DefaultVPMap_const;
-  typedef typename property_map_selector<PolygonMesh, boost::vertex_point_t>::type
-  DefaultVPMap;
+  typedef typename internal_np::Lookup_named_param_def<internal_np::vertex_point_t,
+                                                       NamedParameters,
+                                                       internal_np::Param_not_found>::type VPM_from_NP;
+
+  typedef GetVertexPointMap_impl<PolygonMesh, VPM_from_NP> Impl;
 
 public:
-  typedef typename internal_np::Lookup_named_param_def<internal_np::vertex_point_t,
-                                                       NamedParameters,
-                                                       DefaultVPMap>::type type;
-  typedef typename internal_np::Lookup_named_param_def<internal_np::vertex_point_t,
-                                                       NamedParameters,
-                                                       DefaultVPMap_const>::type const_type;
+  typedef typename Impl::type type;
+  typedef typename Impl::const_type const_type;
+
+  static const_type
+  get_const_map(const NamedParameters& np, const PolygonMesh& pm)
+  {
+    return Impl::get_const_map(np, pm);
+  }
+
+  static type
+  get_map(const NamedParameters& np, PolygonMesh& pm)
+  {
+    return Impl::get_map(np, pm);
+  }
 };
 
 template<typename PolygonMesh, typename NamedParameters>
@@ -137,10 +189,15 @@ public:
   typedef typename CGAL::Kernel_traits<Point>::Kernel Kernel;
 };
 
-template <typename PolygonMesh,
-          typename NamedParametersGT = parameters::Default_named_parameters,
-          typename NamedParametersVPM = NamedParametersGT>
-class GetGeomTraits
+
+template<typename PolygonMesh, class GT, class NamedParametersVPM>
+struct GetGeomTraits_impl
+{
+  typedef GT type;
+};
+
+template<typename PolygonMesh, class NamedParametersVPM>
+struct GetGeomTraits_impl<PolygonMesh, internal_np::Param_not_found, NamedParametersVPM>
 {
   typedef typename CGAL::graph_has_property<PolygonMesh, boost::vertex_point_t>::type Has_internal_pmap;
 
@@ -150,15 +207,23 @@ class GetGeomTraits
 
   struct Fake_GT {}; // to be used if there is no internal vertex_point_map in PolygonMesh
 
-  typedef typename boost::mpl::if_c<Has_internal_pmap::value ||
-                                    !boost::is_same<internal_np::Param_not_found, NP_vpm>::value,
-                                    typename GetK<PolygonMesh, NamedParametersVPM>::Kernel,
-                                    Fake_GT>::type DefaultKernel;
+  typedef std::conditional_t<Has_internal_pmap::value ||
+                             !std::is_same<internal_np::Param_not_found, NP_vpm>::value,
+                             typename GetK<PolygonMesh, NamedParametersVPM>::Kernel,
+                             Fake_GT> type;
+};
 
-public:
+template <typename PolygonMesh,
+          typename NamedParametersGT = parameters::Default_named_parameters,
+          typename NamedParametersVPM = NamedParametersGT>
+struct GetGeomTraits
+{
   typedef typename internal_np::Lookup_named_param_def<internal_np::geom_traits_t,
                                                        NamedParametersGT,
-                                                       DefaultKernel>::type type;
+                                                       internal_np::Param_not_found>::type GT_from_NP;
+  typedef typename GetGeomTraits_impl<PolygonMesh,
+                                          GT_from_NP,
+                                          NamedParametersVPM>::type type;
 };
 
 // Define the following structs:
@@ -277,34 +342,52 @@ public:
   typedef typename CGAL::Identity_property_map<const Dummy_point> const_type;
 };
 
-template <class PointRange, class NamedParameters, typename NP_TAG = internal_np::point_t>
+template <typename PointRange, typename NamedParameters>
+struct GetPolygonSoupGeomTraits
+{
+  typedef typename internal_np::Lookup_named_param_def <
+                     internal_np::geom_traits_t,
+                     NamedParameters,
+                     typename CGAL::Kernel_traits<
+                       typename boost::property_traits<
+                         typename GetPointMap<PointRange, NamedParameters>::type
+                       >::value_type
+                     >::type
+                   > ::type                                                         type;
+};
+
+
+template <class PointRange, class NamedParameters, class PointMap = Default, class NormalMap = Default>
 struct Point_set_processing_3_np_helper
 {
   typedef typename std::iterator_traits<typename PointRange::iterator>::value_type Value_type;
-  typedef CGAL::Identity_property_map<Value_type> DefaultPMap;
-  typedef CGAL::Identity_property_map<const Value_type> DefaultConstPMap;
+  typedef typename Default::Get<PointMap, CGAL::Identity_property_map<Value_type>>::type DefaultPMap;
+  typedef typename Default::Get<PointMap, CGAL::Identity_property_map<const Value_type>>::type DefaultConstPMap;
 
-  typedef typename internal_np::Lookup_named_param_def<NP_TAG,
-                                                       NamedParameters,
-                                                       DefaultPMap>::type Point_map;
-  typedef typename internal_np::Lookup_named_param_def<NP_TAG,
-                                                       NamedParameters,
-                                                       DefaultConstPMap>::type Const_point_map;
+  typedef typename internal_np::Lookup_named_param_def<internal_np::point_t,
+    NamedParameters,DefaultPMap> ::type  Point_map; // public
+  typedef typename internal_np::Lookup_named_param_def<internal_np::point_t,
+    NamedParameters,DefaultConstPMap> ::type  Const_point_map; // public
 
   typedef typename boost::property_traits<Point_map>::value_type Point;
   typedef typename Kernel_traits<Point>::Kernel Default_geom_traits;
 
-  typedef typename internal_np::Lookup_named_param_def<internal_np::geom_traits_t,
-                                                       NamedParameters,
-                                                       Default_geom_traits>::type Geom_traits;
+  typedef typename internal_np::Lookup_named_param_def <
+      internal_np::geom_traits_t,
+      NamedParameters,
+      Default_geom_traits
+    > ::type  Geom_traits; // public
 
-  typedef typename Geom_traits::FT FT;
+  typedef typename Geom_traits::FT FT; // public
 
   typedef Constant_property_map<Value_type, typename Geom_traits::Vector_3> DummyNormalMap;
+  typedef typename Default::Get<NormalMap, DummyNormalMap>::type DefaultNMap;
 
-  typedef typename internal_np::Lookup_named_param_def<internal_np::normal_t,
-                                                       NamedParameters,
-                                                       DummyNormalMap>::type Normal_map;
+  typedef typename internal_np::Lookup_named_param_def<
+    internal_np::normal_t,
+    NamedParameters,
+    DefaultNMap
+    > ::type  Normal_map; // public
 
   static Point_map get_point_map(PointRange&, const NamedParameters& np)
   {
@@ -336,10 +419,10 @@ struct Point_set_processing_3_np_helper
     return parameters::choose_parameter<Geom_traits>(parameters::get_parameter(np, internal_np::geom_traits));
   }
 
-  static constexpr bool has_normal_map()
+  static constexpr bool has_normal_map(const PointRange&, const NamedParameters&)
   {
-    return !boost::is_same< typename internal_np::Get_param<typename NamedParameters::base, internal_np::normal_t>::type,
-                            internal_np::Param_not_found> ::value;
+    using CGAL::parameters::is_default_parameter;
+    return !(is_default_parameter<NamedParameters, internal_np::normal_t>::value);
   }
 };
 
