@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/BGL/include/CGAL/boost/graph/properties.h $
-// $Id: properties.h 8166579 2021-10-11T19:58:07+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/BGL/include/CGAL/boost/graph/properties.h $
+// $Id: include/CGAL/boost/graph/properties.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -140,9 +140,9 @@ struct Point_accessor<Handle, ValueType, ConstReference, true>
   typedef ValueType                      value_type;
   typedef Handle                         key_type;
 
-  typedef typename boost::mpl::if_< boost::is_reference<ConstReference>,
-                                    ValueType&,
-                                    ValueType >::type Reference;
+  typedef std::conditional_t< std::is_reference_v<ConstReference>,
+                              ValueType&,
+                              ValueType > Reference;
 
   Point_accessor() {}
   Point_accessor(Point_accessor<Handle, ValueType, Reference, false>) {}
@@ -172,9 +172,9 @@ struct Is_writable_property_map<PropertyMap, boost::read_write_property_map_tag>
 // property map must define.
 template <typename PropertyMap>
 struct Is_writable_property_map<PropertyMap, boost::lvalue_property_map_tag>
-  : boost::mpl::if_c<std::is_const<typename std::remove_reference<
+  : std::conditional_t<std::is_const<typename std::remove_reference<
                        typename boost::property_traits<PropertyMap>::reference>::type>::value,
-                     CGAL::Tag_false, CGAL::Tag_true>::type
+                       CGAL::Tag_false, CGAL::Tag_true>
 { };
 
 } // namespace internal
