@@ -2,9 +2,9 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.1/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh_time_stamp.h $
-// $Id: properties_Surface_mesh_time_stamp.h 52164b1 2019-10-19T15:34:59+02:00 Sébastien Loriot
-// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh_time_stamp.h $
+// $Id: include/CGAL/boost/graph/properties_Surface_mesh_time_stamp.h 50cfbde3b84 $
+// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
 // Author(s)     : Andreas Fabri
@@ -12,6 +12,9 @@
 #ifndef CGAL_PROPERTIES_SURFACE_MESH_TIME_STAMP_H
 #define CGAL_PROPERTIES_SURFACE_MESH_TIME_STAMP_H
 
+#include <CGAL/license/Surface_mesh.h>
+
+
 #ifndef DOXYGEN_RUNNING
 
 #include <CGAL/Surface_mesh.h>
@@ -59,7 +62,7 @@ namespace CGAL {
 
 #define CGAL_PROPERTY_SURFACE_MESH_RETURN_TYPE(Tag) \
   typename boost::lazy_disable_if<                      \
-     boost::is_const<P>,                                \
+     std::is_const<P>,                                \
      Get_pmap_of_surface_mesh<P, Tag >                  \
    >::type
 
@@ -76,7 +79,7 @@ CGAL_PROPERTY_SURFACE_MESH_RETURN_TYPE(CGAL::vertex_time_stamp_t)
 inline get(CGAL::vertex_time_stamp_t, const Surface_mesh<P> & smesh)
 {
   typedef typename boost::graph_traits<Surface_mesh<P> >::vertex_descriptor vertex_descriptor;
-  return smesh. template property_map<vertex_descriptor,std::size_t>("v:time_stamp").first;
+  return smesh. template property_map<vertex_descriptor,std::size_t>("v:time_stamp").value();
 }
 
 template <typename P>
@@ -92,7 +95,7 @@ CGAL_PROPERTY_SURFACE_MESH_RETURN_TYPE(CGAL::halfedge_time_stamp_t)
 inline get(CGAL::halfedge_time_stamp_t, const Surface_mesh<P> & smesh)
 {
   typedef typename boost::graph_traits<Surface_mesh<P> >::halfedge_descriptor halfedge_descriptor;
-  return smesh. template property_map<halfedge_descriptor,std::size_t>("h:time_stamp").first;
+  return smesh. template property_map<halfedge_descriptor,std::size_t>("h:time_stamp").value();
 }
 
 template <typename P>
@@ -108,7 +111,7 @@ CGAL_PROPERTY_SURFACE_MESH_RETURN_TYPE(CGAL::face_time_stamp_t)
 inline get(CGAL::face_time_stamp_t, const Surface_mesh<P> & smesh)
 {
   typedef typename boost::graph_traits<Surface_mesh<P> >::face_descriptor face_descriptor;
-  return smesh. template property_map<face_descriptor,std::size_t>("v:time_stamp").first;
+  return smesh. template property_map<face_descriptor,std::size_t>("v:time_stamp").value();
 }
 } // namespace CGAL
 
