@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Inscribed_areas/include/CGAL/extremal_polygon_2.h $
-// $Id: extremal_polygon_2.h 3882d27 2021-01-06T10:55:53+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Inscribed_areas/include/CGAL/extremal_polygon_2.h $
+// $Id: include/CGAL/extremal_polygon_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -16,7 +16,7 @@
 #include <CGAL/license/Inscribed_areas.h>
 
 
-#include <CGAL/Optimisation/assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/monotone_matrix_search.h>
 #include <CGAL/Dynamic_matrix.h>
 #include <CGAL/Transform_iterator.h>
@@ -76,7 +76,7 @@ public:
     RandomAccessIC_object begin_col,
     RandomAccessIC_object end_col,
     RandomAccessIC_value  begin_value,
-    RandomAccessIC_value  CGAL_optimisation_precondition_code(end_value),
+    RandomAccessIC_value  CGAL_precondition_code(end_value),
     const Operation&      o)
   // initialization with two ranges [begin_row, end_row) and
   // [begin_col, end_col) of Objects, a range [begin_value, end_value)
@@ -92,9 +92,9 @@ public:
     n_rows( static_cast<int>(iterator_distance( begin_row, end_row))),
     n_cols( static_cast<int>(iterator_distance( begin_col, end_col)))
   {
-    CGAL_optimisation_precondition(
+    CGAL_precondition(
       iterator_distance( begin_value, end_value) == n_cols);
-    CGAL_optimisation_assertion( n_rows > 0 && n_cols > 0);
+    CGAL_assertion( n_rows > 0 && n_cols > 0);
   }
 
   int
@@ -108,8 +108,8 @@ public:
   Value
   operator()( int r, int c) const
   {
-    CGAL_optimisation_precondition( r >= 0 && r < n_rows);
-    CGAL_optimisation_precondition( c >= 0 && c < n_cols);
+    CGAL_precondition( r >= 0 && r < n_rows);
+    CGAL_precondition( c >= 0 && c < n_cols);
     return begin_value_[c] + op( begin_row_[r], begin_col_[c]);
   }
 
@@ -181,11 +181,11 @@ CGAL_maximum_inscribed_rooted_k_gon_2(
 // returns the past-the-end iterator of that sequence.
 {
   // check preconditions:
-  CGAL_optimisation_precondition( k >= t.min_k());
+  CGAL_precondition( k >= t.min_k());
   int number_of_points(
                        static_cast<int>(iterator_distance( points_begin,
                                                            points_end)));
-  CGAL_optimisation_precondition( number_of_points > k);
+  CGAL_precondition( number_of_points > k);
 
   typedef std::vector< int > Index_cont;
 
@@ -203,7 +203,7 @@ CGAL_maximum_inscribed_rooted_k_gon_2(
     points_begin, points_end, max_area, gon.rbegin() + k + 1 - i);
 
   for (;;) {
-    CGAL_optimisation_assertion( gon[0] == 0);
+    CGAL_assertion( gon[0] == 0);
     gon[i] = number_of_points - 1;
     if ( ++i >= k)
       break;
@@ -243,7 +243,7 @@ CGAL_maximum_inscribed_rooted_k_gon_2(
   RandomAccessIC_point points_end,
   int root,
   RandomAccessIC_int left_c_begin,
-  RandomAccessIC_int CGAL_optimisation_precondition_code(left_c_end),
+  RandomAccessIC_int CGAL_precondition_code(left_c_end),
   RandomAccessIC_int right_c_begin,
   RandomAccessIC_int right_c_end,
   typename Traits::FT& max_area,
@@ -294,26 +294,26 @@ CGAL_maximum_inscribed_rooted_k_gon_2(
                                                         right_c_end));
 
   // check preconditions:
-  CGAL_optimisation_precondition( number_of_points > t.min_k());
-  CGAL_optimisation_precondition( size_of_gon >= t.min_k() - 1);
-  CGAL_optimisation_precondition(
+  CGAL_precondition( number_of_points > t.min_k());
+  CGAL_precondition( size_of_gon >= t.min_k() - 1);
+  CGAL_precondition(
     iterator_distance( left_c_begin, left_c_end) ==
     iterator_distance( right_c_begin, right_c_end));
-  CGAL_optimisation_precondition( left_c_begin[0] >= 0);
-  CGAL_optimisation_precondition( right_c_begin[0] >= 0);
-  CGAL_optimisation_precondition(
+  CGAL_precondition( left_c_begin[0] >= 0);
+  CGAL_precondition( right_c_begin[0] >= 0);
+  CGAL_precondition(
     left_c_begin[size_of_gon-1] < number_of_points);
-  CGAL_optimisation_precondition(
+  CGAL_precondition(
     right_c_begin[size_of_gon-1] < number_of_points);
-  CGAL_optimisation_expensive_precondition_code(
+  CGAL_expensive_precondition_code(
     for ( i = 0; i < size_of_gon; ++i) {
-      CGAL_optimisation_expensive_precondition( left_c_begin[i] >= 0);
-      CGAL_optimisation_expensive_precondition( right_c_begin[i] >= 0);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition( left_c_begin[i] >= 0);
+      CGAL_expensive_precondition( right_c_begin[i] >= 0);
+      CGAL_expensive_precondition(
         left_c_begin[i] < number_of_points);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition(
         right_c_begin[i] < number_of_points);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition(
         left_c_begin[i] <= right_c_begin[i]);
     })
 
@@ -426,12 +426,12 @@ extremal_polygon_2(
 // returns the past-the-end iterator of that sequence.
 {
   // check preconditions:
-  CGAL_optimisation_precondition_code(
+  CGAL_precondition_code(
     int number_of_points(
                          static_cast<int>(iterator_distance( points_begin,
                                                              points_end)));)
-  CGAL_optimisation_precondition( number_of_points >= t.min_k());
-  CGAL_optimisation_expensive_precondition(
+  CGAL_precondition( number_of_points >= t.min_k());
+  CGAL_expensive_precondition(
     is_convex_2( points_begin, points_end, t));
 
   typedef typename Traits::Point_2 Point_2;
@@ -491,11 +491,11 @@ CGAL_maximum_inscribed_k_gon_2(
 // returns the past-the-end iterator of that sequence.
 {
   // check preconditions:
-  CGAL_optimisation_precondition( k >= t.min_k());
+  CGAL_precondition( k >= t.min_k());
   int number_of_points(
                        static_cast<int>(iterator_distance( points_begin,
                                                            points_end)));
-  CGAL_optimisation_precondition( number_of_points > 0);
+  CGAL_precondition( number_of_points > 0);
 
   using std::copy;
 
@@ -518,7 +518,7 @@ CGAL_maximum_inscribed_k_gon_2(
     P_0.rbegin() + 1,
     t);
   P_0[k] = number_of_points - 1;
-  CGAL_optimisation_assertion( P_0[0] == 0);
+  CGAL_assertion( P_0[0] == 0);
   // compute k-gon rooted at points_begin[P_0[1]]
   Index_cont P_1( k);
   FT area_1;
@@ -535,7 +535,7 @@ CGAL_maximum_inscribed_k_gon_2(
     P_1.rbegin(),
     t);
 
-  CGAL_optimisation_assertion( P_1[0] == P_0[1]);
+  CGAL_assertion( P_1[0] == P_0[1]);
 
 
   // start recursive computation:
@@ -630,29 +630,29 @@ CGAL_maximum_inscribed_k_gon_2(
   using std::copy;
 
   // check preconditions:
-  CGAL_optimisation_precondition( k >= t.min_k());
-  CGAL_optimisation_precondition( left_index <= right_index);
-  CGAL_optimisation_precondition( left_index >= 0);
-  CGAL_optimisation_precondition( right_index >= 0);
-  CGAL_optimisation_precondition_code(
+  CGAL_precondition( k >= t.min_k());
+  CGAL_precondition( left_index <= right_index);
+  CGAL_precondition( left_index >= 0);
+  CGAL_precondition( right_index >= 0);
+  CGAL_precondition_code(
     int number_of_points(
                          static_cast<int>(iterator_distance( points_begin,
                                                              points_end)));)
-  CGAL_optimisation_precondition( left_index < number_of_points);
-  CGAL_optimisation_precondition( right_index < number_of_points);
-  CGAL_optimisation_precondition(
+  CGAL_precondition( left_index < number_of_points);
+  CGAL_precondition( right_index < number_of_points);
+  CGAL_precondition(
     iterator_distance( left_c_begin, left_c_end) == k - 1);
-  CGAL_optimisation_precondition(
+  CGAL_precondition(
     iterator_distance( right_c_begin, right_c_end) == k - 1);
-  CGAL_optimisation_expensive_precondition_code(
+  CGAL_expensive_precondition_code(
     for ( int i( 0); i < k - 1; ++i) {
-      CGAL_optimisation_expensive_precondition( left_c_begin[i] >= 0);
-      CGAL_optimisation_expensive_precondition( right_c_begin[i] >= 0);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition( left_c_begin[i] >= 0);
+      CGAL_expensive_precondition( right_c_begin[i] >= 0);
+      CGAL_expensive_precondition(
         left_c_begin[i] < number_of_points);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition(
         right_c_begin[i] < number_of_points);
-      CGAL_optimisation_expensive_precondition(
+      CGAL_expensive_precondition(
         left_c_begin[i] <= right_c_begin[i]);
     })
 
@@ -671,7 +671,7 @@ CGAL_maximum_inscribed_k_gon_2(
     area_middle,
     P_m.rbegin(),
     t);
-  CGAL_optimisation_assertion( P_m[0] == middle_index);
+  CGAL_assertion( P_m[0] == middle_index);
   // left recursive branch:
   FT area_left( 0);
   Index_cont P_l( k);
