@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Algebraic_foundations/include/CGAL/number_utils.h $
-// $Id: number_utils.h e222e77 2021-05-18T18:16:44+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Algebraic_foundations/include/CGAL/number_utils.h $
+// $Id: include/CGAL/number_utils.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -194,21 +194,21 @@ root_of( int k, Input_iterator begin, Input_iterator end ) {
 template< class Number_type >
 inline
 // select a Is_zero functor
-typename boost::mpl::if_c<
- ::boost::is_same< typename Algebraic_structure_traits< Number_type >::Is_zero,
- Null_functor  >::value ,
+typename std::conditional_t<
+ std::is_same_v< typename Algebraic_structure_traits< Number_type >::Is_zero,
+ Null_functor  >,
   typename Real_embeddable_traits< Number_type >::Is_zero,
   typename Algebraic_structure_traits< Number_type >::Is_zero
->::type::result_type
+>::result_type
 is_zero( const Number_type& x ) {
     // We take the Algebraic_structure_traits<>::Is_zero functor by default. If it
     //  is not available, we take the Real_embeddable_traits functor
-    typename ::boost::mpl::if_c<
-        ::boost::is_same<
+    std::conditional_t<
+        std::is_same_v<
              typename Algebraic_structure_traits< Number_type >::Is_zero,
-             Null_functor >::value ,
+             Null_functor > ,
        typename Real_embeddable_traits< Number_type >::Is_zero,
-       typename Algebraic_structure_traits< Number_type >::Is_zero >::type
+       typename Algebraic_structure_traits< Number_type >::Is_zero >
        is_zero;
 return is_zero( x );
 }
