@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Partition_2/include/CGAL/partition_is_valid_2.h $
-// $Id: partition_is_valid_2.h 521c72d 2021-10-04T13:22:00+02:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Partition_2/include/CGAL/partition_is_valid_2.h $
+// $Id: include/CGAL/partition_is_valid_2.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -19,7 +19,7 @@
 #include <list>
 #include <utility>
 #include <iterator>
-#include <CGAL/Partition_2/partition_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Partition_2/Partitioned_polygon_2.h>
 #include <CGAL/Partition_2/Partition_vertex_map.h>
 #include <CGAL/ch_selected_extreme_points_2.h>
@@ -147,8 +147,8 @@ partition_is_valid_2 (InputIterator point_first, InputIterator point_last,
    for (;point_first != point_last; point_first++)
       orig_poly.push_back(*point_first);
 
-   CGAL_partition_precondition(orientation_2(orig_poly.begin(),orig_poly.end(),
-                                             traits) == COUNTERCLOCKWISE);
+   CGAL_precondition(orientation_2(orig_poly.begin(),orig_poly.end(),
+                                   traits) == COUNTERCLOCKWISE);
 
    P_Vertex_map  output_vertex_set(poly_first, poly_last, traits);
 
@@ -163,7 +163,7 @@ partition_is_valid_2 (InputIterator point_first, InputIterator point_last,
          std::cout << "Polygon " << poly_num << " is " << std::endl;
          std::cout << *poly_first << std::endl;
 #endif
-      CGAL_partition_assertion (
+      CGAL_assertion (
            orientation_2(vtx_begin, vtx_end, traits) == COUNTERCLOCKWISE);
       if (!is_valid(vtx_begin, vtx_end))
       {
