@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Polygon_mesh_processing/include/CGAL/polygon_mesh_processing.h $
-// $Id: polygon_mesh_processing.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Polygon_mesh_processing/include/CGAL/polygon_mesh_processing.h $
+// $Id: include/CGAL/polygon_mesh_processing.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -17,6 +17,11 @@
 * the free functions of this package.
 */
 
+#ifndef CGAL_POLYGON_MESH_PROCESSING_H
+#define CGAL_POLYGON_MESH_PROCESSING_H
+
+#include <CGAL/license/Polygon_mesh_processing/core.h>
+
 #include <CGAL/Polygon_mesh_processing/orient_polygon_soup.h>
 #include <CGAL/Polygon_mesh_processing/self_intersections.h>
 #include <CGAL/Polygon_mesh_processing/polygon_soup_to_polygon_mesh.h>
@@ -49,21 +54,6 @@
 #include <CGAL/Polygon_mesh_processing/smooth_mesh.h>
 #include <CGAL/Polygon_mesh_processing/smooth_shape.h>
 #include <CGAL/Polygon_mesh_processing/manifoldness.h>
+#include <CGAL/Polygon_mesh_processing/autorefinement.h>
 
-// the named parameter header being not documented the doc is put here for now
-#ifdef DOXYGEN_RUNNING
-namespace CGAL {
-namespace Polygon_mesh_processing {
-namespace parameters {
-
-/*! \ingroup namedparameters
-\deprecated This function is deprecated and `default_values()` should be used instead.
-This function can be used to indicate that all optional named parameters
-to be used are the default ones. This is particularly useful when a function
-requires more than one sequence of named parameters and default values is
-fine only for some of them.
-*/
-unspecified_type all_default();
-
-} } } // end of namespace CGAL::Polygon_mesh_processing::parameters
-#endif
+#endif //CGAL_POLYGON_MESH_PROCESSING_H
