@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.1/Point_set_processing_3/include/CGAL/random_simplify_point_set.h $
-// $Id: random_simplify_point_set.h 6d3176e 2022-01-07T14:42:25+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Point_set_processing_3/include/CGAL/random_simplify_point_set.h $
+// $Id: include/CGAL/random_simplify_point_set.h 50cfbde3b84 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Laurent Saboret
@@ -19,7 +19,7 @@
 #include <CGAL/algorithm.h>
 #include <CGAL/Kernel_traits.h>
 #include <CGAL/property_map.h>
-#include <CGAL/point_set_processing_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Iterator_range.h>
 
 #include <CGAL/Named_function_parameters.h>
@@ -53,7 +53,7 @@ random_simplify_point_set(
   PointRange& points,
   double removed_percentage)
 {
-  CGAL_point_set_processing_precondition(removed_percentage >= 0 && removed_percentage <= 100);
+  CGAL_precondition(removed_percentage >= 0 && removed_percentage <= 100);
 
   // Random shuffle
   CGAL::cpp98::random_shuffle (points.begin(), points.end());
