@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.4.1/Number_types/include/CGAL/to_rational.h $
-// $Id: to_rational.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Number_types/include/CGAL/to_rational.h $
+// $Id: include/CGAL/to_rational.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -34,9 +34,9 @@ to_rational(double x)
     typedef typename FT::Denominator_type Denominator_type;
     typename FT::Compose compose;
 
-    CGAL_static_assertion((::boost::is_same<Is_fraction,Tag_true>::value));
+    static_assert(::std::is_same<Is_fraction,Tag_true>::value);
     CGAL_USE_TYPE(Is_fraction);
-    CGAL_static_assertion((::boost::is_same<Numerator_type,Denominator_type>::value));
+    static_assert(::std::is_same<Numerator_type,Denominator_type>::value);
     CGAL_USE_TYPE(Denominator_type);
 
     Numerator_type num(0),den(1);
