@@ -1,4 +1,4 @@
-// Copyright (c) 2009
+// Copyright (c) 2009-2024
 // Utrecht University (The Netherlands),
 // ETH Zurich (Switzerland),
 // INRIA Sophia-Antipolis (France),
@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6/Installation/include/CGAL/version.h $
-// $Id: version.h 454ac73 2023-07-26T14:15:18+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/Installation/include/CGAL/version.h $
+// $Id: include/CGAL/version.h 50cfbde3b84 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : -
@@ -17,12 +17,12 @@
 #define CGAL_VERSION_H
 
 #ifndef SWIG
-#define CGAL_VERSION 5.6
-#define CGAL_GIT_HASH de4fa0d7d57b5a997012f2804161386ff4bc0d0f
+#define CGAL_VERSION 6.0.1
+#define CGAL_GIT_HASH 50cfbde3b84dbeae8338268db2d78fe4fcb522de
 #endif
-#define CGAL_VERSION_NR 1050601000
+#define CGAL_VERSION_NR 1060011000
 #define CGAL_SVN_REVISION 99999
-#define CGAL_RELEASE_DATE 20230726
+#define CGAL_RELEASE_DATE 20241020
 
 #include <CGAL/version_macros.h>
 
